import { GraphQLResolveInfo, GraphQLScalarType, GraphQLScalarTypeConfig } from 'graphql';
export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export declare type Omit<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    DateTime: any;
    URI: any;
    AnyObject: any;
    Date: any;
    JSON: any;
    URIInput: any;
    JSONObject: any;
    Observable: any;
    Time: any;
    Upload: any;
};
export declare type IAccessRole = IDefaultRole | IOrganizationRole | IResourceRole | IApplicationRolePermission;
/**
 * Teams are groups of organization members that reflect yoru company or group's structure
 * with cascading access permissions and mentions.
 * @property
 * name: The name of the team
 * @property
 * description: Description of the team.
 * @property
 * orgId: The organization to which the team belongs.
 * @property
 * parentTeam: The parent team of the team.
 * @property
 * tags: Arbitrary tags that the team uses.
 * @property
 * invitations: The outstanding invitations to join the team.
 * @property
 * teamMembers: Team members.
 */
export declare type IAccountTeam = {
    __typename?: 'AccountTeam';
    id?: Maybe<Scalars['ID']>;
    _id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    orgName?: Maybe<Scalars['String']>;
    tags?: Maybe<Array<Maybe<Scalars['String']>>>;
    settingsUri?: Maybe<Scalars['URI']>;
    parentTeam?: Maybe<IAccountTeam>;
    updatedAt?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    teamMembers?: Maybe<Array<Maybe<ITeamMember>>>;
};
export declare type IAccountTeam_Input = {
    id?: Maybe<Scalars['ID']>;
    _id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    orgName?: Maybe<Scalars['String']>;
    tags?: Maybe<Array<Maybe<Scalars['String']>>>;
    description?: Maybe<Scalars['String']>;
    parentTeam?: Maybe<IAccountTeam_Input>;
    teamMembers?: Maybe<Array<Maybe<ITeamMember_Input>>>;
};
export declare type IAddressType = {
    __typename?: 'AddressType';
    attention?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    city?: Maybe<Scalars['String']>;
    state?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    zip?: Maybe<Scalars['String']>;
};
export declare type IAddressType_Input = {
    attention?: Maybe<Scalars['String']>;
    address?: Maybe<Scalars['String']>;
    city?: Maybe<Scalars['String']>;
    state?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    zip?: Maybe<Scalars['String']>;
};
export declare type IAdminIdeSettings = {
    __typename?: 'AdminIdeSettings';
    dummy?: Maybe<Scalars['Int']>;
};
export declare type IApplicationPolicy = IIConfigurationModel & {
    __typename?: 'ApplicationPolicy';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IApplicationRolePermission = IIConfigurationModel & {
    __typename?: 'ApplicationRolePermission';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare enum IApplicationRoles {
    /** Admin of an Organization */
    ADMIN = "ADMIN",
    /** Project Contributors */
    CONTRIBUTORS = "CONTRIBUTORS",
    /** Guest  */
    GUEST = "GUEST",
    MEMBER = "MEMBER",
    /**  organization member  */
    ORGANIZATION_MANAGER = "ORGANIZATION_MANAGER",
    /** Owner of an Organization */
    OWNER = "OWNER",
    /** Project Admin */
    PROJECT_ADMIN = "PROJECT_ADMIN",
    /** Project Viewer */
    PROJECT_VIEWER = "PROJECT_VIEWER",
    TEAM_MAINTAINER = "TEAM_MAINTAINER",
    TEAM_MEMBER = "TEAM_MEMBER",
    /** User who is logged in */
    USER = "USER"
}
export declare type IApplicationSettings = IISettingsSubject & {
    __typename?: 'ApplicationSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings. */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare type IAsanaConnection = {
    __typename?: 'AsanaConnection';
    asana?: Maybe<IAsanaConnectionState>;
};
export declare type IAsanaConnectionState = {
    __typename?: 'AsanaConnectionState';
    status?: Maybe<Scalars['String']>;
    user?: Maybe<IAsanaUser>;
};
export declare type IAsanaProjects = {
    __typename?: 'AsanaProjects';
    gid?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
};
export declare type IAsanaUser = {
    __typename?: 'AsanaUser';
    user_id?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
};
export declare type IAsanaWorkspaces = {
    __typename?: 'AsanaWorkspaces';
    gid?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
};
export declare type IAuth0Identity = {
    __typename?: 'Auth0Identity';
    connection?: Maybe<Scalars['String']>;
    isSocial?: Maybe<Scalars['Boolean']>;
    provider?: Maybe<Scalars['String']>;
    user_id?: Maybe<Scalars['String']>;
    profileData?: Maybe<IAuth0IdentityProfileData>;
};
/** Auth0 User Profile */
export declare type IAuth0IdentityProfileData = {
    __typename?: 'Auth0IdentityProfileData';
    email?: Maybe<Scalars['String']>;
    connection?: Maybe<Scalars['String']>;
};
/** AuthUser */
export declare type IAuthUser = IIUser & {
    __typename?: 'AuthUser';
    id: Scalars['ID'];
    auth0UserId?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    emailVerified?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    phoneNo?: Maybe<Scalars['Int']>;
};
export declare type IAuthUser_Input = {
    auth0UserId?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    emailVerified?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    phoneNo?: Maybe<Scalars['Int']>;
};
export declare enum IBaseServiceCommands {
    count = "count",
    get = "get",
    getAll = "getAll",
    create = "create",
    insert = "insert",
    bulkCreate = "bulkCreate",
    update = "update",
    delete = "delete",
    getAllWithCount = "getAllWithCount"
}
export declare type IChannel = IIBaseRepo & {
    __typename?: 'Channel';
    id: Scalars['String'];
    title?: Maybe<Scalars['String']>;
    topic?: Maybe<Scalars['String']>;
    purpose?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    displayName?: Maybe<Scalars['String']>;
    team?: Maybe<IAccountTeam>;
    lastPostAt?: Maybe<Scalars['DateTime']>;
    totalMsgCount?: Maybe<Scalars['Int']>;
    totalMsgCountRoot?: Maybe<Scalars['Int']>;
    creator?: Maybe<IUserAccount>;
    members?: Maybe<Array<Maybe<IChannelMember>>>;
    type?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
};
export declare type IChannelFilterInput = {
    nameFilter?: Maybe<Scalars['String']>;
    privacy?: Maybe<IChannelPrivacy>;
    joinedChannels?: Maybe<Scalars['Boolean']>;
    storyBy?: Maybe<IChannelSort>;
};
export declare type IChannelMember = {
    __typename?: 'ChannelMember';
    id: Scalars['ID'];
    user: Scalars['String'];
    roles?: Maybe<Scalars['String']>;
    msgCount?: Maybe<Scalars['Int']>;
    mentionCount?: Maybe<Scalars['Int']>;
    mentionCountRoot?: Maybe<Scalars['Int']>;
    msgCountRoot?: Maybe<Scalars['Int']>;
    notifyProps?: Maybe<Scalars['AnyObject']>;
    explicitRoles?: Maybe<Scalars['String']>;
    schemeAdmin?: Maybe<Scalars['Boolean']>;
    lastViewedAt?: Maybe<Scalars['Int']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    CreatedAt?: Maybe<Scalars['DateTime']>;
};
export declare type IChannelMemberInput = {
    userId: Scalars['String'];
    roles?: Maybe<Scalars['String']>;
    notifyProps?: Maybe<Scalars['AnyObject']>;
    schemeGuest?: Maybe<Scalars['Boolean']>;
    schemeUser?: Maybe<Scalars['Boolean']>;
    schemeAdmin?: Maybe<Scalars['Boolean']>;
    explicitRoles?: Maybe<Scalars['String']>;
};
export declare type IChannelNameAndDirect = {
    name: Scalars['String'];
    direct: Scalars['Boolean'];
};
export declare enum IChannelPrivacy {
    PRIVATE = "PRIVATE",
    PUBLIC = "PUBLIC",
    ALL = "ALL"
}
export declare enum IChannelServiceCommands {
    createDirectChannel = "createDirectChannel",
    addMemberToChannel = "addMemberToChannel",
    saveDirectChannel = "saveDirectChannel",
    saveChannel = "saveChannel",
    getChannelUnread = "getChannelUnread",
    invalidateChannelByName = "invalidateChannelByName",
    getPinnedPosts = "getPinnedPosts",
    getFromMaster = "getFromMaster",
    restore = "restore",
    permanentDeleteByTeam = "permanentDeleteByTeam",
    permanentDelete = "permanentDelete",
    permanentDeleteMembersByChannel = "permanentDeleteMembersByChannel",
    getChannels = "getChannels",
    getMoreChannels = "getMoreChannels",
    getPrivateChannelsForTeam = "getPrivateChannelsForTeam",
    getPublicChannelsForTeam = "getPublicChannelsForTeam",
    getPublicChannelsByIdsForTeam = "getPublicChannelsByIdsForTeam",
    getChannelCounts = "getChannelCounts",
    getTeamChannels = "getTeamChannels",
    getByName = "getByName",
    getByNames = "getByNames",
    getByNameIncludeDeleted = "getByNameIncludeDeleted",
    getDeletedByName = "getDeletedByName",
    getDeleted = "getDeleted",
    saveMultipleMembers = "saveMultipleMembers",
    hideChannel = "hideChannel",
    leaveChannel = "leaveChannel",
    deleteChannel = "deleteChannel",
    isMember = "isMember",
    viewChannel = "viewChannel"
}
export declare type IChannelSettings = {
    __typename?: 'ChannelSettings';
    disableNotification?: Maybe<Scalars['Boolean']>;
    audio?: Maybe<Scalars['String']>;
    desktop?: Maybe<Scalars['String']>;
    duration?: Maybe<Scalars['Int']>;
    mobile?: Maybe<Scalars['String']>;
    mail?: Maybe<Scalars['String']>;
    hideUnreadRoomStatus?: Maybe<Scalars['Boolean']>;
    unreadTrayIconAlret?: Maybe<Scalars['String']>;
};
export declare enum IChannelSort {
    NAME = "NAME",
    NUMBER_OF_MESSAGES = "NUMBER_OF_MESSAGES"
}
export declare type IChannelUnread = {
    __typename?: 'ChannelUnread';
    teamId?: Maybe<Scalars['String']>;
    channelId?: Maybe<Scalars['String']>;
    msgCount?: Maybe<Scalars['Int']>;
    mentionCount?: Maybe<Scalars['Int']>;
    mentionCountRoot?: Maybe<Scalars['Int']>;
    msgCountRoot?: Maybe<Scalars['Int']>;
    notifyProps?: Maybe<Scalars['AnyObject']>;
};
/** Address City Create Input */
export declare type ICityInput = {
    /** Name of the state to display */
    name: Scalars['String'];
    /** ID of State to associate */
    state: ITerritorialStateInput;
};
/** Address City Update Input */
export declare type ICityUpdateInput = {
    name?: Maybe<Scalars['String']>;
    state: ITerritorialStateUpdateInput;
};
export declare type IClient = {
    __typename?: 'Client';
    id?: Maybe<Scalars['ID']>;
    name: INameType;
    companyName?: Maybe<Scalars['String']>;
    displayName: Scalars['String'];
    email?: Maybe<Scalars['String']>;
    clientPhone?: Maybe<IClientPhone>;
    website?: Maybe<Scalars['String']>;
    currency: Scalars['String'];
    socialConnect?: Maybe<ISocialConnect>;
    billingAddress?: Maybe<IAddressType>;
    shippingAddress?: Maybe<IAddressType>;
    orgName?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
};
export declare type IClientAddRequest = {
    name: IName_Input;
    companyName?: Maybe<Scalars['String']>;
    displayName: Scalars['String'];
    email?: Maybe<Scalars['String']>;
    clientPhone?: Maybe<IClientPhone_Input>;
    website?: Maybe<Scalars['String']>;
    currency: Scalars['String'];
    socialConnect?: Maybe<ISocialConnect_Input>;
    billingAddress?: Maybe<IAddressType_Input>;
    shippingAddress?: Maybe<IAddressType_Input>;
    orgName?: Maybe<Scalars['String']>;
};
export declare type IClientPhone = {
    __typename?: 'ClientPhone';
    workPhone?: Maybe<Scalars['String']>;
    mobile?: Maybe<Scalars['String']>;
};
export declare type IClientPhone_Input = {
    workPhone?: Maybe<Scalars['String']>;
    mobile?: Maybe<Scalars['String']>;
};
export declare enum IClientTypes {
    Business = "Business",
    Individuals = "Individuals"
}
export declare type IClientUpdateRequest = {
    id?: Maybe<Scalars['String']>;
    payload?: Maybe<IUpdatedClient_Input>;
};
export declare enum IConfigCollectionName {
    application = "application",
    accounts = "accounts",
    organizations = "organizations",
    machines = "machines",
    workspaces = "workspaces",
    teams = "teams",
    projects = "projects",
    clients = "clients"
}
export declare enum IConfigFragmentName {
    resources = "resources",
    settings = "settings",
    policies = "policies",
    applicationPolicies = "applicationPolicies",
    roles = "roles",
    contributionRoles = "contributionRoles",
    /**  Team Members Document with role value  */
    teamMembers = "teamMembers",
    /**  Organization Members Document with role value  */
    orgMembers = "orgMembers",
    /**  Billing  */
    billingPlanPolicies = "billingPlanPolicies"
}
export declare type IConfiguration = IDefaultConfiguration | IMachineConfiguration | IUserConfiguration | IOrganizationConfiguration | IOrganizationResourceConfiguration;
export declare type IConfigurationData = {
    __typename?: 'ConfigurationData';
    defaults?: Maybe<IIConfigurationModel>;
    user?: Maybe<IIConfigurationModel>;
    machine?: Maybe<IIConfigurationModel>;
    organization?: Maybe<IIConfigurationModel>;
    resources?: Maybe<Array<Maybe<IIConfigurationModel>>>;
    isComplete?: Maybe<Scalars['Boolean']>;
};
export declare type IConfigurationExtensionInfo = {
    __typename?: 'ConfigurationExtensionInfo';
    id?: Maybe<Scalars['String']>;
};
export declare type IConfigurationInput = {
    target: Scalars['Int'];
    resource?: Maybe<Scalars['URIInput']>;
    /**
     * User resource to identify the core user settings.
     * For guest user, we don't have to define it.
     */
    userResource?: Maybe<Scalars['URI']>;
};
export declare type IConfigurationModel = {
    __typename?: 'ConfigurationModel';
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IConfigurationOverrides = {
    __typename?: 'ConfigurationOverrides';
    resource?: Maybe<Scalars['URI']>;
    overrideIdentifier?: Maybe<Scalars['String']>;
    externalResource?: Maybe<Scalars['URI']>;
};
export declare type IConfigurationOverrides_Input = {
    resource?: Maybe<Scalars['URI']>;
    overrideIdentifier?: Maybe<Scalars['String']>;
    externalResource?: Maybe<Scalars['URI']>;
};
export declare type IConfigurationPolicy = IDefaultPolicy | IOrganizationPolicy | IResourcePolicy | IApplicationPolicy;
/**
 * A configuration settings can have one of the following possible scopes.
 * Configuration scopes determine when a settings is available to the user through the Settings editor and
 * whether the setting is applicable. If no scope is declared, the default is `window`.
 */
export declare enum IConfigurationScope {
    /** Application specific configuration, which can be configured only in local user settings. */
    APPLICATION = "APPLICATION",
    /** Machine specific configuration, which can be configured only in local and remote user settings. */
    MACHINE = "MACHINE",
    /** Window specific configuration, which can be configured in the user or organization settings. */
    WINDOW = "WINDOW",
    /** Resource specific configuration, which can be configured in the user, organization or workspace settings. */
    RESOURCE = "RESOURCE"
}
export declare enum IConfigurationTarget {
    /** Targets the user configuration file for writing. */
    USER = "USER",
    APPLICATION = "APPLICATION",
    MACHINE = "MACHINE",
    /** Targets the organization configuration file for writing. This only works if a organization is opened. */
    ORGANIZATION = "ORGANIZATION",
    /** Targets the resource configuration file for writing. This only works if a organization is opened. */
    ORGANIZATION_RESOURCE = "ORGANIZATION_RESOURCE",
    DEFAULT = "DEFAULT",
    MEMORY = "MEMORY"
}
export declare type IConfigurationUpdateEvent = {
    __typename?: 'ConfigurationUpdateEvent';
    resource: Scalars['URI'];
    contents?: Maybe<Scalars['AnyObject']>;
    overrides?: Maybe<IConfigurationOverrides>;
    target?: Maybe<Scalars['Int']>;
};
/** Contributed Roles added by the user to customize the role's permissions */
export declare type IContributionRoles = {
    __typename?: 'ContributionRoles';
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    target?: Maybe<Scalars['Int']>;
    description?: Maybe<Scalars['String']>;
    permissions?: Maybe<IAccessRole>;
};
export declare type IContributionSettings = {
    __typename?: 'ContributionSettings';
    /**  name of the settings */
    name?: Maybe<Scalars['String']>;
    range?: Maybe<IRange>;
    key?: Maybe<Scalars['String']>;
    keyRange?: Maybe<IRange>;
    /**  @deprecated  */
    default?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['AnyObject']>;
    valueRange?: Maybe<IRange>;
    description?: Maybe<Array<Maybe<Scalars['String']>>>;
    descriptionIsMarkdown?: Maybe<Scalars['Boolean']>;
    descriptionRanges?: Maybe<Array<Maybe<IRange>>>;
    overrides?: Maybe<Array<Maybe<IContributionSettings>>>;
    overrideOf?: Maybe<IContributionSettings>;
    deprecationMessage?: Maybe<Scalars['String']>;
    scope?: Maybe<IConfigurationScope>;
    type?: Maybe<Array<Maybe<Scalars['String']>>>;
    enum?: Maybe<Array<Maybe<Scalars['String']>>>;
    enumDescriptions?: Maybe<Array<Maybe<Scalars['String']>>>;
    enumDescriptionsAreMarkdown?: Maybe<Scalars['Boolean']>;
    tags?: Maybe<Array<Maybe<Scalars['String']>>>;
    extensionInfo?: Maybe<IConfigurationExtensionInfo>;
    properties?: Maybe<IContributionSettingsProperties>;
    /**  dependency to parent setting key  */
    settingDependencies?: Maybe<Array<Maybe<Scalars['String']>>>;
    /**  minimum value for restricting numeric values  */
    minimum?: Maybe<Scalars['Int']>;
    /**  maximum value for restricting numeric values  */
    maximum?: Maybe<Scalars['Int']>;
    /**  max. length for restricting string length  */
    maxLength?: Maybe<Scalars['Int']>;
    /**  min. length for restricting string length  */
    minLength?: Maybe<Scalars['Int']>;
    /**  pattern for restricting strings to a given regular expression  */
    pattern?: Maybe<Scalars['String']>;
    /**  Pattern Error Message for giving a tailored error message when a pttern does not match  */
    patternErrorMessage?: Maybe<Scalars['String']>;
    /**  format for restricting strings to well-known formats, such as date, time, ipv4, email, and uri  */
    format?: Maybe<Scalars['String']>;
    /**  Max. Items for restricting array length  */
    maxItems?: Maybe<Scalars['Int']>;
    /**  Min. Items for restricting array length  */
    minItems?: Maybe<Scalars['Int']>;
    /**
     *  Edit Presentation for controlling whether a single-line inputbox or multi-line
     * textarea is rendered for the string setting in Settings editor
     */
    editPresentation?: Maybe<IEditPresentationTypes>;
};
export declare type IContributionSettingsProperties = {
    __typename?: 'ContributionSettingsProperties';
    readOnly?: Maybe<Scalars['Boolean']>;
    disabled?: Maybe<Scalars['Boolean']>;
};
export declare type ICountry = {
    __typename?: 'Country';
    id: Scalars['ID'];
    name: Scalars['String'];
    phoneCode: Scalars['String'];
};
export declare type ICountryInput = {
    name: Scalars['String'];
};
export declare type ICustomerInvoice = {
    __typename?: 'CustomerInvoice';
    id?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    companyName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<IClientPhone>;
    billingAddress?: Maybe<IAddressType>;
    shippingAddress?: Maybe<IAddressType>;
};
export declare type ICustomerInvoice_Input = {
    id?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    companyName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<IClientPhone_Input>;
    billingAddress?: Maybe<IAddressType_Input>;
    shippingAddress?: Maybe<IAddressType_Input>;
};
export declare type IDefaultConfiguration = IIConfigurationModel & {
    __typename?: 'DefaultConfiguration';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /** The URL to the user's settings. */
    resource: Scalars['URI'];
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IDefaultPolicy = IIConfigurationModel & {
    __typename?: 'DefaultPolicy';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IDefaultRole = IIConfigurationModel & {
    __typename?: 'DefaultRole';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IDefaultSettings = IISettingsSubject & {
    __typename?: 'DefaultSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings. */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare enum IEditPresentationTypes {
    Multiline = "Multiline",
    Singleline = "Singleline"
}
/**
 * A basic environment service that can be used in various processes,
 * such as main, renderer and shared process. Use subclasses of this
 * service for specific environment.
 */
export declare type IEnvironment = {
    __typename?: 'Environment';
    args?: Maybe<Scalars['AnyObject']>;
};
export declare type IEnvironmentPayload = {
    args?: Maybe<Scalars['AnyObject']>;
};
export declare type IExternalResourceData = IIResourceData & {
    __typename?: 'ExternalResourceData';
    /** The associated URI for this external resource. */
    uri?: Maybe<Scalars['URI']>;
    /** The name of this external resource. Defaults to the basename its [uri-path](#Uri.path) */
    name?: Maybe<Scalars['String']>;
    /** The ordinal number of this external resource. */
    index?: Maybe<Scalars['Int']>;
};
export declare type IFieldError = {
    __typename?: 'FieldError';
    field: Scalars['String'];
    message: Scalars['String'];
};
export declare type IFile = {
    __typename?: 'File';
    filename: Scalars['String'];
    mimetype: Scalars['String'];
    encoding: Scalars['String'];
};
export declare type IFileImageDimensions = {
    width?: Maybe<Scalars['Int']>;
    height?: Maybe<Scalars['Int']>;
};
export declare type IFileInfo = {
    __typename?: 'FileInfo';
    id: Scalars['ID'];
    name: Scalars['String'];
    extension: Scalars['String'];
    mimeType: Scalars['String'];
    size: Scalars['Float'];
    width?: Maybe<Scalars['Float']>;
    height?: Maybe<Scalars['Float']>;
    url: Scalars['String'];
    ref: Scalars['ID'];
    refType: IFileRefType;
    createdAt: Scalars['Date'];
    updatedAt?: Maybe<Scalars['Date']>;
    createdBy?: Maybe<INode>;
};
export declare type IFileInfoInput = {
    ref: Scalars['String'];
    refType: IFileRefType;
    createdBy: Scalars['String'];
};
export declare type IFileInfoUpdateInput = {
    ref?: Maybe<Scalars['String']>;
};
/**  File Reference Type  */
export declare enum IFileRefType {
    Post = "Post",
    Unknown = "Unknown"
}
export declare type IFilesInfo = {
    __typename?: 'FilesInfo';
    totalCount: Scalars['Int'];
    data?: Maybe<Array<Maybe<IFileInfo>>>;
};
export declare type IGeoLocation = {
    __typename?: 'GeoLocation';
    coordinates?: Maybe<Array<Maybe<Scalars['Float']>>>;
};
export declare enum IGlobalCurrencies {
    USD = "USD",
    EURO = "EURO",
    AUD = "AUD"
}
export declare enum IGlobalLanguages {
    English = "English",
    Spanish = "Spanish",
    French = "French",
    Russian = "Russian"
}
export declare type IGlobalSettings = IISettingsSubject & {
    __typename?: 'GlobalSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings.  */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare type IIAuth0Identity = {
    connection?: Maybe<Scalars['String']>;
    isSocial?: Maybe<Scalars['Boolean']>;
    provider?: Maybe<Scalars['String']>;
    user_id?: Maybe<Scalars['String']>;
};
/** Result from the extraction of JSON Web Token */
export declare type IIAuth0Token = {
    iss?: Maybe<Scalars['String']>;
    sub?: Maybe<Scalars['String']>;
    aud?: Maybe<Scalars['String']>;
    iat?: Maybe<Scalars['Int']>;
    exp?: Maybe<Scalars['Int']>;
    at_hash?: Maybe<Scalars['String']>;
    nonce?: Maybe<Scalars['String']>;
};
/** Auth0 User details */
export declare type IIAuth0User = {
    name: Scalars['String'];
    user_id: Scalars['String'];
    given_name?: Maybe<Scalars['String']>;
    family_name?: Maybe<Scalars['String']>;
    nickname: Scalars['String'];
    username: Scalars['String'];
    email?: Maybe<Scalars['String']>;
    email_verified?: Maybe<Scalars['Boolean']>;
    picture?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    updated_at?: Maybe<Scalars['String']>;
    phone_number?: Maybe<Scalars['String']>;
};
/** Profile based on Auth0Profile */
export declare type IIAuth0UserProfile = {
    clientID: Scalars['String'];
    gender?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    created_at: Scalars['String'];
    updated_at: Scalars['String'];
    sub?: Maybe<Scalars['String']>;
    user_metadata?: Maybe<IIUserMetadata>;
    app_metadata?: Maybe<Scalars['AnyObject']>;
};
export declare type IIBaseRepo = {
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
};
/** Address City Interface */
export declare type IICity = {
    id: Scalars['ID'];
    name: Scalars['String'];
    state: IITerritorialState;
    location?: Maybe<IGeoLocation>;
    createdAt: Scalars['Date'];
    updatedAt?: Maybe<Scalars['Date']>;
};
export declare type IIConfigurationChangeEvent = {
    __typename?: 'IConfigurationChangeEvent';
    source?: Maybe<IConfigurationTarget>;
    affectedKeys?: Maybe<Array<Maybe<Scalars['String']>>>;
    sourceConfig?: Maybe<Scalars['AnyObject']>;
    changedConfiguration?: Maybe<IConfiguration>;
    changedConfigurationByResource?: Maybe<IOrganizationResourceConfiguration>;
};
export declare type IIConfigurationModel = {
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IIConfigurationService = {
    updateValue?: Maybe<Scalars['Boolean']>;
};
export declare type IIConfigurationServiceupdateValueArgs = {
    key: Scalars['String'];
    value: Scalars['AnyObject'];
    overrides: IConfigurationOverrides_Input;
    target?: Maybe<IConfigurationTarget>;
    donotNotifyError?: Maybe<Scalars['Boolean']>;
};
export declare type IICountry = {
    id: Scalars['ID'];
    name: Scalars['String'];
    phone_code: Scalars['String'];
    location?: Maybe<IGeoLocation>;
    createdAt: Scalars['Date'];
    updatedAt?: Maybe<Scalars['Date']>;
};
export declare type IIFileRef = {
    id: Scalars['ID'];
};
export declare type IImageDimensionsConfigInput = {
    imageWidth?: Maybe<Scalars['Int']>;
    imageHeight?: Maybe<Scalars['Int']>;
    previewImageWidth?: Maybe<Scalars['Int']>;
    previewImageHeight?: Maybe<Scalars['Int']>;
    thumbnailImageWidth?: Maybe<Scalars['Int']>;
    thumbnailImageHeight?: Maybe<Scalars['Int']>;
};
export declare type IIntegraitonConfigurationId = {
    __typename?: 'IntegraitonConfigurationId';
    id?: Maybe<Scalars['String']>;
};
export declare type IIntegrationConfiguration = {
    __typename?: 'IntegrationConfiguration';
    id?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['ID']>;
    integrationName?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    integrationInfo?: Maybe<Scalars['JSON']>;
};
export declare type IIntegrationConfigurationCreateOrUpdateInput = {
    id?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    integrationName?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['String']>;
    integrationInfo?: Maybe<Scalars['JSON']>;
    userId?: Maybe<Scalars['ID']>;
};
export declare type IIntegrationConfigurationFilterInput = {
    id?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    integrationName?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['ID']>;
};
export declare type IIntegrationConfigurationInput = {
    name?: Maybe<Scalars['String']>;
    integrationName?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['String']>;
    integrationInfo?: Maybe<Scalars['JSON']>;
    userId?: Maybe<Scalars['ID']>;
};
export declare type IInviteMember = {
    __typename?: 'InviteMember';
    id?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    teamId?: Maybe<Scalars['String']>;
    teamName?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    status?: Maybe<IInviteStatus>;
};
export declare enum IInviteStatus {
    PENDING = "PENDING",
    ACCEPTED = "ACCEPTED",
    DECLINED = "DECLINED"
}
export declare type IInvoiceCreateRequest = {
    comment?: Maybe<Scalars['String']>;
    currency?: Maybe<Scalars['String']>;
    discount?: Maybe<Scalars['Float']>;
    from?: Maybe<IMemberInvoice_Input>;
    invoiceDate?: Maybe<Scalars['String']>;
    terms?: Maybe<Scalars['String']>;
    dueDate?: Maybe<Scalars['String']>;
    invoiceNumber?: Maybe<Scalars['String']>;
    orderNumber?: Maybe<Scalars['String']>;
    invoiceVendor?: Maybe<IMemberInvoice_Input>;
    logo?: Maybe<Scalars['String']>;
    paymentStatus?: Maybe<Scalars['Boolean']>;
    projects?: Maybe<Array<Maybe<IProjectInvoice_Input>>>;
    subTotal?: Maybe<Scalars['Float']>;
    tax?: Maybe<Scalars['Float']>;
    subject?: Maybe<Scalars['String']>;
    conditions?: Maybe<Scalars['String']>;
    timezoneOffset?: Maybe<Scalars['Int']>;
    to?: Maybe<ICustomerInvoice_Input>;
    total?: Maybe<Scalars['Float']>;
};
export declare type IInvoiceMailRequest = {
    template: ITemplate;
    to: Scalars['String'];
    from: Scalars['String'];
    cc?: Maybe<Scalars['String']>;
    bcc?: Maybe<Scalars['String']>;
    attachments?: Maybe<Array<Maybe<Scalars['AnyObject']>>>;
    subject?: Maybe<Scalars['String']>;
};
export declare type IInvoiceType = {
    __typename?: 'InvoiceType';
    id?: Maybe<Scalars['ID']>;
    comment?: Maybe<Scalars['String']>;
    currency?: Maybe<Scalars['String']>;
    discount?: Maybe<Scalars['Float']>;
    from?: Maybe<IMemberInvoice>;
    invoiceDate?: Maybe<Scalars['String']>;
    terms?: Maybe<Scalars['String']>;
    dueDate?: Maybe<Scalars['String']>;
    invoiceNumber?: Maybe<Scalars['String']>;
    orderNumber?: Maybe<Scalars['String']>;
    invoiceVendor?: Maybe<IMemberInvoice>;
    logo?: Maybe<Scalars['String']>;
    overdue?: Maybe<Scalars['Boolean']>;
    paymentStatus?: Maybe<Scalars['Boolean']>;
    projects?: Maybe<Array<Maybe<IProjectInvoice>>>;
    sendingStatus?: Maybe<Scalars['Boolean']>;
    status?: Maybe<Scalars['String']>;
    subTotal?: Maybe<Scalars['Float']>;
    tax?: Maybe<Scalars['Float']>;
    subject?: Maybe<Scalars['String']>;
    conditions?: Maybe<Scalars['String']>;
    timezoneOffset?: Maybe<Scalars['Int']>;
    to?: Maybe<ICustomerInvoice>;
    total?: Maybe<Scalars['Float']>;
    orgName?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
};
export declare type IInvoiceUpdateRequest = {
    comment?: Maybe<Scalars['String']>;
    currency?: Maybe<Scalars['String']>;
    discount?: Maybe<Scalars['Float']>;
    from?: Maybe<IMemberInvoice_Input>;
    invoiceDate?: Maybe<Scalars['String']>;
    terms?: Maybe<Scalars['String']>;
    dueDate?: Maybe<Scalars['String']>;
    invoiceNumber?: Maybe<Scalars['String']>;
    orderNumber?: Maybe<Scalars['String']>;
    invoiceVendor?: Maybe<IMemberInvoice_Input>;
    logo?: Maybe<Scalars['String']>;
    paymentStatus?: Maybe<Scalars['Boolean']>;
    projects?: Maybe<Array<Maybe<IProjectInvoice_Input>>>;
    subTotal?: Maybe<Scalars['Float']>;
    tax?: Maybe<Scalars['Float']>;
    subject?: Maybe<Scalars['String']>;
    conditions?: Maybe<Scalars['String']>;
    timezoneOffset?: Maybe<Scalars['Int']>;
    to?: Maybe<ICustomerInvoice_Input>;
    total?: Maybe<Scalars['Float']>;
};
export declare type IIOnBoardingParams = {
    org?: Maybe<IOrgType>;
    team?: Maybe<ITeamType>;
};
/**  Organization Template to be used  */
export declare type IIOrgUser = {
    role?: Maybe<IApplicationRoles>;
    isSelf: Scalars['Boolean'];
    orgName: Scalars['String'];
};
export declare type IIResourceData = {
    /** The associated URI for this resource. */
    uri?: Maybe<Scalars['URI']>;
    /** The name of this resource. Defaults to the basename its [uri-path](#Uri.path) */
    name?: Maybe<Scalars['String']>;
    /** The ordinal number of this resource. */
    index?: Maybe<Scalars['Int']>;
};
export declare type IIResourceUserRole = {
    role?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    isSelf?: Maybe<Scalars['Boolean']>;
    orgName?: Maybe<Scalars['String']>;
};
/**
 * ISettingsSubject is something that can have settings: a site ("global settings", which is different from "site
 * configuration"), an organization, or a user.
 */
export declare type IISettingsSubject = {
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings.  */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
/** Territorial State */
export declare type IITerritorialState = {
    id: Scalars['ID'];
    name: Scalars['String'];
    country: IICountry;
    location?: Maybe<IGeoLocation>;
    createdAt: Scalars['Date'];
    updatedAt?: Maybe<Scalars['Date']>;
};
export declare type IIUser = {
    id: Scalars['ID'];
    username?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
};
export declare type IIUserMetadata = {
    last_name?: Maybe<Scalars['String']>;
    first_name?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    phone_number?: Maybe<Scalars['String']>;
    work_email?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    company_name?: Maybe<Scalars['String']>;
    dob?: Maybe<Scalars['Date']>;
    zip_code?: Maybe<Scalars['Int']>;
};
/**
 * A segment of a key path that locates a nested JSON value in a root JSON value. Exactly one field in each
 * KeyPathSegment must be non-null.
 *
 * For example, in {"a": [0, {"b": 3}]}, the value 3 is located at the key path ["a", 1, "b"].
 */
export declare type IKeyPathSegment = {
    /**  The name of the property in the object at this location to descend into.  */
    property?: Maybe<Scalars['String']>;
    /**  The index of the array at this location to descend into.  */
    index?: Maybe<Scalars['Int']>;
};
export declare type ILoginError = {
    __typename?: 'LoginError';
    timeStamp?: Maybe<Scalars['DateTime']>;
    error?: Maybe<Scalars['AnyObject']>;
};
export declare type IMachineConfiguration = IIConfigurationModel & {
    __typename?: 'MachineConfiguration';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /** The URL to the machine's settings. */
    resource: Scalars['URI'];
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IMachineSettings = IISettingsSubject & {
    __typename?: 'MachineSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings. */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare enum IMailTemplateId {
    MessageNotificationServiceId = "MessageNotificationServiceId",
    dummy = "dummy"
}
export declare type IMemberInvoice = {
    __typename?: 'MemberInvoice';
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    companyName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<IClientPhone>;
    address?: Maybe<IAddressType>;
};
export declare type IMemberInvoice_Input = {
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    companyName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    phone?: Maybe<IClientPhone_Input>;
    address?: Maybe<IAddressType_Input>;
};
export declare type IMemorySettings = IISettingsSubject & {
    __typename?: 'MemorySettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings. */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare type IMessageIdentifier = {
    channelId: Scalars['String'];
    messageId: Scalars['String'];
};
export declare type IMessageInput = {
    content: Scalars['String'];
    userRef?: Maybe<Array<Maybe<Scalars['String']>>>;
    channelRef?: Maybe<Array<Maybe<Scalars['String']>>>;
    files?: Maybe<Array<Scalars['ID']>>;
};
export declare type IMessages = {
    __typename?: 'Messages';
    totalCount?: Maybe<Scalars['Int']>;
    data?: Maybe<Array<Maybe<IPost>>>;
};
export declare enum IMessengerNotificationServiceCommands {
    sendNotificationOfUnreadMessages = "sendNotificationOfUnreadMessages"
}
export declare type IMessengerUser = IIUser & {
    __typename?: 'MessengerUser';
    id: Scalars['ID'];
    username?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    status?: Maybe<IMessengerUserStatus>;
    avatar?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    lastLogin?: Maybe<Scalars['String']>;
    channels?: Maybe<Array<Maybe<IChannel>>>;
    directMessages?: Maybe<Array<Maybe<IChannel>>>;
};
export declare enum IMessengerUserStatus {
    ONLINE = "ONLINE",
    AWAY = "AWAY",
    BUSY = "BUSY",
    INVISIBLE = "INVISIBLE"
}
export declare enum IMoleculerCronServiceName {
    MessengerCronJob = "MessengerCronJob",
    dummy = "dummy"
}
/**  All Moleculer Topic names are extended from this. */
export declare enum IMoleculerServiceName {
    MessengerNotificationService = "MessengerNotificationService",
    SmsService = "SmsService",
    dummy = "dummy"
}
export declare enum IMoleculerTopics {
    BaseService = "BaseService",
    ChannelService = "ChannelService",
    PostService = "PostService",
    PostThreadService = "PostThreadService",
    ReactionService = "ReactionService",
    MessengerNotificationService = "MessengerNotificationService"
}
export declare type IMutation = {
    __typename?: 'Mutation';
    acceptOrganizationInvitation?: Maybe<Scalars['Boolean']>;
    accountOnBoarding?: Maybe<Scalars['Boolean']>;
    addClient?: Maybe<Scalars['Boolean']>;
    addContributionRole?: Maybe<Scalars['Boolean']>;
    addMemberToChannel?: Maybe<IChannel>;
    addOrgProject?: Maybe<Scalars['Boolean']>;
    addReactionToMessage?: Maybe<IReaction>;
    addTeamMembers?: Maybe<Scalars['Boolean']>;
    attachUploadedFileToMessage: IFileInfo;
    changeMemberRole?: Maybe<Scalars['Boolean']>;
    changeOrgMemberRole?: Maybe<Scalars['Boolean']>;
    createChannel?: Maybe<IChannel>;
    createDirectChannel?: Maybe<IChannel>;
    createIntegrationConfiguration?: Maybe<IIntegraitonConfigurationId>;
    createInvoice?: Maybe<Scalars['Boolean']>;
    /** Attach Post File */
    createMessageFileUploadLink: Scalars['String'];
    createOrUpdateIntegrationConfiguration?: Maybe<IIntegraitonConfigurationId>;
    createOrganization?: Maybe<IOrganization>;
    createTask?: Maybe<Scalars['Boolean']>;
    createTeam?: Maybe<IAccountTeam>;
    declineOrganizationInvitation?: Maybe<Scalars['Boolean']>;
    deleteChannel?: Maybe<Scalars['Boolean']>;
    deleteIntegrationConfiguration?: Maybe<Scalars['Boolean']>;
    deleteMessage?: Maybe<Scalars['Boolean']>;
    /** Detach Post File */
    deleteMessageFile: Scalars['Boolean'];
    deleteUserAccount?: Maybe<Scalars['Boolean']>;
    deleteUserAuthorizedDevice?: Maybe<Scalars['Boolean']>;
    deliverMessage: Scalars['Boolean'];
    dummy?: Maybe<Scalars['Int']>;
    editMessage?: Maybe<IPost>;
    hideChannel?: Maybe<Scalars['Boolean']>;
    initiateConfigurationValue?: Maybe<Scalars['Boolean']>;
    initiatePolicyValue?: Maybe<Scalars['Boolean']>;
    leaveChannel?: Maybe<Scalars['Boolean']>;
    readMessage: Scalars['Boolean'];
    registerAccountUser?: Maybe<IUserAccount>;
    registerUserInAuth0?: Maybe<IUserProfile>;
    removeInvoice?: Maybe<Scalars['Boolean']>;
    removeOrgClient?: Maybe<Scalars['Boolean']>;
    removeOrgMember?: Maybe<Scalars['Boolean']>;
    removeOrganization?: Maybe<Scalars['Boolean']>;
    removeReactionFromMessage?: Maybe<Scalars['Boolean']>;
    removeTask?: Maybe<Scalars['Boolean']>;
    removeTeam?: Maybe<Scalars['Boolean']>;
    removeTeamMember?: Maybe<Scalars['Boolean']>;
    resendOrganizationInvitation?: Maybe<Scalars['Boolean']>;
    resendUserEmailVerificationEmail?: Maybe<Scalars['Boolean']>;
    sendInvoiceMail?: Maybe<Scalars['Boolean']>;
    sendMessage?: Maybe<IPost>;
    sendNotificationOfUnreadMessages: Scalars['Boolean'];
    sendOrganizationInvitation?: Maybe<Scalars['Boolean']>;
    sendSms: Scalars['Boolean'];
    setSettingsValueByResource?: Maybe<Scalars['Boolean']>;
    /**  Triggers onUserLoggedIn events  */
    updateAuth0UserPassword?: Maybe<Scalars['Boolean']>;
    updateConfigurationPolicyValue?: Maybe<Scalars['Boolean']>;
    updateConfigurationPolicyValueByUri?: Maybe<Scalars['Boolean']>;
    updateConfigurationValue?: Maybe<Scalars['Boolean']>;
    updateConfigurationValueByUri?: Maybe<Scalars['Boolean']>;
    updateInvoice?: Maybe<Scalars['Boolean']>;
    updateOrgClient?: Maybe<IClient>;
    updateOrgMemberTeams?: Maybe<Scalars['Boolean']>;
    updateOrgProject?: Maybe<Scalars['Boolean']>;
    updateOrganization?: Maybe<IOrganization>;
    updateOrganizationContextAddResources?: Maybe<Array<Maybe<IResourceData>>>;
    updateOrganizationContextRemoveResources?: Maybe<Array<Maybe<IResourceData>>>;
    updateOrganizationContextUpdateResources?: Maybe<Array<Maybe<IResourceData>>>;
    updateProjectStatus?: Maybe<Scalars['Boolean']>;
    updateReactionToMessage?: Maybe<IReaction>;
    updateRoleValue?: Maybe<Scalars['Boolean']>;
    updateTask?: Maybe<Scalars['Boolean']>;
    updateUserAccount?: Maybe<Scalars['Boolean']>;
    upsertProjectThroughIntegration?: Maybe<IProjects>;
    verifyUserEmailVerificationToken?: Maybe<Scalars['Boolean']>;
    viewChannel: Scalars['Boolean'];
};
export declare type IMutationacceptOrganizationInvitationArgs = {
    id: Scalars['ID'];
    notification?: Maybe<IOrganizationNotificationValues>;
};
export declare type IMutationaccountOnBoardingArgs = {
    input?: Maybe<IIOnBoardingParams>;
};
export declare type IMutationaddClientArgs = {
    client: IClientAddRequest;
};
export declare type IMutationaddContributionRoleArgs = {
    name: Scalars['String'];
    description?: Maybe<Scalars['String']>;
};
export declare type IMutationaddMemberToChannelArgs = {
    channelId: Scalars['String'];
    memberId: Scalars['String'];
};
export declare type IMutationaddOrgProjectArgs = {
    project: IProjectAddRequest;
};
export declare type IMutationaddReactionToMessageArgs = {
    reaction?: Maybe<IReactionInput>;
};
export declare type IMutationaddTeamMembersArgs = {
    orgName: Scalars['String'];
    teamName: Scalars['String'];
    memberIds: Array<Maybe<Scalars['String']>>;
};
export declare type IMutationattachUploadedFileToMessageArgs = {
    postId: Scalars['ID'];
    file: IUploadedFileInput;
};
export declare type IMutationchangeMemberRoleArgs = {
    orgName: Scalars['String'];
    teamName: Scalars['String'];
    memberId: Scalars['String'];
    role: Scalars['String'];
};
export declare type IMutationchangeOrgMemberRoleArgs = {
    userId: Scalars['String'];
    role: IApplicationRoles;
};
export declare type IMutationcreateChannelArgs = {
    name: Scalars['String'];
    description: Scalars['String'];
};
export declare type IMutationcreateDirectChannelArgs = {
    receiver: Array<Maybe<Scalars['ID']>>;
    displayName: Scalars['String'];
};
export declare type IMutationcreateIntegrationConfigurationArgs = {
    data?: Maybe<IIntegrationConfigurationInput>;
};
export declare type IMutationcreateInvoiceArgs = {
    invoice: IInvoiceCreateRequest;
};
export declare type IMutationcreateMessageFileUploadLinkArgs = {
    postId: Scalars['ID'];
    filename: Scalars['String'];
};
export declare type IMutationcreateOrUpdateIntegrationConfigurationArgs = {
    data?: Maybe<IIntegrationConfigurationCreateOrUpdateInput>;
};
export declare type IMutationcreateOrganizationArgs = {
    organization: IOrganizationCreateRequest;
};
export declare type IMutationcreateTaskArgs = {
    request?: Maybe<ITaskRequest>;
};
export declare type IMutationcreateTeamArgs = {
    request: ITeamCreationRequest;
};
export declare type IMutationdeclineOrganizationInvitationArgs = {
    id: Scalars['ID'];
};
export declare type IMutationdeleteChannelArgs = {
    id: Scalars['ID'];
};
export declare type IMutationdeleteIntegrationConfigurationArgs = {
    id: Scalars['String'];
};
export declare type IMutationdeleteMessageArgs = {
    messageId: IMessageIdentifier;
};
export declare type IMutationdeleteMessageFileArgs = {
    url: Scalars['String'];
};
export declare type IMutationdeleteUserAuthorizedDeviceArgs = {
    deviceId: Scalars['String'];
};
export declare type IMutationdeliverMessageArgs = {
    messageId: IMessageIdentifier;
};
export declare type IMutationeditMessageArgs = {
    messageId: IMessageIdentifier;
    messageInput: IMessageInput;
};
export declare type IMutationhideChannelArgs = {
    id: Scalars['ID'];
};
export declare type IMutationinitiateConfigurationValueArgs = {
    resource?: Maybe<Scalars['URI']>;
};
export declare type IMutationinitiatePolicyValueArgs = {
    resource?: Maybe<Scalars['URI']>;
};
export declare type IMutationleaveChannelArgs = {
    id: Scalars['ID'];
};
export declare type IMutationreadMessageArgs = {
    messageId: IMessageIdentifier;
};
export declare type IMutationregisterAccountUserArgs = {
    userInfo?: Maybe<IUserAuth0UpdateFields>;
};
export declare type IMutationregisterUserInAuth0Args = {
    email: Scalars['String'];
    password: Scalars['String'];
};
export declare type IMutationremoveInvoiceArgs = {
    id?: Maybe<Scalars['String']>;
};
export declare type IMutationremoveOrgClientArgs = {
    clientId: Scalars['String'];
};
export declare type IMutationremoveOrgMemberArgs = {
    memberId: Scalars['String'];
};
export declare type IMutationremoveOrganizationArgs = {
    organization: IOrganizationRemoveRequest;
};
export declare type IMutationremoveReactionFromMessageArgs = {
    id: Scalars['ID'];
};
export declare type IMutationremoveTaskArgs = {
    id: Scalars['String'];
};
export declare type IMutationremoveTeamArgs = {
    teamId: Scalars['String'];
};
export declare type IMutationremoveTeamMemberArgs = {
    orgName: Scalars['String'];
    teamName: Scalars['String'];
    memberId: Scalars['String'];
};
export declare type IMutationresendOrganizationInvitationArgs = {
    id: Scalars['ID'];
};
export declare type IMutationsendInvoiceMailArgs = {
    request: IInvoiceMailRequest;
};
export declare type IMutationsendMessageArgs = {
    channelId: Scalars['String'];
    messageInput: IMessageInput;
};
export declare type IMutationsendNotificationOfUnreadMessagesArgs = {
    unit: Scalars['String'];
    value: Scalars['Int'];
};
export declare type IMutationsendOrganizationInvitationArgs = {
    request?: Maybe<IOrganizationInvitationRequest>;
};
export declare type IMutationsendSmsArgs = {
    sms?: Maybe<ISendSmsInput>;
};
export declare type IMutationsetSettingsValueByResourceArgs = {
    uri?: Maybe<Scalars['URI']>;
    key?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
};
export declare type IMutationupdateAuth0UserPasswordArgs = {
    userId?: Maybe<Scalars['String']>;
    password?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    oldPassword?: Maybe<Scalars['String']>;
};
export declare type IMutationupdateConfigurationPolicyValueArgs = {
    key: Scalars['String'];
    value: Scalars['AnyObject'];
    overrides?: Maybe<IConfigurationOverrides_Input>;
    target?: Maybe<Scalars['Int']>;
    donotNotifyError?: Maybe<Scalars['Boolean']>;
};
export declare type IMutationupdateConfigurationPolicyValueByUriArgs = {
    resource?: Maybe<Scalars['URI']>;
    key: Scalars['String'];
    value: Scalars['AnyObject'];
    overrides?: Maybe<IConfigurationOverrides_Input>;
    target?: Maybe<Scalars['Int']>;
    donotNotifyError?: Maybe<Scalars['Boolean']>;
};
export declare type IMutationupdateConfigurationValueArgs = {
    key: Scalars['String'];
    value: Scalars['AnyObject'];
    overrides?: Maybe<IConfigurationOverrides_Input>;
    target?: Maybe<Scalars['Int']>;
    donotNotifyError?: Maybe<Scalars['Boolean']>;
};
export declare type IMutationupdateConfigurationValueByUriArgs = {
    resource?: Maybe<Scalars['URI']>;
    key: Scalars['String'];
    value: Scalars['AnyObject'];
    overrides?: Maybe<IConfigurationOverrides_Input>;
    target?: Maybe<Scalars['Int']>;
    donotNotifyError?: Maybe<Scalars['Boolean']>;
};
export declare type IMutationupdateInvoiceArgs = {
    id?: Maybe<Scalars['String']>;
    invoice?: Maybe<IInvoiceUpdateRequest>;
};
export declare type IMutationupdateOrgClientArgs = {
    updateRequest?: Maybe<IClientUpdateRequest>;
};
export declare type IMutationupdateOrgMemberTeamsArgs = {
    userId: Scalars['String'];
    orgName: Scalars['String'];
    addToTeams?: Maybe<Array<Maybe<Scalars['String']>>>;
    removeFromTeams?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type IMutationupdateOrgProjectArgs = {
    where: IProjectWhereInput;
    project?: Maybe<IUpdateProject_Input>;
};
export declare type IMutationupdateOrganizationArgs = {
    organization: IOrganizationUpdateRequest;
};
export declare type IMutationupdateOrganizationContextAddResourcesArgs = {
    orgId?: Maybe<Scalars['String']>;
    resourcesToAdd: Array<Maybe<IResourceCreationData_Input>>;
    index?: Maybe<Scalars['Int']>;
};
export declare type IMutationupdateOrganizationContextRemoveResourcesArgs = {
    resourcesToRemove: Array<Scalars['URI']>;
};
export declare type IMutationupdateOrganizationContextUpdateResourcesArgs = {
    resourcesToAdd: Array<Maybe<IResourceCreationData_Input>>;
    resourcesToRemove: Array<Maybe<Scalars['URI']>>;
    index?: Maybe<Scalars['Int']>;
};
export declare type IMutationupdateProjectStatusArgs = {
    id: Scalars['String'];
    status?: Maybe<Scalars['String']>;
};
export declare type IMutationupdateReactionToMessageArgs = {
    id: Scalars['ID'];
    reaction: Scalars['String'];
};
export declare type IMutationupdateRoleValueArgs = {
    key: Scalars['String'];
    value: Scalars['AnyObject'];
    overrides?: Maybe<IConfigurationOverrides_Input>;
    target?: Maybe<Scalars['Int']>;
    donotNotifyError?: Maybe<Scalars['Boolean']>;
};
export declare type IMutationupdateTaskArgs = {
    id: Scalars['String'];
    request?: Maybe<ITaskRequest>;
};
export declare type IMutationupdateUserAccountArgs = {
    userInfo?: Maybe<IUserAuth0UpdateFields>;
};
export declare type IMutationupsertProjectThroughIntegrationArgs = {
    where: IProjectWhereInput;
    project?: Maybe<IUpdateProject_Input>;
};
export declare type IMutationverifyUserEmailVerificationTokenArgs = {
    token?: Maybe<Scalars['String']>;
};
export declare type IMutationviewChannelArgs = {
    id: Scalars['ID'];
};
export declare type IName_Input = {
    salutation?: Maybe<Scalars['String']>;
    firstName?: Maybe<Scalars['String']>;
    lastName?: Maybe<Scalars['String']>;
};
export declare type INameType = {
    __typename?: 'NameType';
    salutation?: Maybe<Scalars['String']>;
    firstName?: Maybe<Scalars['String']>;
    lastName?: Maybe<Scalars['String']>;
};
export declare type INode = {
    id: Scalars['ID'];
};
/**
 * OrganizationInvitationRole: The possible organization invitation roles.
 *
 * @property
 * ADMIN: The user is invited to be an admin of the organization
 * BILLING_MANAGER: The user is invited to be a billing manager of the organization.
 * DIRECT_MEMBER: The user is invited to be a direct member of the organization.
 * REINSTATE: The user's previous role will be reinstated.
 */
export declare enum IOrgainizationInvitationRole {
    ADMIN = "ADMIN",
    REINSTATE = "REINSTATE",
    DIRECT_MEMBER = "DIRECT_MEMBER",
    BILLING_MANAGER = "BILLING_MANAGER"
}
/**
 * Organization: A groups of people can collaborate accross many
 * workspaces/projects at the same time in organization accounts.
 *
 * @property
 * name: The name of the organization
 * @property
 * namespace: The parent namespace which will be used in workspaces
 * @property
 * picture: The org avatar
 * @property
 * isBillingLeader: true if the viewer is the billing leader for the org
 * @property
 * mainBilingLeaderId: The billing leader of the organization (or the first, if more than 1)
 * @property
 * billingEmail: The billing email for the organization.
 * @property
 * periodStart: The datetime the curren billing cycle starts.
 * @property
 * periodStop: The datetime the current billing cycle ends.
 * @property
 * stripeId: The customerId from stripe.
 * @property
 * stripeSubscriptionId: The subscriptionId from stripe.
 */
export declare type IOrganization = {
    __typename?: 'Organization';
    id?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    stripeId?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
    orgUserCount?: Maybe<Scalars['Int']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    orgMembers?: Maybe<Array<Maybe<IOrgUser>>>;
    periodStart?: Maybe<Scalars['DateTime']>;
    periodStop?: Maybe<Scalars['DateTime']>;
    billingLeaders?: Maybe<Array<Maybe<Scalars['String']>>>;
    billingEmail?: Maybe<Scalars['String']>;
    isBillingLeader?: Maybe<Scalars['Boolean']>;
    mainBilingLeaderId?: Maybe<Scalars['String']>;
    stripeSubscriptionId?: Maybe<Scalars['String']>;
    invitations?: Maybe<Array<Maybe<IOrganizationInvitation>>>;
};
export declare type IOrganization_Input = {
    id?: Maybe<Scalars['ID']>;
    name: Scalars['String'];
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    stripeId?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
    orgUserCount?: Maybe<Scalars['Int']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    orgMembers?: Maybe<Array<Maybe<IOrgUser_Input>>>;
    periodStart?: Maybe<Scalars['DateTime']>;
    periodStop?: Maybe<Scalars['DateTime']>;
    billingLeaders?: Maybe<Array<Maybe<Scalars['String']>>>;
    billingEmail?: Maybe<Scalars['String']>;
    isBillingLeader?: Maybe<Scalars['Boolean']>;
    mainBilingLeaderId?: Maybe<Scalars['String']>;
    stripeSubscriptionId?: Maybe<Scalars['String']>;
    invitations?: Maybe<Array<Maybe<IOrganizationInvitation_Input>>>;
    status?: Maybe<Scalars['String']>;
};
export declare type IOrganizationConfiguration = IIConfigurationModel & {
    __typename?: 'OrganizationConfiguration';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    resource: Scalars['URI'];
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IOrganizationConfigValue_Input = {
    section?: Maybe<Scalars['String']>;
    overrides?: Maybe<IConfigurationOverrides_Input>;
};
/** Subscription event for context */
export declare enum IOrganizationContextPubSubEvents {
    OrganizationContextUpdated = "OrganizationContextUpdated",
    OrganizationPolicyUpdated = "OrganizationPolicyUpdated",
    OrganizationConfigurationUpdated = "OrganizationConfigurationUpdated",
    OrganizationPermissionUpdated = "OrganizationPermissionUpdated"
}
export declare type IOrganizationCreateRequest = {
    name?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    namespace?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    orgMembers?: Maybe<Array<Maybe<IOrgUser_Input>>>;
    billingLeaders?: Maybe<Array<Maybe<Scalars['String']>>>;
    mainBillingLeaderId?: Maybe<Scalars['String']>;
    periodStart?: Maybe<Scalars['DateTime']>;
    periodStop?: Maybe<Scalars['DateTime']>;
    stripeId?: Maybe<Scalars['String']>;
    stripeSubscriptionId?: Maybe<Scalars['String']>;
    invitations?: Maybe<Array<Maybe<IOrganizationInvitation_Input>>>;
};
export declare type IOrganizationData = {
    __typename?: 'OrganizationData';
    /** The unique identifier of the workspace. */
    id: Scalars['String'];
    /** Resources in the organization. */
    resources: Array<Maybe<IResourceData>>;
    /** The location of the organization configuration */
    configuration?: Maybe<Scalars['URI']>;
    /** Organization name */
    name?: Maybe<Scalars['String']>;
};
export declare type IOrganizationIdentifier = {
    __typename?: 'OrganizationIdentifier';
    id?: Maybe<Scalars['String']>;
    configPath?: Maybe<Scalars['URI']>;
};
export declare type IOrganizationInvitation = {
    __typename?: 'OrganizationInvitation';
    id: Scalars['ID'];
    email?: Maybe<Scalars['String']>;
    teamId?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    active?: Maybe<Scalars['Boolean']>;
    fullName?: Maybe<Scalars['String']>;
    inviteCount?: Maybe<Scalars['Int']>;
    invitedBy?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    acceptedAt?: Maybe<Scalars['DateTime']>;
    tokenExpiration?: Maybe<Scalars['DateTime']>;
};
export declare type IOrganizationInvitation_Input = {
    email?: Maybe<Scalars['String']>;
    teamId?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    active?: Maybe<Scalars['Boolean']>;
    fullName?: Maybe<Scalars['String']>;
    inviteCount?: Maybe<Scalars['Int']>;
    invitedBy?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    acceptedAt?: Maybe<Scalars['DateTime']>;
    tokenExpiration?: Maybe<Scalars['DateTime']>;
};
export declare type IOrganizationInvitationDecode = {
    __typename?: 'OrganizationInvitationDecode';
    orgName?: Maybe<Scalars['String']>;
    teamName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    invitationId?: Maybe<Scalars['String']>;
    invitedBy?: Maybe<Scalars['String']>;
};
export declare type IOrganizationInvitationRequest = {
    teamId?: Maybe<Scalars['String']>;
    emails?: Maybe<Array<Maybe<Scalars['String']>>>;
    invitedBy?: Maybe<Scalars['String']>;
    orgName?: Maybe<Scalars['String']>;
    role?: Maybe<Scalars['String']>;
};
export declare type IOrganizationMember = {
    __typename?: 'OrganizationMember';
    id?: Maybe<Scalars['String']>;
    user?: Maybe<IAuthUser>;
    isBillingLeader?: Maybe<Scalars['Boolean']>;
    organization?: Maybe<IOrganization>;
};
export declare type IOrganizationNotificationValues = {
    notifyOrgManagersOnUserJoined?: Maybe<Scalars['Boolean']>;
    notifyOrgOwnerOnUserJoined?: Maybe<Scalars['Boolean']>;
};
export declare type IOrganizationPolicy = IIConfigurationModel & {
    __typename?: 'OrganizationPolicy';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IOrganizationRemoveRequest = {
    orgName?: Maybe<Scalars['String']>;
    requestedUserId?: Maybe<Scalars['String']>;
};
export declare type IOrganizationResourceConfiguration = IIConfigurationModel & {
    __typename?: 'OrganizationResourceConfiguration';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    resource: Scalars['URI'];
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IOrganizationResourceData = IIResourceData & {
    __typename?: 'OrganizationResourceData';
    /** The associated URI for this organization resource. */
    uri?: Maybe<Scalars['URI']>;
    /** The name of this organization resource. Defaults to the basename its [uri-path](#Uri.path) */
    name?: Maybe<Scalars['String']>;
    /** The ordinal number of this organization resource. */
    index?: Maybe<Scalars['Int']>;
};
export declare type IOrganizationResourceSettings = IISettingsSubject & {
    __typename?: 'OrganizationResourceSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings. */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare type IOrganizationRole = IIConfigurationModel & {
    __typename?: 'OrganizationRole';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IOrganizationSettings = IISettingsSubject & {
    __typename?: 'OrganizationSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**  The latest settings.  */
    latestSettings?: Maybe<ISettings>;
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /**  Whether the viewer can modify the subject's settings. */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this subject, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     */
    settingsCascade: ISettingsCascade;
};
export declare type IOrganizationUpdateRequest = {
    id?: Maybe<Scalars['String']>;
    requestedUserId?: Maybe<Scalars['String']>;
    payload?: Maybe<IOrganization_Input>;
};
export declare type IOrgDetailWhere = {
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
};
export declare type IOrgMember = {
    __typename?: 'OrgMember';
    _id?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    inactive?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    crossCheckEmail?: Maybe<Scalars['String']>;
    teamNames?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type IOrgType = {
    name?: Maybe<Scalars['String']>;
    settings?: Maybe<Scalars['AnyObject']>;
};
export declare type IOrgUser = IIOrgUser & {
    __typename?: 'OrgUser';
    userId: Scalars['String'];
    role?: Maybe<IApplicationRoles>;
    inactive?: Maybe<Scalars['Boolean']>;
    orgName: Scalars['String'];
    user: IOrgUserAccunt;
    isSelf: Scalars['Boolean'];
    crossCheckEmail?: Maybe<Scalars['String']>;
};
export declare type IOrgUser_Input = {
    userId?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    inactive?: Maybe<Scalars['Boolean']>;
    crossCheckEmail?: Maybe<Scalars['String']>;
};
export declare type IOrgUserAccunt = INode & {
    __typename?: 'OrgUserAccunt';
    id: Scalars['ID'];
    email?: Maybe<Scalars['String']>;
    alias?: Maybe<Array<Maybe<Scalars['String']>>>;
    username?: Maybe<Scalars['String']>;
    emailVerified?: Maybe<Scalars['Boolean']>;
};
export declare enum IOrgUserRole {
    BILLING_LEADER = "BILLING_LEADER",
    MEMBER = "MEMBER",
    ADMIN = "ADMIN",
    OWNER = "OWNER"
}
export declare type IOverrides = {
    __typename?: 'Overrides';
    contents?: Maybe<Scalars['AnyObject']>;
    identifiers?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare enum IPermissionAction {
    Create = "Create",
    Delete = "Delete",
    Edit = "Edit",
    Invite = "Invite",
    Manage = "Manage",
    View = "View"
}
export declare enum IPermissionResource {
    Members = "Members",
    Organization = "Organization",
    Permissions = "Permissions",
    Roles = "Roles",
    Settings = "Settings",
    Teams = "Teams"
}
export declare type IPermissionSubject = {
    __typename?: 'PermissionSubject';
    /**  The URL to the roles.  */
    roleURL: Scalars['URI'];
    /** The time when this was created. */
    createdAt?: Maybe<Scalars['String']>;
    /** The stringified JSON contents of the permissions. */
    permissions: Scalars['AnyObject'];
};
export declare enum IPermissionType {
    Allow = "Allow",
    Deny = "Deny",
    NotSet = "NotSet"
}
export declare type IPhoneNumber = {
    __typename?: 'PhoneNumber';
    countryCode?: Maybe<Scalars['String']>;
    phoneNumber?: Maybe<Scalars['String']>;
};
/**
 * Additional User info provided provided through UI
 * Uses underscore namingspace to support Auth0
 * IUserMetadataInput
 */
export declare type IPhoneNumberInput = {
    countryCode?: Maybe<Scalars['String']>;
    phoneNumber?: Maybe<Scalars['String']>;
};
export declare type IPolicySubject = {
    __typename?: 'PolicySubject';
    /**  The URL to the policies.  */
    policyURL: Scalars['URI'];
    /** The time when this was created. */
    createdAt?: Maybe<Scalars['String']>;
    /** The stringified JSON contents of the permissions. */
    policies: Scalars['AnyObject'];
};
export declare enum IPortalLanguage {
    English = "English",
    Hindi = "Hindi",
    Gujarati = "Gujarati",
    Spanish = "Spanish",
    Russian = "Russian"
}
export declare type IPosition = {
    __typename?: 'Position';
    line?: Maybe<Scalars['Int']>;
    character?: Maybe<Scalars['Int']>;
};
export declare type IPost = IIBaseRepo & IIFileRef & {
    __typename?: 'Post';
    id: Scalars['ID'];
    author?: Maybe<IUserAccount>;
    channel?: Maybe<IChannel>;
    rootId?: Maybe<Scalars['String']>;
    parentId?: Maybe<Scalars['String']>;
    originalId?: Maybe<Scalars['String']>;
    /**  Post sent by server e.g. User joined channel  */
    fromServer?: Maybe<Scalars['Boolean']>;
    message?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
    props?: Maybe<Scalars['AnyObject']>;
    hashTags?: Maybe<Scalars['String']>;
    filenames?: Maybe<Array<Maybe<Scalars['String']>>>;
    fields?: Maybe<Array<Maybe<Scalars['String']>>>;
    reactions?: Maybe<Array<Maybe<IReaction>>>;
    files: IFilesInfo;
    editedBy?: Maybe<IUserAccount>;
    deletedBy?: Maybe<IUserAccount>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
    propsConfiguration?: Maybe<IMachineConfiguration>;
    isRead?: Maybe<Scalars['Boolean']>;
    isDelivered?: Maybe<Scalars['Boolean']>;
};
export declare type IPostfilesArgs = {
    criteria?: Maybe<Scalars['AnyObject']>;
    limit?: Maybe<Scalars['Int']>;
    skip?: Maybe<Scalars['Int']>;
    sort?: Maybe<ISort>;
};
export declare enum IPostServiceCommands {
    attachUploadedFile = "attachUploadedFile",
    createFileUploadLink = "createFileUploadLink",
    deleteFile = "deleteFile",
    readMessage = "readMessage",
    deliverMessage = "deliverMessage"
}
export declare type IPostsWithCursor = {
    __typename?: 'PostsWithCursor';
    cursor?: Maybe<Scalars['String']>;
    channel?: Maybe<IChannel>;
    posts?: Maybe<Array<Maybe<IPost>>>;
};
export declare type IPostThread = {
    __typename?: 'PostThread';
    post?: Maybe<IPost>;
    channel?: Maybe<IChannel>;
    replyCount?: Maybe<Scalars['Int']>;
    lastReplyAt?: Maybe<Scalars['DateTime']>;
    participants?: Maybe<Array<Maybe<IUserAccount>>>;
};
export declare enum IPreDefinedRole {
    OWNER = "OWNER",
    ADMIN = "ADMIN",
    MAINTAINER = "MAINTAINER",
    MEMBER = "MEMBER",
    PROJECT_ADMIN = "PROJECT_ADMIN",
    BILLING_LEADER = "BILLING_LEADER",
    DIRECT_MEMBER = "DIRECT_MEMBER",
    VIEWER = "VIEWER",
    GUEST = "GUEST",
    CONTRIBUTORS = "CONTRIBUTORS"
}
export declare type IPreference_Account = {
    __typename?: 'Preference_Account';
    autoLoadImages?: Maybe<Scalars['Boolean']>;
    avatar?: Maybe<Scalars['String']>;
    collapseEmbeddedMeida?: Maybe<Scalars['Boolean']>;
    convertAsciiToEmoji?: Maybe<Scalars['Boolean']>;
    default?: Maybe<IPreference_Default>;
    email?: Maybe<Scalars['String']>;
    enterKeyBehaviour?: Maybe<Scalars['String']>;
    global?: Maybe<IPreference_Account_Global>;
    hideAvatars?: Maybe<Scalars['Boolean']>;
    hideRightSideBarWithClick?: Maybe<Scalars['Boolean']>;
    hideRoles?: Maybe<Scalars['Boolean']>;
    hideUserName?: Maybe<Scalars['Boolean']>;
    highlights?: Maybe<Scalars['String']>;
    language?: Maybe<Scalars['String']>;
    mergePrivateGroupsWithChannels?: Maybe<Scalars['Boolean']>;
    name?: Maybe<Scalars['String']>;
    newMessageNotificationSound?: Maybe<Scalars['String']>;
    newRoomNotificationSound?: Maybe<Scalars['String']>;
    notification?: Maybe<IPreference_Notification>;
    notificationDuration?: Maybe<Scalars['Float']>;
    offlineEmailNotifications?: Maybe<Scalars['String']>;
    saveMobileBandwith?: Maybe<Scalars['Boolean']>;
    unreadRoomsMode?: Maybe<Scalars['Boolean']>;
    unreadTrayIconAlert?: Maybe<Scalars['Boolean']>;
    useEmojis?: Maybe<Scalars['Boolean']>;
    viewMode?: Maybe<Scalars['String']>;
};
export declare type IPreference_Account_Global = {
    __typename?: 'Preference_Account_Global';
    notification?: Maybe<IPreference_Account_Global_Notification>;
};
export declare type IPreference_Account_Global_Notification = {
    __typename?: 'Preference_Account_Global_Notification';
    offlineMessages?: Maybe<IPreference_Notifications_Settings>;
};
export declare type IPreference_Default = {
    __typename?: 'Preference_Default';
    organization?: Maybe<Scalars['String']>;
};
export declare type IPreference_Global = {
    __typename?: 'Preference_Global';
    user?: Maybe<IPreference_Global_User>;
};
export declare type IPreference_Global_User = {
    __typename?: 'Preference_Global_User';
    preferredLanguage?: Maybe<IGlobalLanguages>;
    preferredCurrency?: Maybe<IGlobalCurrencies>;
    timeZone?: Maybe<Scalars['String']>;
};
export declare type IPreference_Notification = {
    __typename?: 'Preference_Notification';
    billing?: Maybe<Scalars['Boolean']>;
    primaryEmail?: Maybe<Scalars['String']>;
    onChangeAccountSettings?: Maybe<Scalars['Boolean']>;
};
export declare type IPreference_Notifications_Settings = {
    __typename?: 'Preference_Notifications_Settings';
    email?: Maybe<Scalars['Boolean']>;
    sms?: Maybe<Scalars['Boolean']>;
    browser?: Maybe<Scalars['Boolean']>;
};
export declare type IPreference_Organization = {
    __typename?: 'Preference_Organization';
    teams?: Maybe<IPreference_Teams>;
    project?: Maybe<IPreference_Project>;
};
export declare type IPreference_Project = {
    __typename?: 'Preference_Project';
    visibility?: Maybe<Scalars['String']>;
    tags?: Maybe<Scalars['String']>;
};
export declare type IPreference_Teams = {
    __typename?: 'Preference_Teams';
    visibility?: Maybe<IVisibility>;
};
export declare type IPreferenceItem = {
    __typename?: 'PreferenceItem';
    name?: Maybe<Scalars['String']>;
    type?: Maybe<Scalars['String']>;
    default?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    categoryType?: Maybe<Scalars['String']>;
    settings?: Maybe<Scalars['String']>;
    enum?: Maybe<Array<Maybe<Scalars['String']>>>;
    enumDescriptions?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type IPreferences = {
    __typename?: 'Preferences';
    account?: Maybe<IPreference_Account>;
    channel?: Maybe<IChannelSettings>;
    defaultSetting?: Maybe<Array<Maybe<ISettingsGroup>>>;
    dummy?: Maybe<Scalars['Int']>;
    global?: Maybe<IPreference_Global>;
    organization?: Maybe<IPreference_Organization>;
};
export declare type IPreferencesResponse = {
    __typename?: 'PreferencesResponse';
    preferences?: Maybe<Array<Maybe<IPreferencesType>>>;
};
export declare type IPreferencesType = {
    __typename?: 'PreferencesType';
    type?: Maybe<Scalars['String']>;
    data?: Maybe<Array<Maybe<IContributionSettings>>>;
};
export declare type IProject_Input = {
    id?: Maybe<Scalars['String']>;
    _id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    path?: Maybe<Scalars['String']>;
    source?: Maybe<IProjectSource_Input>;
    problems?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type IProject_Output = {
    __typename?: 'Project_Output';
    id?: Maybe<Scalars['String']>;
    name: Scalars['String'];
    clientId?: Maybe<Scalars['String']>;
    teams?: Maybe<Array<Maybe<Scalars['String']>>>;
    status?: Maybe<Scalars['String']>;
    orgName?: Maybe<Scalars['String']>;
    integrationConfigurationId?: Maybe<Scalars['String']>;
};
export declare type IProjectAddRequest = {
    name: Scalars['String'];
    clientId?: Maybe<Scalars['String']>;
    teams?: Maybe<Array<Maybe<Scalars['String']>>>;
    orgName?: Maybe<Scalars['String']>;
    integrationConfigurationId?: Maybe<Scalars['String']>;
};
export declare type IProjectInvoice = {
    __typename?: 'ProjectInvoice';
    id?: Maybe<Scalars['ID']>;
    hours?: Maybe<Scalars['Int']>;
    projectName?: Maybe<Scalars['String']>;
    rate?: Maybe<Scalars['Float']>;
    subTotal?: Maybe<Scalars['Float']>;
};
export declare type IProjectInvoice_Input = {
    hours?: Maybe<Scalars['Int']>;
    projectName?: Maybe<Scalars['String']>;
    rate?: Maybe<Scalars['Float']>;
    subTotal?: Maybe<Scalars['Float']>;
};
export declare type IProjectParameters = {
    __typename?: 'ProjectParameters';
    branch?: Maybe<Scalars['String']>;
    httpsUrl?: Maybe<Scalars['String']>;
    isPrivate?: Maybe<Scalars['Boolean']>;
};
export declare type IProjectParameters_Input = {
    branch?: Maybe<Scalars['String']>;
    httpsUrl?: Maybe<Scalars['String']>;
    isPrivate?: Maybe<Scalars['Boolean']>;
};
/**
 * * Project can be any of the following:
 * * i. Git Repository
 * * ii. Blank, in case the source.location is empty
 * * iii. Others like upload files or zip files
 * *
 * * @property
 * * name: Project Name
 * * @property
 * * description: Project description
 * * @property
 * * path: Path of the project in workspace
 * * @property
 * * source: Source of the project, it could Git etc. If GIT we define the branch under parameters.
 * * @property
 * * problems: If the project failed with any issues, we save them to notify the user.
 */
export declare type IProjects = {
    __typename?: 'Projects';
    id?: Maybe<Scalars['ID']>;
    name: Scalars['String'];
    description?: Maybe<Scalars['String']>;
    clientId?: Maybe<Scalars['String']>;
    source?: Maybe<IProjectSource>;
    problems?: Maybe<Array<Maybe<Scalars['String']>>>;
    teams?: Maybe<Array<Maybe<Scalars['String']>>>;
    status?: Maybe<Scalars['String']>;
    type?: Maybe<IProjectType>;
    integrationConfigurationId?: Maybe<Scalars['String']>;
    /**  Predefined Project template   */
    templateId?: Maybe<Scalars['String']>;
    orgName?: Maybe<Scalars['String']>;
    updatedAt?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['String']>;
};
export declare type IProjectSource = {
    __typename?: 'ProjectSource';
    location?: Maybe<Scalars['String']>;
    type?: Maybe<IProjectSourceType>;
    parameters?: Maybe<IProjectParameters>;
    providers?: Maybe<IProjectSourceProviders>;
    language?: Maybe<Scalars['String']>;
};
export declare type IProjectSource_Input = {
    location?: Maybe<Scalars['String']>;
    type?: Maybe<IProjectSourceType>;
    parameters?: Maybe<IProjectParameters_Input>;
    providers?: Maybe<IProjectSourceProviders>;
    language?: Maybe<Scalars['String']>;
};
/** Various Source Providers for Projects Source. */
export declare enum IProjectSourceProviders {
    Github = "Github",
    Bitbucket = "Bitbucket",
    Gitlab = "Gitlab",
    Vsts = "Vsts",
    None = "None"
}
/** Various types of sources. */
export declare enum IProjectSourceType {
    Blank = "Blank",
    Zip = "Zip",
    Git = "Git"
}
export declare enum IProjectType {
    internal = "internal",
    others = "others",
    asana = "asana"
}
export declare type IProjectWhereInput = {
    id?: Maybe<Scalars['String']>;
    integrationConfigurationId?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    orgName?: Maybe<Scalars['String']>;
};
export declare type IQuery = {
    __typename?: 'Query';
    channelByName?: Maybe<IChannel>;
    channels?: Maybe<Array<Maybe<IChannel>>>;
    channelsByUser?: Maybe<Array<Maybe<IChannel>>>;
    currentUser?: Maybe<IUserAccount>;
    decodeOrganizationInvitation?: Maybe<IOrganizationInvitationDecode>;
    /** Return the permissions groups */
    defaultPermissions?: Maybe<Array<Maybe<ISettingsGroup>>>;
    /** Return the Policies groups */
    defaultPolicies?: Maybe<Array<Maybe<ISettingsGroup>>>;
    /**
     * Default Preferences
     * @deprecated not used
     */
    defaultPreferences?: Maybe<IPreferencesResponse>;
    defaultSetting?: Maybe<IContributionSettings>;
    /**
     * The default settings for the requested ConfigurationTarget
     * Note: Due to bug in graphql we using  `target: Int` argument instead of  `target:ConfigurationTarget`
     * https://github.com/apollographql/apollo-server/issues/2556
     */
    defaultViewerSettingsSubject: IDefaultSettings;
    directChannel?: Maybe<IChannel>;
    dummy?: Maybe<Scalars['Int']>;
    /**  Fetches a User from Auth0 Service  */
    fetchAuth0User?: Maybe<IUserProfile>;
    fetchUserAuthorizedDevices?: Maybe<Array<Maybe<IUserDevice>>>;
    fileInfo: IFileInfo;
    filesInfo: IFilesInfo;
    filterIntegrationConfiguration?: Maybe<Array<Maybe<IIntegrationConfiguration>>>;
    getAccounts?: Maybe<Array<Maybe<IUserAccount>>>;
    getAllCountries?: Maybe<Array<Maybe<ICountry>>>;
    getAllIntegrationConfigurations?: Maybe<Array<Maybe<IIntegrationConfiguration>>>;
    getAsanaConnectionState?: Maybe<IAsanaConnection>;
    getAsanaWorkspaceProjects?: Maybe<Array<Maybe<IAsanaProjects>>>;
    getAsanaWorkspaces?: Maybe<Array<Maybe<IAsanaWorkspaces>>>;
    getConfiguration?: Maybe<Array<Maybe<IConfiguration>>>;
    getConfigurationData?: Maybe<IConfigurationData>;
    getConfigurationPolicies?: Maybe<Array<Maybe<IConfigurationPolicy>>>;
    getContributionRoles?: Maybe<Array<Maybe<IContributionRoles>>>;
    getDefaultInvoiceNumber?: Maybe<Scalars['String']>;
    getEnvironment?: Maybe<IEnvironment>;
    getFilteredProjects?: Maybe<Array<Maybe<IProjects>>>;
    getIntegrationConfiguration?: Maybe<IIntegrationConfiguration>;
    getInvoices?: Maybe<Array<Maybe<IInvoiceType>>>;
    getManageableOrganizations?: Maybe<Array<Maybe<IOrganization>>>;
    getOrgInvitationMembers?: Maybe<Array<Maybe<IInviteMember>>>;
    getOrgTeamInvitations?: Maybe<Array<Maybe<IOrganizationInvitation>>>;
    getOrganizationClients?: Maybe<Array<Maybe<IClient>>>;
    getOrganizationConfigValue?: Maybe<Scalars['AnyObject']>;
    getOrganizationDetail?: Maybe<IOrganization>;
    getOrganizationDetailUnsecured?: Maybe<IOrganization>;
    getOrganizationInvitation?: Maybe<IOrganizationInvitation>;
    getOrganizationMembers?: Maybe<Array<Maybe<IOrgMember>>>;
    getOrganizationResourceContext?: Maybe<IOrganizationData>;
    getOrganizationTeams?: Maybe<Array<Maybe<IAccountTeam>>>;
    getPostReactions?: Maybe<Array<Maybe<IReaction>>>;
    getProjects?: Maybe<Array<Maybe<IProject_Output>>>;
    getRole?: Maybe<IAccessRole>;
    getRoles?: Maybe<Array<Maybe<IAccessRole>>>;
    getTasks?: Maybe<Array<Maybe<ITask>>>;
    getTeam?: Maybe<IAccountTeam>;
    getUserAccessRole?: Maybe<IResourceAccessRole>;
    getUserAccount?: Maybe<IUserAccount>;
    getUserAccountByAuth0Id?: Maybe<IUserAccount>;
    getUserEmailVerificationTokenDetails?: Maybe<IUserEmailVerificationTokenDetails>;
    getUserOrganizations?: Maybe<Array<Maybe<IOrganization>>>;
    getUserOrganizationsWithRole?: Maybe<Array<Maybe<IOrganization>>>;
    getUsers?: Maybe<Array<Maybe<IUserAccount>>>;
    /** Get the available roles and its descriptions */
    getViewerPermissions?: Maybe<IPermissionSubject>;
    /**
     * Get the available policies and its descriptions
     * @deprecate use viewerPolicies
     */
    getViewerPolicies?: Maybe<IPolicySubject>;
    /** Shortcut way to send merged defautPermissions with applicaiton role's permission. */
    mergedApplicationPermissions?: Maybe<Array<Maybe<IContributionSettings>>>;
    messages: IMessages;
    organizations?: Maybe<Array<Maybe<IOrganization>>>;
    team?: Maybe<IAccountTeam>;
    teams?: Maybe<Array<Maybe<IAccountTeam>>>;
    usersToChat?: Maybe<Array<Maybe<IUserAccount>>>;
    /** The policies for the viewer. */
    viewerPolicies?: Maybe<IPolicySubject>;
    /**
     * The settings for the viewer. The viewer is either an anonymous visitor (in which case viewer settings is
     * global settings) or an authenticated user (in which case viewer settings are the user's settings).
     */
    viewerSettings: IViewerSettingsSubject;
};
export declare type IQuerychannelByNameArgs = {
    name: Scalars['String'];
};
export declare type IQuerychannelsArgs = {
    filter?: Maybe<IChannelFilterInput>;
};
export declare type IQuerycurrentUserArgs = {
    auth0Id: Scalars['String'];
};
export declare type IQuerydecodeOrganizationInvitationArgs = {
    token: Scalars['String'];
};
export declare type IQuerydefaultPermissionsArgs = {
    target?: Maybe<Scalars['Int']>;
};
export declare type IQuerydefaultPoliciesArgs = {
    target?: Maybe<Scalars['Int']>;
};
export declare type IQuerydefaultViewerSettingsSubjectArgs = {
    target?: Maybe<Scalars['Int']>;
};
export declare type IQuerydirectChannelArgs = {
    id: Scalars['ID'];
};
export declare type IQueryfetchAuth0UserArgs = {
    auth0UserId: Scalars['String'];
};
export declare type IQueryfetchUserAuthorizedDevicesArgs = {
    auth0UserId: Scalars['String'];
};
export declare type IQueryfileInfoArgs = {
    id: Scalars['ID'];
};
export declare type IQueryfilesInfoArgs = {
    criteria?: Maybe<Scalars['AnyObject']>;
    limit?: Maybe<Scalars['Int']>;
    skip?: Maybe<Scalars['Int']>;
    sort?: Maybe<ISort>;
};
export declare type IQueryfilterIntegrationConfigurationArgs = {
    filter?: Maybe<IIntegrationConfigurationFilterInput>;
};
export declare type IQuerygetAccountsArgs = {
    where?: Maybe<IUserAccountWhere>;
};
export declare type IQuerygetAllCountriesArgs = {
    criteria?: Maybe<Scalars['JSON']>;
};
export declare type IQuerygetAsanaWorkspaceProjectsArgs = {
    workspaceId: Scalars['String'];
};
export declare type IQuerygetConfigurationArgs = {
    input?: Maybe<Array<Maybe<IConfigurationInput>>>;
};
export declare type IQuerygetConfigurationPoliciesArgs = {
    input?: Maybe<Array<Maybe<IConfigurationInput>>>;
};
export declare type IQuerygetFilteredProjectsArgs = {
    filter: IProjectWhereInput;
};
export declare type IQuerygetIntegrationConfigurationArgs = {
    id: Scalars['String'];
};
export declare type IQuerygetOrgTeamInvitationsArgs = {
    teamId?: Maybe<Scalars['String']>;
};
export declare type IQuerygetOrganizationConfigValueArgs = {
    value?: Maybe<IOrganizationConfigValue_Input>;
};
export declare type IQuerygetOrganizationDetailArgs = {
    where: IOrgDetailWhere;
};
export declare type IQuerygetOrganizationDetailUnsecuredArgs = {
    where: IOrgDetailWhere;
};
export declare type IQuerygetOrganizationInvitationArgs = {
    id: Scalars['ID'];
};
export declare type IQuerygetOrganizationResourceContextArgs = {
    orgId?: Maybe<Scalars['String']>;
};
export declare type IQuerygetOrganizationTeamsArgs = {
    orgName?: Maybe<Scalars['String']>;
};
export declare type IQuerygetPostReactionsArgs = {
    message: Scalars['ID'];
};
export declare type IQuerygetRoleArgs = {
    input?: Maybe<IRoleInput>;
};
export declare type IQuerygetRolesArgs = {
    input?: Maybe<Array<Maybe<IRoleInput>>>;
};
export declare type IQuerygetTasksArgs = {
    projectId?: Maybe<Scalars['String']>;
};
export declare type IQuerygetTeamArgs = {
    orgName: Scalars['String'];
    teamName: Scalars['String'];
};
export declare type IQuerygetUserAccessRoleArgs = {
    input?: Maybe<Array<Maybe<IRoleInput>>>;
};
export declare type IQuerygetUserAccountArgs = {
    userId: Scalars['String'];
};
export declare type IQuerygetUserAccountByAuth0IdArgs = {
    userAuth0Id: Scalars['String'];
};
export declare type IQuerygetUserOrganizationsArgs = {
    userId?: Maybe<Scalars['String']>;
};
export declare type IQuerygetUserOrganizationsWithRoleArgs = {
    userId?: Maybe<Scalars['String']>;
};
export declare type IQuerygetUsersArgs = {
    where?: Maybe<IUserAccountWhere>;
};
export declare type IQuerygetViewerPermissionsArgs = {
    input?: Maybe<IRoleInput>;
};
export declare type IQuerygetViewerPoliciesArgs = {
    input: IViewerPoliciesInput;
};
export declare type IQuerymergedApplicationPermissionsArgs = {
    roleName?: Maybe<Scalars['String']>;
};
export declare type IQuerymessagesArgs = {
    channelId?: Maybe<Scalars['ID']>;
    limit?: Maybe<Scalars['Int']>;
    skip?: Maybe<Scalars['Int']>;
};
export declare type IQueryteamArgs = {
    teamId: Scalars['ID'];
};
export declare type IQueryusersToChatArgs = {
    auth0Id: Scalars['String'];
};
export declare type IQueryviewerPoliciesArgs = {
    input: IViewerPoliciesInput;
};
export declare type IQueryviewerSettingsArgs = {
    input?: Maybe<IViewerSettingsInput>;
};
export declare type IRange = {
    __typename?: 'Range';
    /**
     * @lsp
     * The range's start position.
     */
    start?: Maybe<IPosition>;
    /**
     * @lsp
     * The range's end position.
     */
    end?: Maybe<IPosition>;
    /** @editor - Line number on which the range starts (starts at 1). */
    startLineNumber?: Maybe<Scalars['Int']>;
    /** @editor - Column on which the range starts in the line `startLineNumber` (starts at 1). */
    startColumn?: Maybe<Scalars['Int']>;
    /** @editor - Line number on which the range ends. */
    endLineNumber?: Maybe<Scalars['Int']>;
    /** @editor - Column on which the range ends in the line `endLineNumber` */
    endColumn?: Maybe<Scalars['Int']>;
};
export declare type IReaction = {
    __typename?: 'Reaction';
    id: Scalars['ID'];
    reaction: Scalars['String'];
    user: IUserAccount;
    post: IPost;
};
export declare type IReactionInput = {
    reaction: Scalars['String'];
    post: Scalars['String'];
};
export declare type IResourceAccessRole = {
    __typename?: 'ResourceAccessRole';
    accessRoles?: Maybe<Array<Maybe<IAccessRole>>>;
    resourceUserRoles?: Maybe<Array<Maybe<IResourceUser>>>;
};
export declare type IResourceCreationData_Input = {
    uri: Scalars['URI'];
    name?: Maybe<Scalars['String']>;
};
export declare type IResourceData = IOrganizationResourceData | IExternalResourceData;
export declare type IResourcePolicy = IIConfigurationModel & {
    __typename?: 'ResourcePolicy';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IResourceRole = IIConfigurationModel & {
    __typename?: 'ResourceRole';
    resource?: Maybe<Scalars['URI']>;
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IResourceUser = IIResourceUserRole & {
    __typename?: 'ResourceUser';
    resource?: Maybe<Scalars['URI']>;
    role?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    isSelf?: Maybe<Scalars['Boolean']>;
    orgName?: Maybe<Scalars['String']>;
};
export declare enum IRole {
    ADMIN = "ADMIN",
    REVIEWER = "REVIEWER",
    USER = "USER",
    UNKNOWN = "UNKNOWN"
}
export declare type IRoleInput = {
    target: Scalars['Int'];
    resource?: Maybe<Scalars['URIInput']>;
    roleName?: Maybe<Scalars['String']>;
};
export declare enum IRoomType {
    CHANNEL = "CHANNEL",
    DIRECT = "DIRECT",
    GROUP = "GROUP",
    PRIVATE = "PRIVATE",
    VISITOR = "VISITOR"
}
export declare type ISendSmsInput = {
    body: Scalars['String'];
    to: Scalars['String'];
};
/** Settings is a version of a configuration settings file. */
export declare type ISettings = {
    __typename?: 'Settings';
    /** The time when this was created. */
    createdAt?: Maybe<Scalars['String']>;
    /**
     * The stringified JSON contents of the settings. The contents may include "//"-style comments and trailing
     * commas in the JSON.
     */
    contents: Scalars['String'];
};
/** The configuration for all of the relevant settings subjects, plus the merged settings. */
export declare type ISettingsCascade = {
    __typename?: 'SettingsCascade';
    /**
     * The other settings subjects that are applied with lower precedence that this subject to
     * form the final merged settings. For example, a user in 2 organizations would have the following
     * settings subjects: site (global settings), org 1, org 2 and the user.
     */
    subjects?: Maybe<Array<Maybe<ISettingsSubject>>>;
    /** The effective final merged settings as (stringified) JSON, merged from all of the subjects. */
    final?: Maybe<Scalars['String']>;
    /** The effective final merged settings as Object, merged from all of the subjects. */
    finalConfiguration?: Maybe<IPreferences>;
};
export declare type ISettingsGroup = {
    __typename?: 'SettingsGroup';
    id?: Maybe<Scalars['String']>;
    range?: Maybe<IRange>;
    title?: Maybe<Scalars['String']>;
    titleRange?: Maybe<IRange>;
    sections?: Maybe<Array<Maybe<ISettingsSection>>>;
    contributedByExtension?: Maybe<Scalars['Boolean']>;
};
export declare type ISettingsSection = {
    __typename?: 'SettingsSection';
    titleRange?: Maybe<IRange>;
    title?: Maybe<Scalars['String']>;
    settings?: Maybe<Array<Maybe<IContributionSettings>>>;
};
export declare type ISettingsSubject = IUserSettings | IApplicationSettings | IMachineSettings | IOrganizationResourceSettings | IGlobalSettings | IOrganizationSettings | IMemorySettings | IDefaultSettings;
export declare enum ISettingValueType {
    Null = "Null",
    Enum = "Enum",
    String = "String",
    Integer = "Integer",
    Number = "Number",
    Boolean = "Boolean",
    Exclude = "Exclude",
    Complex = "Complex",
    NullableInteger = "NullableInteger",
    NullableNumber = "NullableNumber"
}
export declare enum ISmsServiceActions {
    send = "send"
}
export declare type ISocialConnect = {
    __typename?: 'SocialConnect';
    facebook?: Maybe<Scalars['String']>;
    twitter?: Maybe<Scalars['String']>;
};
export declare type ISocialConnect_Input = {
    facebook?: Maybe<Scalars['String']>;
    twitter?: Maybe<Scalars['String']>;
};
export declare type ISort = {
    key: Scalars['String'];
    value: ISortEnum;
};
export declare enum ISortEnum {
    ASC = "ASC",
    DESC = "DESC"
}
export declare type ISubscribedOrganizationData = {
    __typename?: 'SubscribedOrganizationData';
    /** Resources in the organization. */
    resources?: Maybe<Array<Maybe<IResourceData>>>;
    orgNameFilter?: Maybe<Scalars['String']>;
};
export declare type ISubscription = {
    __typename?: 'Subscription';
    SubscribeToConfigurationUpdate?: Maybe<IConfigurationUpdateEvent>;
    SubscribeToOrganizationContext?: Maybe<ISubscribedOrganizationData>;
    SubscribeToPermissionUpdate?: Maybe<IConfigurationUpdateEvent>;
    SubscribeToPolicyUpdate?: Maybe<IConfigurationUpdateEvent>;
    chatMessageAdded?: Maybe<IPost>;
    dummy?: Maybe<Scalars['Int']>;
};
export declare type ISubscriptionSubscribeToConfigurationUpdateArgs = {
    orgName: Scalars['String'];
};
export declare type ISubscriptionSubscribeToOrganizationContextArgs = {
    orgNameFilter?: Maybe<Scalars['String']>;
};
export declare type ISubscriptionSubscribeToPermissionUpdateArgs = {
    orgName?: Maybe<Scalars['String']>;
};
export declare type ISubscriptionSubscribeToPolicyUpdateArgs = {
    orgName?: Maybe<Scalars['String']>;
};
export declare type ISubscriptionchatMessageAddedArgs = {
    channelId?: Maybe<Scalars['String']>;
    directTo?: Maybe<Scalars['String']>;
};
export declare type ITask = {
    __typename?: 'Task';
    id?: Maybe<Scalars['String']>;
    projectId?: Maybe<Scalars['String']>;
    taskName?: Maybe<Scalars['String']>;
};
export declare type ITaskRequest = {
    projectId?: Maybe<Scalars['String']>;
    taskName?: Maybe<Scalars['String']>;
};
export declare type ITeamCreateRequest = {
    name?: Maybe<Scalars['String']>;
    title: Scalars['String'];
    orgName: Scalars['String'];
    tags?: Maybe<Array<Maybe<Scalars['String']>>>;
    emails?: Maybe<Array<Maybe<Scalars['String']>>>;
    teamMembers?: Maybe<Array<Maybe<ITeamMember_Input>>>;
    parentTeam?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
};
export declare type ITeamCreationRequest = {
    name?: Maybe<Scalars['String']>;
    title: Scalars['String'];
    orgName: Scalars['String'];
    tags?: Maybe<Array<Maybe<Scalars['String']>>>;
    emails?: Maybe<Array<Maybe<Scalars['String']>>>;
    parentTeam?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
};
/** TeamMember: A member of a team. */
export declare type ITeamMember = {
    __typename?: 'TeamMember';
    id?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    status?: Maybe<Scalars['String']>;
};
export declare type ITeamMember_Input = {
    id?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['String']>;
    role?: Maybe<IApplicationRoles>;
    status?: Maybe<Scalars['String']>;
};
export declare type ITeamRemoveRequest = {
    teamId?: Maybe<Scalars['String']>;
    emails?: Maybe<Array<Maybe<Scalars['String']>>>;
    invitedBy?: Maybe<Scalars['String']>;
    id: Scalars['String'];
    requestedUserId?: Maybe<Scalars['String']>;
};
export declare type ITeamType = {
    name?: Maybe<Scalars['String']>;
    settings?: Maybe<Scalars['AnyObject']>;
    membersInviteList?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type ITeamUpdateRequest = {
    id: Scalars['String'];
    payload?: Maybe<IAccountTeam_Input>;
    requestedUserId?: Maybe<Scalars['String']>;
};
export declare type ITemplate = {
    templateId?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    text?: Maybe<Scalars['String']>;
    html?: Maybe<Scalars['String']>;
    engine?: Maybe<Scalars['String']>;
    topic?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    variables?: Maybe<Scalars['AnyObject']>;
};
/** Address State Create Input */
export declare type ITerritorialStateInput = {
    /** Name of the country to display */
    name: Scalars['String'];
    /** ID of Country to associate */
    country: Scalars['String'];
};
/** Address State Update Input */
export declare type ITerritorialStateUpdateInput = {
    name?: Maybe<Scalars['String']>;
    country: Scalars['Int'];
};
export declare type IUpdatedClient_Input = {
    name?: Maybe<IName_Input>;
    companyName?: Maybe<Scalars['String']>;
    displayName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    clientPhone?: Maybe<IClientPhone_Input>;
    website?: Maybe<Scalars['String']>;
    currency?: Maybe<Scalars['String']>;
    socialConnect?: Maybe<ISocialConnect_Input>;
    billingAddress?: Maybe<IAddressType_Input>;
    shippingAddress?: Maybe<IAddressType_Input>;
    orgName?: Maybe<Scalars['String']>;
};
export declare type IUpdateProject_Input = {
    name: Scalars['String'];
    clientId?: Maybe<Scalars['String']>;
    teams?: Maybe<Array<Maybe<Scalars['String']>>>;
    orgName?: Maybe<Scalars['String']>;
    integrationConfigurationId?: Maybe<Scalars['String']>;
};
export declare type IUploadedFileInput = {
    name: Scalars['String'];
    mimeType: Scalars['String'];
    size: Scalars['Float'];
    width?: Maybe<Scalars['Float']>;
    height?: Maybe<Scalars['Float']>;
    url: Scalars['String'];
};
export declare type IUserAccount = INode & {
    __typename?: 'UserAccount';
    id: Scalars['ID'];
    email?: Maybe<Scalars['String']>;
    alias?: Maybe<Array<Maybe<Scalars['String']>>>;
    username?: Maybe<Scalars['String']>;
    emailVerified?: Maybe<Scalars['Boolean']>;
    notificationEmail?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    phoneNumber?: Maybe<Array<IPhoneNumber>>;
    tokens?: Maybe<Array<Maybe<IUserVerificationToken>>>;
};
export declare type IUserAccount_Input = {
    id?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    alias?: Maybe<Array<Maybe<Scalars['String']>>>;
    username?: Maybe<Scalars['String']>;
    tokens?: Maybe<Array<Maybe<IUserVerificationTokenInput>>>;
};
export declare type IUserAccountCreatedDetailedEvent = {
    __typename?: 'UserAccountCreatedDetailedEvent';
    id: Scalars['String'];
    email: Scalars['String'];
    username: Scalars['String'];
    emailVerified?: Maybe<Scalars['Boolean']>;
    notificationEmail?: Maybe<Scalars['String']>;
    alias?: Maybe<Array<Maybe<Scalars['String']>>>;
    user_metadata?: Maybe<Scalars['AnyObject']>;
};
export declare type IUserAccountCreatedEvent = {
    __typename?: 'UserAccountCreatedEvent';
    createdUser?: Maybe<IUserAccountCreatedDetailedEvent>;
    sourceUser?: Maybe<IUserProfile>;
};
export declare type IUserAccountCreateRequest = {
    email: Scalars['String'];
    username: Scalars['String'];
    alias?: Maybe<Array<Maybe<Scalars['String']>>>;
    emailVerified?: Maybe<Scalars['Boolean']>;
    notificationEmail?: Maybe<Scalars['String']>;
    familyName?: Maybe<Scalars['String']>;
    givenName?: Maybe<Scalars['String']>;
    picture?: Maybe<Scalars['String']>;
    workEmail?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    companyName?: Maybe<Scalars['String']>;
    phoneNumber?: Maybe<Scalars['String']>;
    tokens?: Maybe<Array<Maybe<IUserVerificationTokenInput>>>;
};
export declare type IUserAccountRemovedEvent = {
    __typename?: 'UserAccountRemovedEvent';
    id?: Maybe<Scalars['String']>;
    email: Scalars['String'];
    username: Scalars['String'];
    notificationEmail?: Maybe<Scalars['String']>;
};
export declare type IUserAccountRemoveRequest = {
    id?: Maybe<Scalars['String']>;
};
export declare type IUserAccountUpdateRequest = {
    id: Scalars['String'];
    payload?: Maybe<IUserAccount_Input>;
};
export declare type IUserAccountWhere = {
    id?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    alias?: Maybe<Array<Maybe<Scalars['String']>>>;
    username?: Maybe<Scalars['String']>;
};
export declare type IUserAuth0UpdateFields = {
    family_name?: Maybe<Scalars['String']>;
    given_name?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    phone_number?: Maybe<IPhoneNumberInput>;
    work_email?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    company_name?: Maybe<Scalars['String']>;
    dob?: Maybe<Scalars['Date']>;
    zip_code?: Maybe<Scalars['Int']>;
    email_verified?: Maybe<Scalars['Boolean']>;
};
export declare type IUserConfiguration = IIConfigurationModel & {
    __typename?: 'UserConfiguration';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /** The URL to the user's settings. */
    resource: Scalars['URI'];
    target?: Maybe<Scalars['Int']>;
    contents?: Maybe<Scalars['AnyObject']>;
    keys?: Maybe<Array<Maybe<Scalars['String']>>>;
    overrides?: Maybe<Array<Maybe<IOverrides>>>;
};
export declare type IUserDevice = {
    __typename?: 'UserDevice';
    name?: Maybe<Scalars['String']>;
    lastLoginAt?: Maybe<Scalars['Date']>;
    lastLoginIp?: Maybe<Scalars['String']>;
};
export declare type IUserEmailVerificationTokenDetails = {
    __typename?: 'UserEmailVerificationTokenDetails';
    key?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
    token?: Maybe<Scalars['String']>;
    verified?: Maybe<Scalars['Boolean']>;
    isValid?: Maybe<Scalars['Boolean']>;
};
export declare type IUserMetadata = IIUserMetadata & {
    __typename?: 'UserMetadata';
    last_name?: Maybe<Scalars['String']>;
    first_name?: Maybe<Scalars['String']>;
    username?: Maybe<Scalars['String']>;
    phone_number?: Maybe<Scalars['String']>;
    work_email?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    company_name?: Maybe<Scalars['String']>;
    dob?: Maybe<Scalars['Date']>;
    zip_code?: Maybe<Scalars['Int']>;
};
export declare enum IUserOrderBy {
    auth0UserId_ASC = "auth0UserId_ASC",
    auth0UserId_DESC = "auth0UserId_DESC",
    createdAt_ASC = "createdAt_ASC",
    createdAt_DESC = "createdAt_DESC",
    emailSubscription_ASC = "emailSubscription_ASC",
    emailSubscription_DESC = "emailSubscription_DESC",
    id_ASC = "id_ASC",
    id_DESC = "id_DESC",
    updatedAt_ASC = "updatedAt_ASC",
    updatedAt_DESC = "updatedAt_DESC"
}
/** The user/org M:F join, denormalized on the user/org tables. */
export declare type IUserOrg = {
    __typename?: 'UserOrg';
    userId: Scalars['String'];
    role?: Maybe<IApplicationRoles>;
    inactive?: Maybe<Scalars['Boolean']>;
};
export declare type IUserOrg_Input = {
    userId: Scalars['String'];
    role?: Maybe<IApplicationRoles>;
    inactive?: Maybe<Scalars['Boolean']>;
};
export declare type IUserPreviousValues = {
    __typename?: 'UserPreviousValues';
    auth0UserId?: Maybe<Scalars['String']>;
    createdAt: Scalars['DateTime'];
    emailSubscription?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    updatedAt: Scalars['DateTime'];
};
export declare type IUserProfile = IIAuth0User & IIAuth0UserProfile & IIAuth0Token & {
    __typename?: 'UserProfile';
    name: Scalars['String'];
    nickname: Scalars['String'];
    picture: Scalars['String'];
    user_id: Scalars['String'];
    username: Scalars['String'];
    given_name?: Maybe<Scalars['String']>;
    family_name?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    email_verified?: Maybe<Scalars['Boolean']>;
    clientID: Scalars['String'];
    gender?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    identities?: Maybe<Array<Maybe<IAuth0Identity>>>;
    accessToken?: Maybe<Scalars['String']>;
    created_at: Scalars['String'];
    updated_at: Scalars['String'];
    user_metadata?: Maybe<IUserMetadata>;
    app_metadata?: Maybe<Scalars['AnyObject']>;
    phone_number?: Maybe<Scalars['String']>;
    work_email?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    company_name?: Maybe<Scalars['String']>;
    iss?: Maybe<Scalars['String']>;
    sub?: Maybe<Scalars['String']>;
    aud?: Maybe<Scalars['String']>;
    iat?: Maybe<Scalars['Int']>;
    exp?: Maybe<Scalars['Int']>;
    at_hash?: Maybe<Scalars['String']>;
    nonce?: Maybe<Scalars['String']>;
};
/** UserSettings is a combination of ApplicationSettings and MachineSettings */
export declare type IUserSettings = IISettingsSubject & {
    __typename?: 'UserSettings';
    /**  The ID.  */
    id?: Maybe<Scalars['ID']>;
    /**
     * The latest settings for the user.
     *
     * Only the user and site admins can access this field.
     */
    latestSettings?: Maybe<ISettings>;
    /** The URL to the user's settings. */
    settingsURL: Scalars['URI'];
    /**
     * Whether the viewer has admin privileges on this user. The user has admin privileges on their own user, and
     * site admins have admin privileges on all users.
     */
    viewerCanAdminister: Scalars['Boolean'];
    /**
     * All settings for this user, and the individual levels in the settings cascade (global > organization > user)
     * that were merged to produce the final merged settings.
     *
     * Only the user and site admins can access this field.
     */
    settingsCascade: ISettingsCascade;
};
/**
 * The User Account.
 *
 * @property
 * id: User ID
 * @property
 * email: The user email
 * @property
 * emailVerified: ture if email is verified, otherwise false
 * @property
 * featureFlags: Any super power given to the user via a super user
 * @property
 * identities: An array of objects with information about the user's identities.
 * More than one will exists in case accounts are linked.
 * @property
 * inactive: true if the user is not currently being billed for service.
 * @property
 * isBillingLeader: true if user is BillingLeader
 * @property
 * userOgs: the orgs and roles for this user on each.
 */
export declare type IUserVerificationToken = {
    __typename?: 'UserVerificationToken';
    key?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
    token?: Maybe<Scalars['String']>;
    verified?: Maybe<Scalars['Boolean']>;
};
export declare type IUserVerificationTokenInput = {
    key?: Maybe<Scalars['String']>;
    value?: Maybe<Scalars['String']>;
    token?: Maybe<Scalars['String']>;
};
export declare type IViewerPoliciesInput = {
    target: Scalars['Int'];
    /**
     * To get the Resource or Organization resource of which we need to get the settings.
     * If we pass the <resource> URI, we can construct the orgUri in background to merge as a parent
     * configuration to the resource configuration.
     */
    settingsResource?: Maybe<Scalars['URI']>;
    /** Application resource to identify the core application settings. */
    applicationResource?: Maybe<Scalars['URI']>;
};
export declare type IViewerSettingsInput = {
    target: Scalars['Int'];
    /**
     * To get the Resource or Organization resource of which we need to get the settings.
     * If we pass the <resource> URI, we can construct the orgUri in background to merge as a parent
     * configuration to the resource configuration.
     */
    settingsResource?: Maybe<Scalars['URI']>;
    /**
     * User resource to identify the core user settings.
     * For guest user, we don't have to define it.
     */
    userResource?: Maybe<Scalars['URI']>;
    /** Application resource to identify the core application settings. */
    applicationResource?: Maybe<Scalars['URI']>;
};
export declare type IViewerSettingsSubject = {
    __typename?: 'ViewerSettingsSubject';
    /**  The URL to the settings.  */
    settingsURL: Scalars['URI'];
    /** Graphql typed settings */
    settings?: Maybe<IPreferences>;
};
export declare enum IVisibility {
    private = "private",
    public = "public"
}
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type LegacyStitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type NewStitchingResolver<TResult, TParent, TContext, TArgs> = {
    selectionSet: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = LegacyStitchingResolver<TResult, TParent, TContext, TArgs> | NewStitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type IResolversTypes = {
    Query: ResolverTypeWrapper<{}>;
    String: ResolverTypeWrapper<Scalars['String']>;
    Channel: ResolverTypeWrapper<IChannel>;
    IBaseRepo: IResolversTypes['Channel'] | IResolversTypes['Post'];
    DateTime: ResolverTypeWrapper<Scalars['DateTime']>;
    AccountTeam: ResolverTypeWrapper<IAccountTeam>;
    ID: ResolverTypeWrapper<Scalars['ID']>;
    URI: ResolverTypeWrapper<Scalars['URI']>;
    TeamMember: ResolverTypeWrapper<ITeamMember>;
    ApplicationRoles: IApplicationRoles;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    UserAccount: ResolverTypeWrapper<IUserAccount>;
    Node: IResolversTypes['UserAccount'] | IResolversTypes['OrgUserAccunt'];
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
    PhoneNumber: ResolverTypeWrapper<IPhoneNumber>;
    UserVerificationToken: ResolverTypeWrapper<IUserVerificationToken>;
    ChannelMember: ResolverTypeWrapper<IChannelMember>;
    AnyObject: ResolverTypeWrapper<Scalars['AnyObject']>;
    ChannelFilterInput: IChannelFilterInput;
    ChannelPrivacy: IChannelPrivacy;
    ChannelSort: IChannelSort;
    OrganizationInvitationDecode: ResolverTypeWrapper<IOrganizationInvitationDecode>;
    SettingsGroup: ResolverTypeWrapper<ISettingsGroup>;
    Range: ResolverTypeWrapper<IRange>;
    Position: ResolverTypeWrapper<IPosition>;
    SettingsSection: ResolverTypeWrapper<ISettingsSection>;
    ContributionSettings: ResolverTypeWrapper<IContributionSettings>;
    ConfigurationScope: IConfigurationScope;
    ConfigurationExtensionInfo: ResolverTypeWrapper<IConfigurationExtensionInfo>;
    ContributionSettingsProperties: ResolverTypeWrapper<IContributionSettingsProperties>;
    EditPresentationTypes: IEditPresentationTypes;
    PreferencesResponse: ResolverTypeWrapper<IPreferencesResponse>;
    PreferencesType: ResolverTypeWrapper<IPreferencesType>;
    DefaultSettings: ResolverTypeWrapper<IDefaultSettings>;
    ISettingsSubject: IResolversTypes['DefaultSettings'] | IResolversTypes['UserSettings'] | IResolversTypes['ApplicationSettings'] | IResolversTypes['MachineSettings'] | IResolversTypes['OrganizationResourceSettings'] | IResolversTypes['GlobalSettings'] | IResolversTypes['OrganizationSettings'] | IResolversTypes['MemorySettings'];
    Settings: ResolverTypeWrapper<ISettings>;
    SettingsCascade: ResolverTypeWrapper<Omit<ISettingsCascade, 'subjects'> & {
        subjects?: Maybe<Array<Maybe<IResolversTypes['SettingsSubject']>>>;
    }>;
    SettingsSubject: IResolversTypes['UserSettings'] | IResolversTypes['ApplicationSettings'] | IResolversTypes['MachineSettings'] | IResolversTypes['OrganizationResourceSettings'] | IResolversTypes['GlobalSettings'] | IResolversTypes['OrganizationSettings'] | IResolversTypes['MemorySettings'] | IResolversTypes['DefaultSettings'];
    UserSettings: ResolverTypeWrapper<IUserSettings>;
    ApplicationSettings: ResolverTypeWrapper<IApplicationSettings>;
    MachineSettings: ResolverTypeWrapper<IMachineSettings>;
    OrganizationResourceSettings: ResolverTypeWrapper<IOrganizationResourceSettings>;
    GlobalSettings: ResolverTypeWrapper<IGlobalSettings>;
    OrganizationSettings: ResolverTypeWrapper<IOrganizationSettings>;
    MemorySettings: ResolverTypeWrapper<IMemorySettings>;
    Preferences: ResolverTypeWrapper<IPreferences>;
    Preference_Account: ResolverTypeWrapper<IPreference_Account>;
    Preference_Default: ResolverTypeWrapper<IPreference_Default>;
    Preference_Account_Global: ResolverTypeWrapper<IPreference_Account_Global>;
    Preference_Account_Global_Notification: ResolverTypeWrapper<IPreference_Account_Global_Notification>;
    Preference_Notifications_Settings: ResolverTypeWrapper<IPreference_Notifications_Settings>;
    Preference_Notification: ResolverTypeWrapper<IPreference_Notification>;
    Float: ResolverTypeWrapper<Scalars['Float']>;
    ChannelSettings: ResolverTypeWrapper<IChannelSettings>;
    Preference_Global: ResolverTypeWrapper<IPreference_Global>;
    Preference_Global_User: ResolverTypeWrapper<IPreference_Global_User>;
    GlobalLanguages: IGlobalLanguages;
    GlobalCurrencies: IGlobalCurrencies;
    Preference_Organization: ResolverTypeWrapper<IPreference_Organization>;
    Preference_Teams: ResolverTypeWrapper<IPreference_Teams>;
    Visibility: IVisibility;
    Preference_Project: ResolverTypeWrapper<IPreference_Project>;
    UserProfile: ResolverTypeWrapper<IUserProfile>;
    IAuth0User: IResolversTypes['UserProfile'];
    IAuth0UserProfile: IResolversTypes['UserProfile'];
    IUserMetadata: IResolversTypes['UserMetadata'];
    Date: ResolverTypeWrapper<Scalars['Date']>;
    IAuth0Token: IResolversTypes['UserProfile'];
    Auth0Identity: ResolverTypeWrapper<IAuth0Identity>;
    Auth0IdentityProfileData: ResolverTypeWrapper<IAuth0IdentityProfileData>;
    UserMetadata: ResolverTypeWrapper<IUserMetadata>;
    UserDevice: ResolverTypeWrapper<IUserDevice>;
    FileInfo: ResolverTypeWrapper<IFileInfo>;
    FileRefType: IFileRefType;
    Sort: ISort;
    SortEnum: ISortEnum;
    FilesInfo: ResolverTypeWrapper<IFilesInfo>;
    IntegrationConfigurationFilterInput: IIntegrationConfigurationFilterInput;
    IntegrationConfiguration: ResolverTypeWrapper<IIntegrationConfiguration>;
    JSON: ResolverTypeWrapper<Scalars['JSON']>;
    UserAccountWhere: IUserAccountWhere;
    Country: ResolverTypeWrapper<ICountry>;
    AsanaConnection: ResolverTypeWrapper<IAsanaConnection>;
    AsanaConnectionState: ResolverTypeWrapper<IAsanaConnectionState>;
    AsanaUser: ResolverTypeWrapper<IAsanaUser>;
    AsanaProjects: ResolverTypeWrapper<IAsanaProjects>;
    AsanaWorkspaces: ResolverTypeWrapper<IAsanaWorkspaces>;
    ConfigurationInput: IConfigurationInput;
    URIInput: ResolverTypeWrapper<Scalars['URIInput']>;
    Configuration: IResolversTypes['DefaultConfiguration'] | IResolversTypes['MachineConfiguration'] | IResolversTypes['UserConfiguration'] | IResolversTypes['OrganizationConfiguration'] | IResolversTypes['OrganizationResourceConfiguration'];
    DefaultConfiguration: ResolverTypeWrapper<IDefaultConfiguration>;
    IConfigurationModel: IResolversTypes['DefaultConfiguration'] | IResolversTypes['MachineConfiguration'] | IResolversTypes['UserConfiguration'] | IResolversTypes['OrganizationConfiguration'] | IResolversTypes['OrganizationResourceConfiguration'] | IResolversTypes['DefaultPolicy'] | IResolversTypes['OrganizationPolicy'] | IResolversTypes['ResourcePolicy'] | IResolversTypes['ApplicationPolicy'] | IResolversTypes['DefaultRole'] | IResolversTypes['OrganizationRole'] | IResolversTypes['ResourceRole'] | IResolversTypes['ApplicationRolePermission'];
    Overrides: ResolverTypeWrapper<IOverrides>;
    MachineConfiguration: ResolverTypeWrapper<IMachineConfiguration>;
    UserConfiguration: ResolverTypeWrapper<IUserConfiguration>;
    OrganizationConfiguration: ResolverTypeWrapper<IOrganizationConfiguration>;
    OrganizationResourceConfiguration: ResolverTypeWrapper<IOrganizationResourceConfiguration>;
    ConfigurationData: ResolverTypeWrapper<IConfigurationData>;
    ConfigurationPolicy: IResolversTypes['DefaultPolicy'] | IResolversTypes['OrganizationPolicy'] | IResolversTypes['ResourcePolicy'] | IResolversTypes['ApplicationPolicy'];
    DefaultPolicy: ResolverTypeWrapper<IDefaultPolicy>;
    OrganizationPolicy: ResolverTypeWrapper<IOrganizationPolicy>;
    ResourcePolicy: ResolverTypeWrapper<IResourcePolicy>;
    ApplicationPolicy: ResolverTypeWrapper<IApplicationPolicy>;
    ContributionRoles: ResolverTypeWrapper<Omit<IContributionRoles, 'permissions'> & {
        permissions?: Maybe<IResolversTypes['AccessRole']>;
    }>;
    AccessRole: IResolversTypes['DefaultRole'] | IResolversTypes['OrganizationRole'] | IResolversTypes['ResourceRole'] | IResolversTypes['ApplicationRolePermission'];
    DefaultRole: ResolverTypeWrapper<IDefaultRole>;
    OrganizationRole: ResolverTypeWrapper<IOrganizationRole>;
    ResourceRole: ResolverTypeWrapper<IResourceRole>;
    ApplicationRolePermission: ResolverTypeWrapper<IApplicationRolePermission>;
    Environment: ResolverTypeWrapper<IEnvironment>;
    ProjectWhereInput: IProjectWhereInput;
    Projects: ResolverTypeWrapper<IProjects>;
    ProjectSource: ResolverTypeWrapper<IProjectSource>;
    ProjectSourceType: IProjectSourceType;
    ProjectParameters: ResolverTypeWrapper<IProjectParameters>;
    ProjectSourceProviders: IProjectSourceProviders;
    ProjectType: IProjectType;
    InvoiceType: ResolverTypeWrapper<IInvoiceType>;
    MemberInvoice: ResolverTypeWrapper<IMemberInvoice>;
    ClientPhone: ResolverTypeWrapper<IClientPhone>;
    AddressType: ResolverTypeWrapper<IAddressType>;
    ProjectInvoice: ResolverTypeWrapper<IProjectInvoice>;
    CustomerInvoice: ResolverTypeWrapper<ICustomerInvoice>;
    Organization: ResolverTypeWrapper<IOrganization>;
    OrgUser: ResolverTypeWrapper<IOrgUser>;
    IOrgUser: IResolversTypes['OrgUser'];
    OrgUserAccunt: ResolverTypeWrapper<IOrgUserAccunt>;
    OrganizationInvitation: ResolverTypeWrapper<IOrganizationInvitation>;
    InviteMember: ResolverTypeWrapper<IInviteMember>;
    InviteStatus: IInviteStatus;
    Client: ResolverTypeWrapper<IClient>;
    NameType: ResolverTypeWrapper<INameType>;
    SocialConnect: ResolverTypeWrapper<ISocialConnect>;
    OrganizationConfigValue_Input: IOrganizationConfigValue_Input;
    ConfigurationOverrides_Input: IConfigurationOverrides_Input;
    OrgDetailWhere: IOrgDetailWhere;
    OrgMember: ResolverTypeWrapper<IOrgMember>;
    OrganizationData: ResolverTypeWrapper<Omit<IOrganizationData, 'resources'> & {
        resources: Array<Maybe<IResolversTypes['ResourceData']>>;
    }>;
    ResourceData: IResolversTypes['OrganizationResourceData'] | IResolversTypes['ExternalResourceData'];
    OrganizationResourceData: ResolverTypeWrapper<IOrganizationResourceData>;
    IResourceData: IResolversTypes['OrganizationResourceData'] | IResolversTypes['ExternalResourceData'];
    ExternalResourceData: ResolverTypeWrapper<IExternalResourceData>;
    Reaction: ResolverTypeWrapper<IReaction>;
    Post: ResolverTypeWrapper<IPost>;
    IFileRef: IResolversTypes['Post'];
    Project_Output: ResolverTypeWrapper<IProject_Output>;
    RoleInput: IRoleInput;
    Task: ResolverTypeWrapper<ITask>;
    ResourceAccessRole: ResolverTypeWrapper<Omit<IResourceAccessRole, 'accessRoles'> & {
        accessRoles?: Maybe<Array<Maybe<IResolversTypes['AccessRole']>>>;
    }>;
    ResourceUser: ResolverTypeWrapper<IResourceUser>;
    IResourceUserRole: IResolversTypes['ResourceUser'];
    UserEmailVerificationTokenDetails: ResolverTypeWrapper<IUserEmailVerificationTokenDetails>;
    PermissionSubject: ResolverTypeWrapper<IPermissionSubject>;
    ViewerPoliciesInput: IViewerPoliciesInput;
    PolicySubject: ResolverTypeWrapper<IPolicySubject>;
    Messages: ResolverTypeWrapper<IMessages>;
    ViewerSettingsInput: IViewerSettingsInput;
    ViewerSettingsSubject: ResolverTypeWrapper<IViewerSettingsSubject>;
    Mutation: ResolverTypeWrapper<{}>;
    OrganizationNotificationValues: IOrganizationNotificationValues;
    IOnBoardingParams: IIOnBoardingParams;
    OrgType: IOrgType;
    TeamType: ITeamType;
    ClientAddRequest: IClientAddRequest;
    Name_Input: IName_Input;
    ClientPhone_Input: IClientPhone_Input;
    SocialConnect_Input: ISocialConnect_Input;
    AddressType_Input: IAddressType_Input;
    ProjectAddRequest: IProjectAddRequest;
    ReactionInput: IReactionInput;
    UploadedFileInput: IUploadedFileInput;
    IntegrationConfigurationInput: IIntegrationConfigurationInput;
    IntegraitonConfigurationId: ResolverTypeWrapper<IIntegraitonConfigurationId>;
    InvoiceCreateRequest: IInvoiceCreateRequest;
    MemberInvoice_Input: IMemberInvoice_Input;
    ProjectInvoice_Input: IProjectInvoice_Input;
    CustomerInvoice_Input: ICustomerInvoice_Input;
    IntegrationConfigurationCreateOrUpdateInput: IIntegrationConfigurationCreateOrUpdateInput;
    OrganizationCreateRequest: IOrganizationCreateRequest;
    OrgUser_Input: IOrgUser_Input;
    OrganizationInvitation_Input: IOrganizationInvitation_Input;
    TaskRequest: ITaskRequest;
    TeamCreationRequest: ITeamCreationRequest;
    MessageIdentifier: IMessageIdentifier;
    MessageInput: IMessageInput;
    UserAuth0UpdateFields: IUserAuth0UpdateFields;
    PhoneNumberInput: IPhoneNumberInput;
    OrganizationRemoveRequest: IOrganizationRemoveRequest;
    InvoiceMailRequest: IInvoiceMailRequest;
    Template: ITemplate;
    OrganizationInvitationRequest: IOrganizationInvitationRequest;
    SendSmsInput: ISendSmsInput;
    InvoiceUpdateRequest: IInvoiceUpdateRequest;
    ClientUpdateRequest: IClientUpdateRequest;
    UpdatedClient_Input: IUpdatedClient_Input;
    UpdateProject_Input: IUpdateProject_Input;
    OrganizationUpdateRequest: IOrganizationUpdateRequest;
    Organization_Input: IOrganization_Input;
    ResourceCreationData_Input: IResourceCreationData_Input;
    Subscription: ResolverTypeWrapper<{}>;
    ConfigurationUpdateEvent: ResolverTypeWrapper<IConfigurationUpdateEvent>;
    ConfigurationOverrides: ResolverTypeWrapper<IConfigurationOverrides>;
    SubscribedOrganizationData: ResolverTypeWrapper<Omit<ISubscribedOrganizationData, 'resources'> & {
        resources?: Maybe<Array<Maybe<IResolversTypes['ResourceData']>>>;
    }>;
    AccountTeam_Input: IAccountTeam_Input;
    TeamMember_Input: ITeamMember_Input;
    AdminIdeSettings: ResolverTypeWrapper<IAdminIdeSettings>;
    AuthUser: ResolverTypeWrapper<IAuthUser>;
    IUser: IResolversTypes['AuthUser'] | IResolversTypes['MessengerUser'];
    AuthUser_Input: IAuthUser_Input;
    BaseServiceCommands: IBaseServiceCommands;
    ChannelMemberInput: IChannelMemberInput;
    ChannelNameAndDirect: IChannelNameAndDirect;
    ChannelServiceCommands: IChannelServiceCommands;
    ChannelUnread: ResolverTypeWrapper<IChannelUnread>;
    CityInput: ICityInput;
    TerritorialStateInput: ITerritorialStateInput;
    CityUpdateInput: ICityUpdateInput;
    TerritorialStateUpdateInput: ITerritorialStateUpdateInput;
    ClientTypes: IClientTypes;
    ConfigCollectionName: IConfigCollectionName;
    ConfigFragmentName: IConfigFragmentName;
    ConfigurationModel: ResolverTypeWrapper<IConfigurationModel>;
    ConfigurationTarget: IConfigurationTarget;
    CountryInput: ICountryInput;
    EnvironmentPayload: IEnvironmentPayload;
    FieldError: ResolverTypeWrapper<IFieldError>;
    File: ResolverTypeWrapper<IFile>;
    FileImageDimensions: IFileImageDimensions;
    FileInfoInput: IFileInfoInput;
    FileInfoUpdateInput: IFileInfoUpdateInput;
    GeoLocation: ResolverTypeWrapper<IGeoLocation>;
    IAuth0Identity: never;
    ICity: never;
    ITerritorialState: never;
    ICountry: never;
    IConfigurationChangeEvent: ResolverTypeWrapper<Omit<IIConfigurationChangeEvent, 'changedConfiguration'> & {
        changedConfiguration?: Maybe<IResolversTypes['Configuration']>;
    }>;
    IConfigurationService: never;
    ImageDimensionsConfigInput: IImageDimensionsConfigInput;
    JSONObject: ResolverTypeWrapper<Scalars['JSONObject']>;
    KeyPathSegment: IKeyPathSegment;
    LoginError: ResolverTypeWrapper<ILoginError>;
    MailTemplateId: IMailTemplateId;
    MessengerNotificationServiceCommands: IMessengerNotificationServiceCommands;
    MessengerUser: ResolverTypeWrapper<IMessengerUser>;
    MessengerUserStatus: IMessengerUserStatus;
    MoleculerCronServiceName: IMoleculerCronServiceName;
    MoleculerServiceName: IMoleculerServiceName;
    MoleculerTopics: IMoleculerTopics;
    Observable: ResolverTypeWrapper<Scalars['Observable']>;
    OrgUserRole: IOrgUserRole;
    OrgainizationInvitationRole: IOrgainizationInvitationRole;
    OrganizationContextPubSubEvents: IOrganizationContextPubSubEvents;
    OrganizationIdentifier: ResolverTypeWrapper<IOrganizationIdentifier>;
    OrganizationMember: ResolverTypeWrapper<IOrganizationMember>;
    PermissionAction: IPermissionAction;
    PermissionResource: IPermissionResource;
    PermissionType: IPermissionType;
    PortalLanguage: IPortalLanguage;
    PostServiceCommands: IPostServiceCommands;
    PostThread: ResolverTypeWrapper<IPostThread>;
    PostsWithCursor: ResolverTypeWrapper<IPostsWithCursor>;
    PreDefinedRole: IPreDefinedRole;
    PreferenceItem: ResolverTypeWrapper<IPreferenceItem>;
    ProjectParameters_Input: IProjectParameters_Input;
    ProjectSource_Input: IProjectSource_Input;
    Project_Input: IProject_Input;
    Role: IRole;
    RoomType: IRoomType;
    SettingValueType: ISettingValueType;
    SmsServiceActions: ISmsServiceActions;
    TeamCreateRequest: ITeamCreateRequest;
    TeamRemoveRequest: ITeamRemoveRequest;
    TeamUpdateRequest: ITeamUpdateRequest;
    Time: ResolverTypeWrapper<Scalars['Time']>;
    Upload: ResolverTypeWrapper<Scalars['Upload']>;
    UserAccountCreateRequest: IUserAccountCreateRequest;
    UserVerificationTokenInput: IUserVerificationTokenInput;
    UserAccountCreatedDetailedEvent: ResolverTypeWrapper<IUserAccountCreatedDetailedEvent>;
    UserAccountCreatedEvent: ResolverTypeWrapper<IUserAccountCreatedEvent>;
    UserAccountRemoveRequest: IUserAccountRemoveRequest;
    UserAccountRemovedEvent: ResolverTypeWrapper<IUserAccountRemovedEvent>;
    UserAccountUpdateRequest: IUserAccountUpdateRequest;
    UserAccount_Input: IUserAccount_Input;
    UserOrderBy: IUserOrderBy;
    UserOrg: ResolverTypeWrapper<IUserOrg>;
    UserOrg_Input: IUserOrg_Input;
    UserPreviousValues: ResolverTypeWrapper<IUserPreviousValues>;
};
/** Mapping between all available schema types and the resolvers parents */
export declare type IResolversParentTypes = {
    Query: {};
    String: Scalars['String'];
    Channel: IChannel;
    IBaseRepo: IResolversParentTypes['Channel'] | IResolversParentTypes['Post'];
    DateTime: Scalars['DateTime'];
    AccountTeam: IAccountTeam;
    ID: Scalars['ID'];
    URI: Scalars['URI'];
    TeamMember: ITeamMember;
    Int: Scalars['Int'];
    UserAccount: IUserAccount;
    Node: IResolversParentTypes['UserAccount'] | IResolversParentTypes['OrgUserAccunt'];
    Boolean: Scalars['Boolean'];
    PhoneNumber: IPhoneNumber;
    UserVerificationToken: IUserVerificationToken;
    ChannelMember: IChannelMember;
    AnyObject: Scalars['AnyObject'];
    ChannelFilterInput: IChannelFilterInput;
    OrganizationInvitationDecode: IOrganizationInvitationDecode;
    SettingsGroup: ISettingsGroup;
    Range: IRange;
    Position: IPosition;
    SettingsSection: ISettingsSection;
    ContributionSettings: IContributionSettings;
    ConfigurationExtensionInfo: IConfigurationExtensionInfo;
    ContributionSettingsProperties: IContributionSettingsProperties;
    PreferencesResponse: IPreferencesResponse;
    PreferencesType: IPreferencesType;
    DefaultSettings: IDefaultSettings;
    ISettingsSubject: IResolversParentTypes['DefaultSettings'] | IResolversParentTypes['UserSettings'] | IResolversParentTypes['ApplicationSettings'] | IResolversParentTypes['MachineSettings'] | IResolversParentTypes['OrganizationResourceSettings'] | IResolversParentTypes['GlobalSettings'] | IResolversParentTypes['OrganizationSettings'] | IResolversParentTypes['MemorySettings'];
    Settings: ISettings;
    SettingsCascade: Omit<ISettingsCascade, 'subjects'> & {
        subjects?: Maybe<Array<Maybe<IResolversParentTypes['SettingsSubject']>>>;
    };
    SettingsSubject: IResolversParentTypes['UserSettings'] | IResolversParentTypes['ApplicationSettings'] | IResolversParentTypes['MachineSettings'] | IResolversParentTypes['OrganizationResourceSettings'] | IResolversParentTypes['GlobalSettings'] | IResolversParentTypes['OrganizationSettings'] | IResolversParentTypes['MemorySettings'] | IResolversParentTypes['DefaultSettings'];
    UserSettings: IUserSettings;
    ApplicationSettings: IApplicationSettings;
    MachineSettings: IMachineSettings;
    OrganizationResourceSettings: IOrganizationResourceSettings;
    GlobalSettings: IGlobalSettings;
    OrganizationSettings: IOrganizationSettings;
    MemorySettings: IMemorySettings;
    Preferences: IPreferences;
    Preference_Account: IPreference_Account;
    Preference_Default: IPreference_Default;
    Preference_Account_Global: IPreference_Account_Global;
    Preference_Account_Global_Notification: IPreference_Account_Global_Notification;
    Preference_Notifications_Settings: IPreference_Notifications_Settings;
    Preference_Notification: IPreference_Notification;
    Float: Scalars['Float'];
    ChannelSettings: IChannelSettings;
    Preference_Global: IPreference_Global;
    Preference_Global_User: IPreference_Global_User;
    Preference_Organization: IPreference_Organization;
    Preference_Teams: IPreference_Teams;
    Preference_Project: IPreference_Project;
    UserProfile: IUserProfile;
    IAuth0User: IResolversParentTypes['UserProfile'];
    IAuth0UserProfile: IResolversParentTypes['UserProfile'];
    IUserMetadata: IResolversParentTypes['UserMetadata'];
    Date: Scalars['Date'];
    IAuth0Token: IResolversParentTypes['UserProfile'];
    Auth0Identity: IAuth0Identity;
    Auth0IdentityProfileData: IAuth0IdentityProfileData;
    UserMetadata: IUserMetadata;
    UserDevice: IUserDevice;
    FileInfo: IFileInfo;
    Sort: ISort;
    FilesInfo: IFilesInfo;
    IntegrationConfigurationFilterInput: IIntegrationConfigurationFilterInput;
    IntegrationConfiguration: IIntegrationConfiguration;
    JSON: Scalars['JSON'];
    UserAccountWhere: IUserAccountWhere;
    Country: ICountry;
    AsanaConnection: IAsanaConnection;
    AsanaConnectionState: IAsanaConnectionState;
    AsanaUser: IAsanaUser;
    AsanaProjects: IAsanaProjects;
    AsanaWorkspaces: IAsanaWorkspaces;
    ConfigurationInput: IConfigurationInput;
    URIInput: Scalars['URIInput'];
    Configuration: IResolversParentTypes['DefaultConfiguration'] | IResolversParentTypes['MachineConfiguration'] | IResolversParentTypes['UserConfiguration'] | IResolversParentTypes['OrganizationConfiguration'] | IResolversParentTypes['OrganizationResourceConfiguration'];
    DefaultConfiguration: IDefaultConfiguration;
    IConfigurationModel: IResolversParentTypes['DefaultConfiguration'] | IResolversParentTypes['MachineConfiguration'] | IResolversParentTypes['UserConfiguration'] | IResolversParentTypes['OrganizationConfiguration'] | IResolversParentTypes['OrganizationResourceConfiguration'] | IResolversParentTypes['DefaultPolicy'] | IResolversParentTypes['OrganizationPolicy'] | IResolversParentTypes['ResourcePolicy'] | IResolversParentTypes['ApplicationPolicy'] | IResolversParentTypes['DefaultRole'] | IResolversParentTypes['OrganizationRole'] | IResolversParentTypes['ResourceRole'] | IResolversParentTypes['ApplicationRolePermission'];
    Overrides: IOverrides;
    MachineConfiguration: IMachineConfiguration;
    UserConfiguration: IUserConfiguration;
    OrganizationConfiguration: IOrganizationConfiguration;
    OrganizationResourceConfiguration: IOrganizationResourceConfiguration;
    ConfigurationData: IConfigurationData;
    ConfigurationPolicy: IResolversParentTypes['DefaultPolicy'] | IResolversParentTypes['OrganizationPolicy'] | IResolversParentTypes['ResourcePolicy'] | IResolversParentTypes['ApplicationPolicy'];
    DefaultPolicy: IDefaultPolicy;
    OrganizationPolicy: IOrganizationPolicy;
    ResourcePolicy: IResourcePolicy;
    ApplicationPolicy: IApplicationPolicy;
    ContributionRoles: Omit<IContributionRoles, 'permissions'> & {
        permissions?: Maybe<IResolversParentTypes['AccessRole']>;
    };
    AccessRole: IResolversParentTypes['DefaultRole'] | IResolversParentTypes['OrganizationRole'] | IResolversParentTypes['ResourceRole'] | IResolversParentTypes['ApplicationRolePermission'];
    DefaultRole: IDefaultRole;
    OrganizationRole: IOrganizationRole;
    ResourceRole: IResourceRole;
    ApplicationRolePermission: IApplicationRolePermission;
    Environment: IEnvironment;
    ProjectWhereInput: IProjectWhereInput;
    Projects: IProjects;
    ProjectSource: IProjectSource;
    ProjectParameters: IProjectParameters;
    InvoiceType: IInvoiceType;
    MemberInvoice: IMemberInvoice;
    ClientPhone: IClientPhone;
    AddressType: IAddressType;
    ProjectInvoice: IProjectInvoice;
    CustomerInvoice: ICustomerInvoice;
    Organization: IOrganization;
    OrgUser: IOrgUser;
    IOrgUser: IResolversParentTypes['OrgUser'];
    OrgUserAccunt: IOrgUserAccunt;
    OrganizationInvitation: IOrganizationInvitation;
    InviteMember: IInviteMember;
    Client: IClient;
    NameType: INameType;
    SocialConnect: ISocialConnect;
    OrganizationConfigValue_Input: IOrganizationConfigValue_Input;
    ConfigurationOverrides_Input: IConfigurationOverrides_Input;
    OrgDetailWhere: IOrgDetailWhere;
    OrgMember: IOrgMember;
    OrganizationData: Omit<IOrganizationData, 'resources'> & {
        resources: Array<Maybe<IResolversParentTypes['ResourceData']>>;
    };
    ResourceData: IResolversParentTypes['OrganizationResourceData'] | IResolversParentTypes['ExternalResourceData'];
    OrganizationResourceData: IOrganizationResourceData;
    IResourceData: IResolversParentTypes['OrganizationResourceData'] | IResolversParentTypes['ExternalResourceData'];
    ExternalResourceData: IExternalResourceData;
    Reaction: IReaction;
    Post: IPost;
    IFileRef: IResolversParentTypes['Post'];
    Project_Output: IProject_Output;
    RoleInput: IRoleInput;
    Task: ITask;
    ResourceAccessRole: Omit<IResourceAccessRole, 'accessRoles'> & {
        accessRoles?: Maybe<Array<Maybe<IResolversParentTypes['AccessRole']>>>;
    };
    ResourceUser: IResourceUser;
    IResourceUserRole: IResolversParentTypes['ResourceUser'];
    UserEmailVerificationTokenDetails: IUserEmailVerificationTokenDetails;
    PermissionSubject: IPermissionSubject;
    ViewerPoliciesInput: IViewerPoliciesInput;
    PolicySubject: IPolicySubject;
    Messages: IMessages;
    ViewerSettingsInput: IViewerSettingsInput;
    ViewerSettingsSubject: IViewerSettingsSubject;
    Mutation: {};
    OrganizationNotificationValues: IOrganizationNotificationValues;
    IOnBoardingParams: IIOnBoardingParams;
    OrgType: IOrgType;
    TeamType: ITeamType;
    ClientAddRequest: IClientAddRequest;
    Name_Input: IName_Input;
    ClientPhone_Input: IClientPhone_Input;
    SocialConnect_Input: ISocialConnect_Input;
    AddressType_Input: IAddressType_Input;
    ProjectAddRequest: IProjectAddRequest;
    ReactionInput: IReactionInput;
    UploadedFileInput: IUploadedFileInput;
    IntegrationConfigurationInput: IIntegrationConfigurationInput;
    IntegraitonConfigurationId: IIntegraitonConfigurationId;
    InvoiceCreateRequest: IInvoiceCreateRequest;
    MemberInvoice_Input: IMemberInvoice_Input;
    ProjectInvoice_Input: IProjectInvoice_Input;
    CustomerInvoice_Input: ICustomerInvoice_Input;
    IntegrationConfigurationCreateOrUpdateInput: IIntegrationConfigurationCreateOrUpdateInput;
    OrganizationCreateRequest: IOrganizationCreateRequest;
    OrgUser_Input: IOrgUser_Input;
    OrganizationInvitation_Input: IOrganizationInvitation_Input;
    TaskRequest: ITaskRequest;
    TeamCreationRequest: ITeamCreationRequest;
    MessageIdentifier: IMessageIdentifier;
    MessageInput: IMessageInput;
    UserAuth0UpdateFields: IUserAuth0UpdateFields;
    PhoneNumberInput: IPhoneNumberInput;
    OrganizationRemoveRequest: IOrganizationRemoveRequest;
    InvoiceMailRequest: IInvoiceMailRequest;
    Template: ITemplate;
    OrganizationInvitationRequest: IOrganizationInvitationRequest;
    SendSmsInput: ISendSmsInput;
    InvoiceUpdateRequest: IInvoiceUpdateRequest;
    ClientUpdateRequest: IClientUpdateRequest;
    UpdatedClient_Input: IUpdatedClient_Input;
    UpdateProject_Input: IUpdateProject_Input;
    OrganizationUpdateRequest: IOrganizationUpdateRequest;
    Organization_Input: IOrganization_Input;
    ResourceCreationData_Input: IResourceCreationData_Input;
    Subscription: {};
    ConfigurationUpdateEvent: IConfigurationUpdateEvent;
    ConfigurationOverrides: IConfigurationOverrides;
    SubscribedOrganizationData: Omit<ISubscribedOrganizationData, 'resources'> & {
        resources?: Maybe<Array<Maybe<IResolversParentTypes['ResourceData']>>>;
    };
    AccountTeam_Input: IAccountTeam_Input;
    TeamMember_Input: ITeamMember_Input;
    AdminIdeSettings: IAdminIdeSettings;
    AuthUser: IAuthUser;
    IUser: IResolversParentTypes['AuthUser'] | IResolversParentTypes['MessengerUser'];
    AuthUser_Input: IAuthUser_Input;
    ChannelMemberInput: IChannelMemberInput;
    ChannelNameAndDirect: IChannelNameAndDirect;
    ChannelUnread: IChannelUnread;
    CityInput: ICityInput;
    TerritorialStateInput: ITerritorialStateInput;
    CityUpdateInput: ICityUpdateInput;
    TerritorialStateUpdateInput: ITerritorialStateUpdateInput;
    ConfigurationModel: IConfigurationModel;
    CountryInput: ICountryInput;
    EnvironmentPayload: IEnvironmentPayload;
    FieldError: IFieldError;
    File: IFile;
    FileImageDimensions: IFileImageDimensions;
    FileInfoInput: IFileInfoInput;
    FileInfoUpdateInput: IFileInfoUpdateInput;
    GeoLocation: IGeoLocation;
    IAuth0Identity: never;
    ICity: never;
    ITerritorialState: never;
    ICountry: never;
    IConfigurationChangeEvent: Omit<IIConfigurationChangeEvent, 'changedConfiguration'> & {
        changedConfiguration?: Maybe<IResolversParentTypes['Configuration']>;
    };
    IConfigurationService: never;
    ImageDimensionsConfigInput: IImageDimensionsConfigInput;
    JSONObject: Scalars['JSONObject'];
    KeyPathSegment: IKeyPathSegment;
    LoginError: ILoginError;
    MessengerUser: IMessengerUser;
    Observable: Scalars['Observable'];
    OrganizationIdentifier: IOrganizationIdentifier;
    OrganizationMember: IOrganizationMember;
    PostThread: IPostThread;
    PostsWithCursor: IPostsWithCursor;
    PreferenceItem: IPreferenceItem;
    ProjectParameters_Input: IProjectParameters_Input;
    ProjectSource_Input: IProjectSource_Input;
    Project_Input: IProject_Input;
    TeamCreateRequest: ITeamCreateRequest;
    TeamRemoveRequest: ITeamRemoveRequest;
    TeamUpdateRequest: ITeamUpdateRequest;
    Time: Scalars['Time'];
    Upload: Scalars['Upload'];
    UserAccountCreateRequest: IUserAccountCreateRequest;
    UserVerificationTokenInput: IUserVerificationTokenInput;
    UserAccountCreatedDetailedEvent: IUserAccountCreatedDetailedEvent;
    UserAccountCreatedEvent: IUserAccountCreatedEvent;
    UserAccountRemoveRequest: IUserAccountRemoveRequest;
    UserAccountRemovedEvent: IUserAccountRemovedEvent;
    UserAccountUpdateRequest: IUserAccountUpdateRequest;
    UserAccount_Input: IUserAccount_Input;
    UserOrg: IUserOrg;
    UserOrg_Input: IUserOrg_Input;
    UserPreviousValues: IUserPreviousValues;
};
export declare type IaddAccountContextDirectiveArgs = {};
export declare type IaddAccountContextDirectiveResolver<Result, Parent, ContextType = any, Args = IaddAccountContextDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IaddNamespaceContextDirectiveArgs = {};
export declare type IaddNamespaceContextDirectiveResolver<Result, Parent, ContextType = any, Args = IaddNamespaceContextDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IhasScopeDirectiveArgs = {
    scope?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type IhasScopeDirectiveResolver<Result, Parent, ContextType = any, Args = IhasScopeDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IisAuthenticatedDirectiveArgs = {};
export declare type IisAuthenticatedDirectiveResolver<Result, Parent, ContextType = any, Args = IisAuthenticatedDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IprofileDirectiveArgs = {};
export declare type IprofileDirectiveResolver<Result, Parent, ContextType = any, Args = IprofileDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IAccessRoleResolvers<ContextType = any, ParentType extends IResolversParentTypes['AccessRole'] = IResolversParentTypes['AccessRole']> = {
    __resolveType: TypeResolveFn<'DefaultRole' | 'OrganizationRole' | 'ResourceRole' | 'ApplicationRolePermission', ParentType, ContextType>;
};
export declare type IAccountTeamResolvers<ContextType = any, ParentType extends IResolversParentTypes['AccountTeam'] = IResolversParentTypes['AccountTeam']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    _id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    title?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    tags?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    settingsUri?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    parentTeam?: Resolver<Maybe<IResolversTypes['AccountTeam']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    description?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teamMembers?: Resolver<Maybe<Array<Maybe<IResolversTypes['TeamMember']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAddressTypeResolvers<ContextType = any, ParentType extends IResolversParentTypes['AddressType'] = IResolversParentTypes['AddressType']> = {
    attention?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    address?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    city?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    state?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    country?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    zip?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAdminIdeSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['AdminIdeSettings'] = IResolversParentTypes['AdminIdeSettings']> = {
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface IAnyObjectScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['AnyObject'], any> {
    name: 'AnyObject';
}
export declare type IApplicationPolicyResolvers<ContextType = any, ParentType extends IResolversParentTypes['ApplicationPolicy'] = IResolversParentTypes['ApplicationPolicy']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IApplicationRolePermissionResolvers<ContextType = any, ParentType extends IResolversParentTypes['ApplicationRolePermission'] = IResolversParentTypes['ApplicationRolePermission']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IApplicationSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['ApplicationSettings'] = IResolversParentTypes['ApplicationSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAsanaConnectionResolvers<ContextType = any, ParentType extends IResolversParentTypes['AsanaConnection'] = IResolversParentTypes['AsanaConnection']> = {
    asana?: Resolver<Maybe<IResolversTypes['AsanaConnectionState']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAsanaConnectionStateResolvers<ContextType = any, ParentType extends IResolversParentTypes['AsanaConnectionState'] = IResolversParentTypes['AsanaConnectionState']> = {
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<IResolversTypes['AsanaUser']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAsanaProjectsResolvers<ContextType = any, ParentType extends IResolversParentTypes['AsanaProjects'] = IResolversParentTypes['AsanaProjects']> = {
    gid?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAsanaUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['AsanaUser'] = IResolversParentTypes['AsanaUser']> = {
    user_id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAsanaWorkspacesResolvers<ContextType = any, ParentType extends IResolversParentTypes['AsanaWorkspaces'] = IResolversParentTypes['AsanaWorkspaces']> = {
    gid?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAuth0IdentityResolvers<ContextType = any, ParentType extends IResolversParentTypes['Auth0Identity'] = IResolversParentTypes['Auth0Identity']> = {
    connection?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    isSocial?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    provider?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    user_id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    profileData?: Resolver<Maybe<IResolversTypes['Auth0IdentityProfileData']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAuth0IdentityProfileDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['Auth0IdentityProfileData'] = IResolversParentTypes['Auth0IdentityProfileData']> = {
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    connection?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IAuthUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['AuthUser'] = IResolversParentTypes['AuthUser']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    auth0UserId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    emailVerified?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    givenName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    familyName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    picture?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phoneNo?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IChannelResolvers<ContextType = any, ParentType extends IResolversParentTypes['Channel'] = IResolversParentTypes['Channel']> = {
    id?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    title?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    topic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    purpose?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    description?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    displayName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    team?: Resolver<Maybe<IResolversTypes['AccountTeam']>, ParentType, ContextType>;
    lastPostAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    totalMsgCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    totalMsgCountRoot?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    creator?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType>;
    members?: Resolver<Maybe<Array<Maybe<IResolversTypes['ChannelMember']>>>, ParentType, ContextType>;
    type?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    deletedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IChannelMemberResolvers<ContextType = any, ParentType extends IResolversParentTypes['ChannelMember'] = IResolversParentTypes['ChannelMember']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    user?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    roles?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    msgCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    mentionCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    mentionCountRoot?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    msgCountRoot?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    notifyProps?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    explicitRoles?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    schemeAdmin?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    lastViewedAt?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    CreatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IChannelSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['ChannelSettings'] = IResolversParentTypes['ChannelSettings']> = {
    disableNotification?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    audio?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    desktop?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    duration?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    mobile?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    mail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    hideUnreadRoomStatus?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    unreadTrayIconAlret?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IChannelUnreadResolvers<ContextType = any, ParentType extends IResolversParentTypes['ChannelUnread'] = IResolversParentTypes['ChannelUnread']> = {
    teamId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    channelId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    msgCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    mentionCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    mentionCountRoot?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    msgCountRoot?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    notifyProps?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IClientResolvers<ContextType = any, ParentType extends IResolversParentTypes['Client'] = IResolversParentTypes['Client']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    name?: Resolver<IResolversTypes['NameType'], ParentType, ContextType>;
    companyName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    displayName?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    clientPhone?: Resolver<Maybe<IResolversTypes['ClientPhone']>, ParentType, ContextType>;
    website?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    currency?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    socialConnect?: Resolver<Maybe<IResolversTypes['SocialConnect']>, ParentType, ContextType>;
    billingAddress?: Resolver<Maybe<IResolversTypes['AddressType']>, ParentType, ContextType>;
    shippingAddress?: Resolver<Maybe<IResolversTypes['AddressType']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IClientPhoneResolvers<ContextType = any, ParentType extends IResolversParentTypes['ClientPhone'] = IResolversParentTypes['ClientPhone']> = {
    workPhone?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    mobile?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['Configuration'] = IResolversParentTypes['Configuration']> = {
    __resolveType: TypeResolveFn<'DefaultConfiguration' | 'MachineConfiguration' | 'UserConfiguration' | 'OrganizationConfiguration' | 'OrganizationResourceConfiguration', ParentType, ContextType>;
};
export declare type IConfigurationDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['ConfigurationData'] = IResolversParentTypes['ConfigurationData']> = {
    defaults?: Resolver<Maybe<IResolversTypes['IConfigurationModel']>, ParentType, ContextType>;
    user?: Resolver<Maybe<IResolversTypes['IConfigurationModel']>, ParentType, ContextType>;
    machine?: Resolver<Maybe<IResolversTypes['IConfigurationModel']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<IResolversTypes['IConfigurationModel']>, ParentType, ContextType>;
    resources?: Resolver<Maybe<Array<Maybe<IResolversTypes['IConfigurationModel']>>>, ParentType, ContextType>;
    isComplete?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IConfigurationExtensionInfoResolvers<ContextType = any, ParentType extends IResolversParentTypes['ConfigurationExtensionInfo'] = IResolversParentTypes['ConfigurationExtensionInfo']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IConfigurationModelResolvers<ContextType = any, ParentType extends IResolversParentTypes['ConfigurationModel'] = IResolversParentTypes['ConfigurationModel']> = {
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IConfigurationOverridesResolvers<ContextType = any, ParentType extends IResolversParentTypes['ConfigurationOverrides'] = IResolversParentTypes['ConfigurationOverrides']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    overrideIdentifier?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    externalResource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IConfigurationPolicyResolvers<ContextType = any, ParentType extends IResolversParentTypes['ConfigurationPolicy'] = IResolversParentTypes['ConfigurationPolicy']> = {
    __resolveType: TypeResolveFn<'DefaultPolicy' | 'OrganizationPolicy' | 'ResourcePolicy' | 'ApplicationPolicy', ParentType, ContextType>;
};
export declare type IConfigurationUpdateEventResolvers<ContextType = any, ParentType extends IResolversParentTypes['ConfigurationUpdateEvent'] = IResolversParentTypes['ConfigurationUpdateEvent']> = {
    resource?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<IResolversTypes['ConfigurationOverrides']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IContributionRolesResolvers<ContextType = any, ParentType extends IResolversParentTypes['ContributionRoles'] = IResolversParentTypes['ContributionRoles']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    description?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    permissions?: Resolver<Maybe<IResolversTypes['AccessRole']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IContributionSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['ContributionSettings'] = IResolversParentTypes['ContributionSettings']> = {
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    range?: Resolver<Maybe<IResolversTypes['Range']>, ParentType, ContextType>;
    key?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    keyRange?: Resolver<Maybe<IResolversTypes['Range']>, ParentType, ContextType>;
    default?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    value?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    valueRange?: Resolver<Maybe<IResolversTypes['Range']>, ParentType, ContextType>;
    description?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    descriptionIsMarkdown?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    descriptionRanges?: Resolver<Maybe<Array<Maybe<IResolversTypes['Range']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['ContributionSettings']>>>, ParentType, ContextType>;
    overrideOf?: Resolver<Maybe<IResolversTypes['ContributionSettings']>, ParentType, ContextType>;
    deprecationMessage?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    scope?: Resolver<Maybe<IResolversTypes['ConfigurationScope']>, ParentType, ContextType>;
    type?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    enum?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    enumDescriptions?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    enumDescriptionsAreMarkdown?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    tags?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    extensionInfo?: Resolver<Maybe<IResolversTypes['ConfigurationExtensionInfo']>, ParentType, ContextType>;
    properties?: Resolver<Maybe<IResolversTypes['ContributionSettingsProperties']>, ParentType, ContextType>;
    settingDependencies?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    minimum?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    maximum?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    maxLength?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    minLength?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    pattern?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    patternErrorMessage?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    format?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    maxItems?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    minItems?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    editPresentation?: Resolver<Maybe<IResolversTypes['EditPresentationTypes']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IContributionSettingsPropertiesResolvers<ContextType = any, ParentType extends IResolversParentTypes['ContributionSettingsProperties'] = IResolversParentTypes['ContributionSettingsProperties']> = {
    readOnly?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    disabled?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ICountryResolvers<ContextType = any, ParentType extends IResolversParentTypes['Country'] = IResolversParentTypes['Country']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    phoneCode?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ICustomerInvoiceResolvers<ContextType = any, ParentType extends IResolversParentTypes['CustomerInvoice'] = IResolversParentTypes['CustomerInvoice']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    companyName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phone?: Resolver<Maybe<IResolversTypes['ClientPhone']>, ParentType, ContextType>;
    billingAddress?: Resolver<Maybe<IResolversTypes['AddressType']>, ParentType, ContextType>;
    shippingAddress?: Resolver<Maybe<IResolversTypes['AddressType']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface IDateScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Date'], any> {
    name: 'Date';
}
export interface IDateTimeScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['DateTime'], any> {
    name: 'DateTime';
}
export declare type IDefaultConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['DefaultConfiguration'] = IResolversParentTypes['DefaultConfiguration']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    resource?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IDefaultPolicyResolvers<ContextType = any, ParentType extends IResolversParentTypes['DefaultPolicy'] = IResolversParentTypes['DefaultPolicy']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IDefaultRoleResolvers<ContextType = any, ParentType extends IResolversParentTypes['DefaultRole'] = IResolversParentTypes['DefaultRole']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IDefaultSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['DefaultSettings'] = IResolversParentTypes['DefaultSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IEnvironmentResolvers<ContextType = any, ParentType extends IResolversParentTypes['Environment'] = IResolversParentTypes['Environment']> = {
    args?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IExternalResourceDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['ExternalResourceData'] = IResolversParentTypes['ExternalResourceData']> = {
    uri?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    index?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IFieldErrorResolvers<ContextType = any, ParentType extends IResolversParentTypes['FieldError'] = IResolversParentTypes['FieldError']> = {
    field?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    message?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IFileResolvers<ContextType = any, ParentType extends IResolversParentTypes['File'] = IResolversParentTypes['File']> = {
    filename?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    mimetype?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    encoding?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IFileInfoResolvers<ContextType = any, ParentType extends IResolversParentTypes['FileInfo'] = IResolversParentTypes['FileInfo']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    extension?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    mimeType?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    size?: Resolver<IResolversTypes['Float'], ParentType, ContextType>;
    width?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    height?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    url?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    ref?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    refType?: Resolver<IResolversTypes['FileRefType'], ParentType, ContextType>;
    createdAt?: Resolver<IResolversTypes['Date'], ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
    createdBy?: Resolver<Maybe<IResolversTypes['Node']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IFilesInfoResolvers<ContextType = any, ParentType extends IResolversParentTypes['FilesInfo'] = IResolversParentTypes['FilesInfo']> = {
    totalCount?: Resolver<IResolversTypes['Int'], ParentType, ContextType>;
    data?: Resolver<Maybe<Array<Maybe<IResolversTypes['FileInfo']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IGeoLocationResolvers<ContextType = any, ParentType extends IResolversParentTypes['GeoLocation'] = IResolversParentTypes['GeoLocation']> = {
    coordinates?: Resolver<Maybe<Array<Maybe<IResolversTypes['Float']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IGlobalSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['GlobalSettings'] = IResolversParentTypes['GlobalSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IIAuth0IdentityResolvers<ContextType = any, ParentType extends IResolversParentTypes['IAuth0Identity'] = IResolversParentTypes['IAuth0Identity']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    connection?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    isSocial?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    provider?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    user_id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IIAuth0TokenResolvers<ContextType = any, ParentType extends IResolversParentTypes['IAuth0Token'] = IResolversParentTypes['IAuth0Token']> = {
    __resolveType: TypeResolveFn<'UserProfile', ParentType, ContextType>;
    iss?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    sub?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    aud?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    iat?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    exp?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    at_hash?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    nonce?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IIAuth0UserResolvers<ContextType = any, ParentType extends IResolversParentTypes['IAuth0User'] = IResolversParentTypes['IAuth0User']> = {
    __resolveType: TypeResolveFn<'UserProfile', ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    user_id?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    given_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    family_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    nickname?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    username?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email_verified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    picture?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    locale?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    updated_at?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phone_number?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IIAuth0UserProfileResolvers<ContextType = any, ParentType extends IResolversParentTypes['IAuth0UserProfile'] = IResolversParentTypes['IAuth0UserProfile']> = {
    __resolveType: TypeResolveFn<'UserProfile', ParentType, ContextType>;
    clientID?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    gender?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    locale?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    created_at?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    updated_at?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    sub?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    user_metadata?: Resolver<Maybe<IResolversTypes['IUserMetadata']>, ParentType, ContextType>;
    app_metadata?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
};
export declare type IIBaseRepoResolvers<ContextType = any, ParentType extends IResolversParentTypes['IBaseRepo'] = IResolversParentTypes['IBaseRepo']> = {
    __resolveType: TypeResolveFn<'Channel' | 'Post', ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    deletedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
};
export declare type IICityResolvers<ContextType = any, ParentType extends IResolversParentTypes['ICity'] = IResolversParentTypes['ICity']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    state?: Resolver<IResolversTypes['ITerritorialState'], ParentType, ContextType>;
    location?: Resolver<Maybe<IResolversTypes['GeoLocation']>, ParentType, ContextType>;
    createdAt?: Resolver<IResolversTypes['Date'], ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
};
export declare type IIConfigurationChangeEventResolvers<ContextType = any, ParentType extends IResolversParentTypes['IConfigurationChangeEvent'] = IResolversParentTypes['IConfigurationChangeEvent']> = {
    source?: Resolver<Maybe<IResolversTypes['ConfigurationTarget']>, ParentType, ContextType>;
    affectedKeys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    sourceConfig?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    changedConfiguration?: Resolver<Maybe<IResolversTypes['Configuration']>, ParentType, ContextType>;
    changedConfigurationByResource?: Resolver<Maybe<IResolversTypes['OrganizationResourceConfiguration']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IIConfigurationModelResolvers<ContextType = any, ParentType extends IResolversParentTypes['IConfigurationModel'] = IResolversParentTypes['IConfigurationModel']> = {
    __resolveType: TypeResolveFn<'DefaultConfiguration' | 'MachineConfiguration' | 'UserConfiguration' | 'OrganizationConfiguration' | 'OrganizationResourceConfiguration' | 'DefaultPolicy' | 'OrganizationPolicy' | 'ResourcePolicy' | 'ApplicationPolicy' | 'DefaultRole' | 'OrganizationRole' | 'ResourceRole' | 'ApplicationRolePermission', ParentType, ContextType>;
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
};
export declare type IIConfigurationServiceResolvers<ContextType = any, ParentType extends IResolversParentTypes['IConfigurationService'] = IResolversParentTypes['IConfigurationService']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    updateValue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IIConfigurationServiceupdateValueArgs, 'key' | 'value' | 'overrides'>>;
};
export declare type IICountryResolvers<ContextType = any, ParentType extends IResolversParentTypes['ICountry'] = IResolversParentTypes['ICountry']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    phone_code?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    location?: Resolver<Maybe<IResolversTypes['GeoLocation']>, ParentType, ContextType>;
    createdAt?: Resolver<IResolversTypes['Date'], ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
};
export declare type IIFileRefResolvers<ContextType = any, ParentType extends IResolversParentTypes['IFileRef'] = IResolversParentTypes['IFileRef']> = {
    __resolveType: TypeResolveFn<'Post', ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
};
export declare type IIntegraitonConfigurationIdResolvers<ContextType = any, ParentType extends IResolversParentTypes['IntegraitonConfigurationId'] = IResolversParentTypes['IntegraitonConfigurationId']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IIntegrationConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['IntegrationConfiguration'] = IResolversParentTypes['IntegrationConfiguration']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    userId?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    integrationName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    integrationInfo?: Resolver<Maybe<IResolversTypes['JSON']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IInviteMemberResolvers<ContextType = any, ParentType extends IResolversParentTypes['InviteMember'] = IResolversParentTypes['InviteMember']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teamId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['InviteStatus']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IInvoiceTypeResolvers<ContextType = any, ParentType extends IResolversParentTypes['InvoiceType'] = IResolversParentTypes['InvoiceType']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    comment?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    currency?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    discount?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    from?: Resolver<Maybe<IResolversTypes['MemberInvoice']>, ParentType, ContextType>;
    invoiceDate?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    terms?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    dueDate?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    invoiceNumber?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    orderNumber?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    invoiceVendor?: Resolver<Maybe<IResolversTypes['MemberInvoice']>, ParentType, ContextType>;
    logo?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    overdue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    paymentStatus?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    projects?: Resolver<Maybe<Array<Maybe<IResolversTypes['ProjectInvoice']>>>, ParentType, ContextType>;
    sendingStatus?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    subTotal?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    tax?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    subject?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    conditions?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    timezoneOffset?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    to?: Resolver<Maybe<IResolversTypes['CustomerInvoice']>, ParentType, ContextType>;
    total?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IIOrgUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['IOrgUser'] = IResolversParentTypes['IOrgUser']> = {
    __resolveType: TypeResolveFn<'OrgUser', ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    isSelf?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    orgName?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
};
export declare type IIResourceDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['IResourceData'] = IResolversParentTypes['IResourceData']> = {
    __resolveType: TypeResolveFn<'OrganizationResourceData' | 'ExternalResourceData', ParentType, ContextType>;
    uri?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    index?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
};
export declare type IIResourceUserRoleResolvers<ContextType = any, ParentType extends IResolversParentTypes['IResourceUserRole'] = IResolversParentTypes['IResourceUserRole']> = {
    __resolveType: TypeResolveFn<'ResourceUser', ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    isSelf?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IISettingsSubjectResolvers<ContextType = any, ParentType extends IResolversParentTypes['ISettingsSubject'] = IResolversParentTypes['ISettingsSubject']> = {
    __resolveType: TypeResolveFn<'DefaultSettings' | 'UserSettings' | 'ApplicationSettings' | 'MachineSettings' | 'OrganizationResourceSettings' | 'GlobalSettings' | 'OrganizationSettings' | 'MemorySettings', ParentType, ContextType>;
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
};
export declare type IITerritorialStateResolvers<ContextType = any, ParentType extends IResolversParentTypes['ITerritorialState'] = IResolversParentTypes['ITerritorialState']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    country?: Resolver<IResolversTypes['ICountry'], ParentType, ContextType>;
    location?: Resolver<Maybe<IResolversTypes['GeoLocation']>, ParentType, ContextType>;
    createdAt?: Resolver<IResolversTypes['Date'], ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
};
export declare type IIUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['IUser'] = IResolversParentTypes['IUser']> = {
    __resolveType: TypeResolveFn<'AuthUser' | 'MessengerUser', ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IIUserMetadataResolvers<ContextType = any, ParentType extends IResolversParentTypes['IUserMetadata'] = IResolversParentTypes['IUserMetadata']> = {
    __resolveType: TypeResolveFn<'UserMetadata', ParentType, ContextType>;
    last_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    first_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phone_number?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    work_email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    country?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    company_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    dob?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
    zip_code?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
};
export interface IJSONScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['JSON'], any> {
    name: 'JSON';
}
export interface IJSONObjectScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['JSONObject'], any> {
    name: 'JSONObject';
}
export declare type ILoginErrorResolvers<ContextType = any, ParentType extends IResolversParentTypes['LoginError'] = IResolversParentTypes['LoginError']> = {
    timeStamp?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    error?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMachineConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['MachineConfiguration'] = IResolversParentTypes['MachineConfiguration']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    resource?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMachineSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['MachineSettings'] = IResolversParentTypes['MachineSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMemberInvoiceResolvers<ContextType = any, ParentType extends IResolversParentTypes['MemberInvoice'] = IResolversParentTypes['MemberInvoice']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    companyName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phone?: Resolver<Maybe<IResolversTypes['ClientPhone']>, ParentType, ContextType>;
    address?: Resolver<Maybe<IResolversTypes['AddressType']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMemorySettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['MemorySettings'] = IResolversParentTypes['MemorySettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMessagesResolvers<ContextType = any, ParentType extends IResolversParentTypes['Messages'] = IResolversParentTypes['Messages']> = {
    totalCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    data?: Resolver<Maybe<Array<Maybe<IResolversTypes['Post']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMessengerUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['MessengerUser'] = IResolversParentTypes['MessengerUser']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['MessengerUserStatus']>, ParentType, ContextType>;
    avatar?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    lastLogin?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    channels?: Resolver<Maybe<Array<Maybe<IResolversTypes['Channel']>>>, ParentType, ContextType>;
    directMessages?: Resolver<Maybe<Array<Maybe<IResolversTypes['Channel']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMutationResolvers<ContextType = any, ParentType extends IResolversParentTypes['Mutation'] = IResolversParentTypes['Mutation']> = {
    acceptOrganizationInvitation?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationacceptOrganizationInvitationArgs, 'id'>>;
    accountOnBoarding?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationaccountOnBoardingArgs, never>>;
    addClient?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationaddClientArgs, 'client'>>;
    addContributionRole?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationaddContributionRoleArgs, 'name'>>;
    addMemberToChannel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType, RequireFields<IMutationaddMemberToChannelArgs, 'channelId' | 'memberId'>>;
    addOrgProject?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationaddOrgProjectArgs, 'project'>>;
    addReactionToMessage?: Resolver<Maybe<IResolversTypes['Reaction']>, ParentType, ContextType, RequireFields<IMutationaddReactionToMessageArgs, never>>;
    addTeamMembers?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationaddTeamMembersArgs, 'orgName' | 'teamName' | 'memberIds'>>;
    attachUploadedFileToMessage?: Resolver<IResolversTypes['FileInfo'], ParentType, ContextType, RequireFields<IMutationattachUploadedFileToMessageArgs, 'postId' | 'file'>>;
    changeMemberRole?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationchangeMemberRoleArgs, 'orgName' | 'teamName' | 'memberId' | 'role'>>;
    changeOrgMemberRole?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationchangeOrgMemberRoleArgs, 'userId' | 'role'>>;
    createChannel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType, RequireFields<IMutationcreateChannelArgs, 'name' | 'description'>>;
    createDirectChannel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType, RequireFields<IMutationcreateDirectChannelArgs, 'receiver' | 'displayName'>>;
    createIntegrationConfiguration?: Resolver<Maybe<IResolversTypes['IntegraitonConfigurationId']>, ParentType, ContextType, RequireFields<IMutationcreateIntegrationConfigurationArgs, never>>;
    createInvoice?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationcreateInvoiceArgs, 'invoice'>>;
    createMessageFileUploadLink?: Resolver<IResolversTypes['String'], ParentType, ContextType, RequireFields<IMutationcreateMessageFileUploadLinkArgs, 'postId' | 'filename'>>;
    createOrUpdateIntegrationConfiguration?: Resolver<Maybe<IResolversTypes['IntegraitonConfigurationId']>, ParentType, ContextType, RequireFields<IMutationcreateOrUpdateIntegrationConfigurationArgs, never>>;
    createOrganization?: Resolver<Maybe<IResolversTypes['Organization']>, ParentType, ContextType, RequireFields<IMutationcreateOrganizationArgs, 'organization'>>;
    createTask?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationcreateTaskArgs, never>>;
    createTeam?: Resolver<Maybe<IResolversTypes['AccountTeam']>, ParentType, ContextType, RequireFields<IMutationcreateTeamArgs, 'request'>>;
    declineOrganizationInvitation?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationdeclineOrganizationInvitationArgs, 'id'>>;
    deleteChannel?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationdeleteChannelArgs, 'id'>>;
    deleteIntegrationConfiguration?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationdeleteIntegrationConfigurationArgs, 'id'>>;
    deleteMessage?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationdeleteMessageArgs, 'messageId'>>;
    deleteMessageFile?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType, RequireFields<IMutationdeleteMessageFileArgs, 'url'>>;
    deleteUserAccount?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    deleteUserAuthorizedDevice?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationdeleteUserAuthorizedDeviceArgs, 'deviceId'>>;
    deliverMessage?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType, RequireFields<IMutationdeliverMessageArgs, 'messageId'>>;
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    editMessage?: Resolver<Maybe<IResolversTypes['Post']>, ParentType, ContextType, RequireFields<IMutationeditMessageArgs, 'messageId' | 'messageInput'>>;
    hideChannel?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationhideChannelArgs, 'id'>>;
    initiateConfigurationValue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationinitiateConfigurationValueArgs, never>>;
    initiatePolicyValue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationinitiatePolicyValueArgs, never>>;
    leaveChannel?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationleaveChannelArgs, 'id'>>;
    readMessage?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType, RequireFields<IMutationreadMessageArgs, 'messageId'>>;
    registerAccountUser?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType, RequireFields<IMutationregisterAccountUserArgs, never>>;
    registerUserInAuth0?: Resolver<Maybe<IResolversTypes['UserProfile']>, ParentType, ContextType, RequireFields<IMutationregisterUserInAuth0Args, 'email' | 'password'>>;
    removeInvoice?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveInvoiceArgs, never>>;
    removeOrgClient?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveOrgClientArgs, 'clientId'>>;
    removeOrgMember?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveOrgMemberArgs, 'memberId'>>;
    removeOrganization?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveOrganizationArgs, 'organization'>>;
    removeReactionFromMessage?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveReactionFromMessageArgs, 'id'>>;
    removeTask?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveTaskArgs, 'id'>>;
    removeTeam?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveTeamArgs, 'teamId'>>;
    removeTeamMember?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationremoveTeamMemberArgs, 'orgName' | 'teamName' | 'memberId'>>;
    resendOrganizationInvitation?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationresendOrganizationInvitationArgs, 'id'>>;
    resendUserEmailVerificationEmail?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    sendInvoiceMail?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationsendInvoiceMailArgs, 'request'>>;
    sendMessage?: Resolver<Maybe<IResolversTypes['Post']>, ParentType, ContextType, RequireFields<IMutationsendMessageArgs, 'channelId' | 'messageInput'>>;
    sendNotificationOfUnreadMessages?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType, RequireFields<IMutationsendNotificationOfUnreadMessagesArgs, 'unit' | 'value'>>;
    sendOrganizationInvitation?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationsendOrganizationInvitationArgs, never>>;
    sendSms?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType, RequireFields<IMutationsendSmsArgs, never>>;
    setSettingsValueByResource?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationsetSettingsValueByResourceArgs, never>>;
    updateAuth0UserPassword?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateAuth0UserPasswordArgs, never>>;
    updateConfigurationPolicyValue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateConfigurationPolicyValueArgs, 'key' | 'value'>>;
    updateConfigurationPolicyValueByUri?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateConfigurationPolicyValueByUriArgs, 'key' | 'value'>>;
    updateConfigurationValue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateConfigurationValueArgs, 'key' | 'value'>>;
    updateConfigurationValueByUri?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateConfigurationValueByUriArgs, 'key' | 'value'>>;
    updateInvoice?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateInvoiceArgs, never>>;
    updateOrgClient?: Resolver<Maybe<IResolversTypes['Client']>, ParentType, ContextType, RequireFields<IMutationupdateOrgClientArgs, never>>;
    updateOrgMemberTeams?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateOrgMemberTeamsArgs, 'userId' | 'orgName'>>;
    updateOrgProject?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateOrgProjectArgs, 'where'>>;
    updateOrganization?: Resolver<Maybe<IResolversTypes['Organization']>, ParentType, ContextType, RequireFields<IMutationupdateOrganizationArgs, 'organization'>>;
    updateOrganizationContextAddResources?: Resolver<Maybe<Array<Maybe<IResolversTypes['ResourceData']>>>, ParentType, ContextType, RequireFields<IMutationupdateOrganizationContextAddResourcesArgs, 'resourcesToAdd'>>;
    updateOrganizationContextRemoveResources?: Resolver<Maybe<Array<Maybe<IResolversTypes['ResourceData']>>>, ParentType, ContextType, RequireFields<IMutationupdateOrganizationContextRemoveResourcesArgs, 'resourcesToRemove'>>;
    updateOrganizationContextUpdateResources?: Resolver<Maybe<Array<Maybe<IResolversTypes['ResourceData']>>>, ParentType, ContextType, RequireFields<IMutationupdateOrganizationContextUpdateResourcesArgs, 'resourcesToAdd' | 'resourcesToRemove'>>;
    updateProjectStatus?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateProjectStatusArgs, 'id'>>;
    updateReactionToMessage?: Resolver<Maybe<IResolversTypes['Reaction']>, ParentType, ContextType, RequireFields<IMutationupdateReactionToMessageArgs, 'id' | 'reaction'>>;
    updateRoleValue?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateRoleValueArgs, 'key' | 'value'>>;
    updateTask?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateTaskArgs, 'id'>>;
    updateUserAccount?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationupdateUserAccountArgs, never>>;
    upsertProjectThroughIntegration?: Resolver<Maybe<IResolversTypes['Projects']>, ParentType, ContextType, RequireFields<IMutationupsertProjectThroughIntegrationArgs, 'where'>>;
    verifyUserEmailVerificationToken?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationverifyUserEmailVerificationTokenArgs, never>>;
    viewChannel?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType, RequireFields<IMutationviewChannelArgs, 'id'>>;
};
export declare type INameTypeResolvers<ContextType = any, ParentType extends IResolversParentTypes['NameType'] = IResolversParentTypes['NameType']> = {
    salutation?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    firstName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    lastName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type INodeResolvers<ContextType = any, ParentType extends IResolversParentTypes['Node'] = IResolversParentTypes['Node']> = {
    __resolveType: TypeResolveFn<'UserAccount' | 'OrgUserAccunt', ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
};
export interface IObservableScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Observable'], any> {
    name: 'Observable';
}
export declare type IOrganizationResolvers<ContextType = any, ParentType extends IResolversParentTypes['Organization'] = IResolversParentTypes['Organization']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    title?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    description?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    picture?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    stripeId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    namespace?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    orgUserCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    orgMembers?: Resolver<Maybe<Array<Maybe<IResolversTypes['OrgUser']>>>, ParentType, ContextType>;
    periodStart?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    periodStop?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    billingLeaders?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    billingEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    isBillingLeader?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    mainBilingLeaderId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    stripeSubscriptionId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    invitations?: Resolver<Maybe<Array<Maybe<IResolversTypes['OrganizationInvitation']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationConfiguration'] = IResolversParentTypes['OrganizationConfiguration']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    resource?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationData'] = IResolversParentTypes['OrganizationData']> = {
    id?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    resources?: Resolver<Array<Maybe<IResolversTypes['ResourceData']>>, ParentType, ContextType>;
    configuration?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationIdentifierResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationIdentifier'] = IResolversParentTypes['OrganizationIdentifier']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    configPath?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationInvitationResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationInvitation'] = IResolversParentTypes['OrganizationInvitation']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teamId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    active?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    fullName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    inviteCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    invitedBy?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    acceptedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    tokenExpiration?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationInvitationDecodeResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationInvitationDecode'] = IResolversParentTypes['OrganizationInvitationDecode']> = {
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teamName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    invitationId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    invitedBy?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationMemberResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationMember'] = IResolversParentTypes['OrganizationMember']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    user?: Resolver<Maybe<IResolversTypes['AuthUser']>, ParentType, ContextType>;
    isBillingLeader?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<IResolversTypes['Organization']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationPolicyResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationPolicy'] = IResolversParentTypes['OrganizationPolicy']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationResourceConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationResourceConfiguration'] = IResolversParentTypes['OrganizationResourceConfiguration']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    resource?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationResourceDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationResourceData'] = IResolversParentTypes['OrganizationResourceData']> = {
    uri?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    index?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationResourceSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationResourceSettings'] = IResolversParentTypes['OrganizationResourceSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationRoleResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationRole'] = IResolversParentTypes['OrganizationRole']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrganizationSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrganizationSettings'] = IResolversParentTypes['OrganizationSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrgMemberResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrgMember'] = IResolversParentTypes['OrgMember']> = {
    _id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    userId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    inactive?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    crossCheckEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teamNames?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrgUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrgUser'] = IResolversParentTypes['OrgUser']> = {
    userId?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    inactive?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    orgName?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    user?: Resolver<IResolversTypes['OrgUserAccunt'], ParentType, ContextType>;
    isSelf?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    crossCheckEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOrgUserAccuntResolvers<ContextType = any, ParentType extends IResolversParentTypes['OrgUserAccunt'] = IResolversParentTypes['OrgUserAccunt']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    alias?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    emailVerified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOverridesResolvers<ContextType = any, ParentType extends IResolversParentTypes['Overrides'] = IResolversParentTypes['Overrides']> = {
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    identifiers?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPermissionSubjectResolvers<ContextType = any, ParentType extends IResolversParentTypes['PermissionSubject'] = IResolversParentTypes['PermissionSubject']> = {
    roleURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    permissions?: Resolver<IResolversTypes['AnyObject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPhoneNumberResolvers<ContextType = any, ParentType extends IResolversParentTypes['PhoneNumber'] = IResolversParentTypes['PhoneNumber']> = {
    countryCode?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phoneNumber?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPolicySubjectResolvers<ContextType = any, ParentType extends IResolversParentTypes['PolicySubject'] = IResolversParentTypes['PolicySubject']> = {
    policyURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    policies?: Resolver<IResolversTypes['AnyObject'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPositionResolvers<ContextType = any, ParentType extends IResolversParentTypes['Position'] = IResolversParentTypes['Position']> = {
    line?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    character?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPostResolvers<ContextType = any, ParentType extends IResolversParentTypes['Post'] = IResolversParentTypes['Post']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    author?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType>;
    channel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType>;
    rootId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    parentId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    originalId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    fromServer?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    message?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    type?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    props?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    hashTags?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    filenames?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    fields?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    reactions?: Resolver<Maybe<Array<Maybe<IResolversTypes['Reaction']>>>, ParentType, ContextType>;
    files?: Resolver<IResolversTypes['FilesInfo'], ParentType, ContextType, RequireFields<IPostfilesArgs, never>>;
    editedBy?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType>;
    deletedBy?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    deletedAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    propsConfiguration?: Resolver<Maybe<IResolversTypes['MachineConfiguration']>, ParentType, ContextType>;
    isRead?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    isDelivered?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPostsWithCursorResolvers<ContextType = any, ParentType extends IResolversParentTypes['PostsWithCursor'] = IResolversParentTypes['PostsWithCursor']> = {
    cursor?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    channel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType>;
    posts?: Resolver<Maybe<Array<Maybe<IResolversTypes['Post']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPostThreadResolvers<ContextType = any, ParentType extends IResolversParentTypes['PostThread'] = IResolversParentTypes['PostThread']> = {
    post?: Resolver<Maybe<IResolversTypes['Post']>, ParentType, ContextType>;
    channel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType>;
    replyCount?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    lastReplyAt?: Resolver<Maybe<IResolversTypes['DateTime']>, ParentType, ContextType>;
    participants?: Resolver<Maybe<Array<Maybe<IResolversTypes['UserAccount']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_AccountResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Account'] = IResolversParentTypes['Preference_Account']> = {
    autoLoadImages?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    avatar?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    collapseEmbeddedMeida?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    convertAsciiToEmoji?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    default?: Resolver<Maybe<IResolversTypes['Preference_Default']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    enterKeyBehaviour?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    global?: Resolver<Maybe<IResolversTypes['Preference_Account_Global']>, ParentType, ContextType>;
    hideAvatars?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    hideRightSideBarWithClick?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    hideRoles?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    hideUserName?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    highlights?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    language?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    mergePrivateGroupsWithChannels?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    newMessageNotificationSound?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    newRoomNotificationSound?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    notification?: Resolver<Maybe<IResolversTypes['Preference_Notification']>, ParentType, ContextType>;
    notificationDuration?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    offlineEmailNotifications?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    saveMobileBandwith?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    unreadRoomsMode?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    unreadTrayIconAlert?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    useEmojis?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    viewMode?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_Account_GlobalResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Account_Global'] = IResolversParentTypes['Preference_Account_Global']> = {
    notification?: Resolver<Maybe<IResolversTypes['Preference_Account_Global_Notification']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_Account_Global_NotificationResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Account_Global_Notification'] = IResolversParentTypes['Preference_Account_Global_Notification']> = {
    offlineMessages?: Resolver<Maybe<IResolversTypes['Preference_Notifications_Settings']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_DefaultResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Default'] = IResolversParentTypes['Preference_Default']> = {
    organization?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_GlobalResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Global'] = IResolversParentTypes['Preference_Global']> = {
    user?: Resolver<Maybe<IResolversTypes['Preference_Global_User']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_Global_UserResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Global_User'] = IResolversParentTypes['Preference_Global_User']> = {
    preferredLanguage?: Resolver<Maybe<IResolversTypes['GlobalLanguages']>, ParentType, ContextType>;
    preferredCurrency?: Resolver<Maybe<IResolversTypes['GlobalCurrencies']>, ParentType, ContextType>;
    timeZone?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_NotificationResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Notification'] = IResolversParentTypes['Preference_Notification']> = {
    billing?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    primaryEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    onChangeAccountSettings?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_Notifications_SettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Notifications_Settings'] = IResolversParentTypes['Preference_Notifications_Settings']> = {
    email?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    sms?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    browser?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_OrganizationResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Organization'] = IResolversParentTypes['Preference_Organization']> = {
    teams?: Resolver<Maybe<IResolversTypes['Preference_Teams']>, ParentType, ContextType>;
    project?: Resolver<Maybe<IResolversTypes['Preference_Project']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_ProjectResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Project'] = IResolversParentTypes['Preference_Project']> = {
    visibility?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    tags?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreference_TeamsResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preference_Teams'] = IResolversParentTypes['Preference_Teams']> = {
    visibility?: Resolver<Maybe<IResolversTypes['Visibility']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreferenceItemResolvers<ContextType = any, ParentType extends IResolversParentTypes['PreferenceItem'] = IResolversParentTypes['PreferenceItem']> = {
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    type?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    default?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    description?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    categoryType?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    settings?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    enum?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    enumDescriptions?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreferencesResolvers<ContextType = any, ParentType extends IResolversParentTypes['Preferences'] = IResolversParentTypes['Preferences']> = {
    account?: Resolver<Maybe<IResolversTypes['Preference_Account']>, ParentType, ContextType>;
    channel?: Resolver<Maybe<IResolversTypes['ChannelSettings']>, ParentType, ContextType>;
    defaultSetting?: Resolver<Maybe<Array<Maybe<IResolversTypes['SettingsGroup']>>>, ParentType, ContextType>;
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    global?: Resolver<Maybe<IResolversTypes['Preference_Global']>, ParentType, ContextType>;
    organization?: Resolver<Maybe<IResolversTypes['Preference_Organization']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreferencesResponseResolvers<ContextType = any, ParentType extends IResolversParentTypes['PreferencesResponse'] = IResolversParentTypes['PreferencesResponse']> = {
    preferences?: Resolver<Maybe<Array<Maybe<IResolversTypes['PreferencesType']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPreferencesTypeResolvers<ContextType = any, ParentType extends IResolversParentTypes['PreferencesType'] = IResolversParentTypes['PreferencesType']> = {
    type?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    data?: Resolver<Maybe<Array<Maybe<IResolversTypes['ContributionSettings']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IProject_OutputResolvers<ContextType = any, ParentType extends IResolversParentTypes['Project_Output'] = IResolversParentTypes['Project_Output']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    clientId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    teams?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    integrationConfigurationId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IProjectInvoiceResolvers<ContextType = any, ParentType extends IResolversParentTypes['ProjectInvoice'] = IResolversParentTypes['ProjectInvoice']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    hours?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    projectName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    rate?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    subTotal?: Resolver<Maybe<IResolversTypes['Float']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IProjectParametersResolvers<ContextType = any, ParentType extends IResolversParentTypes['ProjectParameters'] = IResolversParentTypes['ProjectParameters']> = {
    branch?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    httpsUrl?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    isPrivate?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IProjectsResolvers<ContextType = any, ParentType extends IResolversParentTypes['Projects'] = IResolversParentTypes['Projects']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    description?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    clientId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    source?: Resolver<Maybe<IResolversTypes['ProjectSource']>, ParentType, ContextType>;
    problems?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    teams?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    type?: Resolver<Maybe<IResolversTypes['ProjectType']>, ParentType, ContextType>;
    integrationConfigurationId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    templateId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    updatedAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IProjectSourceResolvers<ContextType = any, ParentType extends IResolversParentTypes['ProjectSource'] = IResolversParentTypes['ProjectSource']> = {
    location?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    type?: Resolver<Maybe<IResolversTypes['ProjectSourceType']>, ParentType, ContextType>;
    parameters?: Resolver<Maybe<IResolversTypes['ProjectParameters']>, ParentType, ContextType>;
    providers?: Resolver<Maybe<IResolversTypes['ProjectSourceProviders']>, ParentType, ContextType>;
    language?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IQueryResolvers<ContextType = any, ParentType extends IResolversParentTypes['Query'] = IResolversParentTypes['Query']> = {
    channelByName?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType, RequireFields<IQuerychannelByNameArgs, 'name'>>;
    channels?: Resolver<Maybe<Array<Maybe<IResolversTypes['Channel']>>>, ParentType, ContextType, RequireFields<IQuerychannelsArgs, 'filter'>>;
    channelsByUser?: Resolver<Maybe<Array<Maybe<IResolversTypes['Channel']>>>, ParentType, ContextType>;
    currentUser?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType, RequireFields<IQuerycurrentUserArgs, 'auth0Id'>>;
    decodeOrganizationInvitation?: Resolver<Maybe<IResolversTypes['OrganizationInvitationDecode']>, ParentType, ContextType, RequireFields<IQuerydecodeOrganizationInvitationArgs, 'token'>>;
    defaultPermissions?: Resolver<Maybe<Array<Maybe<IResolversTypes['SettingsGroup']>>>, ParentType, ContextType, RequireFields<IQuerydefaultPermissionsArgs, never>>;
    defaultPolicies?: Resolver<Maybe<Array<Maybe<IResolversTypes['SettingsGroup']>>>, ParentType, ContextType, RequireFields<IQuerydefaultPoliciesArgs, never>>;
    defaultPreferences?: Resolver<Maybe<IResolversTypes['PreferencesResponse']>, ParentType, ContextType>;
    defaultSetting?: Resolver<Maybe<IResolversTypes['ContributionSettings']>, ParentType, ContextType>;
    defaultViewerSettingsSubject?: Resolver<IResolversTypes['DefaultSettings'], ParentType, ContextType, RequireFields<IQuerydefaultViewerSettingsSubjectArgs, never>>;
    directChannel?: Resolver<Maybe<IResolversTypes['Channel']>, ParentType, ContextType, RequireFields<IQuerydirectChannelArgs, 'id'>>;
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    fetchAuth0User?: Resolver<Maybe<IResolversTypes['UserProfile']>, ParentType, ContextType, RequireFields<IQueryfetchAuth0UserArgs, 'auth0UserId'>>;
    fetchUserAuthorizedDevices?: Resolver<Maybe<Array<Maybe<IResolversTypes['UserDevice']>>>, ParentType, ContextType, RequireFields<IQueryfetchUserAuthorizedDevicesArgs, 'auth0UserId'>>;
    fileInfo?: Resolver<IResolversTypes['FileInfo'], ParentType, ContextType, RequireFields<IQueryfileInfoArgs, 'id'>>;
    filesInfo?: Resolver<IResolversTypes['FilesInfo'], ParentType, ContextType, RequireFields<IQueryfilesInfoArgs, never>>;
    filterIntegrationConfiguration?: Resolver<Maybe<Array<Maybe<IResolversTypes['IntegrationConfiguration']>>>, ParentType, ContextType, RequireFields<IQueryfilterIntegrationConfigurationArgs, never>>;
    getAccounts?: Resolver<Maybe<Array<Maybe<IResolversTypes['UserAccount']>>>, ParentType, ContextType, RequireFields<IQuerygetAccountsArgs, never>>;
    getAllCountries?: Resolver<Maybe<Array<Maybe<IResolversTypes['Country']>>>, ParentType, ContextType, RequireFields<IQuerygetAllCountriesArgs, never>>;
    getAllIntegrationConfigurations?: Resolver<Maybe<Array<Maybe<IResolversTypes['IntegrationConfiguration']>>>, ParentType, ContextType>;
    getAsanaConnectionState?: Resolver<Maybe<IResolversTypes['AsanaConnection']>, ParentType, ContextType>;
    getAsanaWorkspaceProjects?: Resolver<Maybe<Array<Maybe<IResolversTypes['AsanaProjects']>>>, ParentType, ContextType, RequireFields<IQuerygetAsanaWorkspaceProjectsArgs, 'workspaceId'>>;
    getAsanaWorkspaces?: Resolver<Maybe<Array<Maybe<IResolversTypes['AsanaWorkspaces']>>>, ParentType, ContextType>;
    getConfiguration?: Resolver<Maybe<Array<Maybe<IResolversTypes['Configuration']>>>, ParentType, ContextType, RequireFields<IQuerygetConfigurationArgs, never>>;
    getConfigurationData?: Resolver<Maybe<IResolversTypes['ConfigurationData']>, ParentType, ContextType>;
    getConfigurationPolicies?: Resolver<Maybe<Array<Maybe<IResolversTypes['ConfigurationPolicy']>>>, ParentType, ContextType, RequireFields<IQuerygetConfigurationPoliciesArgs, never>>;
    getContributionRoles?: Resolver<Maybe<Array<Maybe<IResolversTypes['ContributionRoles']>>>, ParentType, ContextType>;
    getDefaultInvoiceNumber?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    getEnvironment?: Resolver<Maybe<IResolversTypes['Environment']>, ParentType, ContextType>;
    getFilteredProjects?: Resolver<Maybe<Array<Maybe<IResolversTypes['Projects']>>>, ParentType, ContextType, RequireFields<IQuerygetFilteredProjectsArgs, 'filter'>>;
    getIntegrationConfiguration?: Resolver<Maybe<IResolversTypes['IntegrationConfiguration']>, ParentType, ContextType, RequireFields<IQuerygetIntegrationConfigurationArgs, 'id'>>;
    getInvoices?: Resolver<Maybe<Array<Maybe<IResolversTypes['InvoiceType']>>>, ParentType, ContextType>;
    getManageableOrganizations?: Resolver<Maybe<Array<Maybe<IResolversTypes['Organization']>>>, ParentType, ContextType>;
    getOrgInvitationMembers?: Resolver<Maybe<Array<Maybe<IResolversTypes['InviteMember']>>>, ParentType, ContextType>;
    getOrgTeamInvitations?: Resolver<Maybe<Array<Maybe<IResolversTypes['OrganizationInvitation']>>>, ParentType, ContextType, RequireFields<IQuerygetOrgTeamInvitationsArgs, never>>;
    getOrganizationClients?: Resolver<Maybe<Array<Maybe<IResolversTypes['Client']>>>, ParentType, ContextType>;
    getOrganizationConfigValue?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IQuerygetOrganizationConfigValueArgs, never>>;
    getOrganizationDetail?: Resolver<Maybe<IResolversTypes['Organization']>, ParentType, ContextType, RequireFields<IQuerygetOrganizationDetailArgs, 'where'>>;
    getOrganizationDetailUnsecured?: Resolver<Maybe<IResolversTypes['Organization']>, ParentType, ContextType, RequireFields<IQuerygetOrganizationDetailUnsecuredArgs, 'where'>>;
    getOrganizationInvitation?: Resolver<Maybe<IResolversTypes['OrganizationInvitation']>, ParentType, ContextType, RequireFields<IQuerygetOrganizationInvitationArgs, 'id'>>;
    getOrganizationMembers?: Resolver<Maybe<Array<Maybe<IResolversTypes['OrgMember']>>>, ParentType, ContextType>;
    getOrganizationResourceContext?: Resolver<Maybe<IResolversTypes['OrganizationData']>, ParentType, ContextType, RequireFields<IQuerygetOrganizationResourceContextArgs, never>>;
    getOrganizationTeams?: Resolver<Maybe<Array<Maybe<IResolversTypes['AccountTeam']>>>, ParentType, ContextType, RequireFields<IQuerygetOrganizationTeamsArgs, never>>;
    getPostReactions?: Resolver<Maybe<Array<Maybe<IResolversTypes['Reaction']>>>, ParentType, ContextType, RequireFields<IQuerygetPostReactionsArgs, 'message'>>;
    getProjects?: Resolver<Maybe<Array<Maybe<IResolversTypes['Project_Output']>>>, ParentType, ContextType>;
    getRole?: Resolver<Maybe<IResolversTypes['AccessRole']>, ParentType, ContextType, RequireFields<IQuerygetRoleArgs, never>>;
    getRoles?: Resolver<Maybe<Array<Maybe<IResolversTypes['AccessRole']>>>, ParentType, ContextType, RequireFields<IQuerygetRolesArgs, never>>;
    getTasks?: Resolver<Maybe<Array<Maybe<IResolversTypes['Task']>>>, ParentType, ContextType, RequireFields<IQuerygetTasksArgs, never>>;
    getTeam?: Resolver<Maybe<IResolversTypes['AccountTeam']>, ParentType, ContextType, RequireFields<IQuerygetTeamArgs, 'orgName' | 'teamName'>>;
    getUserAccessRole?: Resolver<Maybe<IResolversTypes['ResourceAccessRole']>, ParentType, ContextType, RequireFields<IQuerygetUserAccessRoleArgs, never>>;
    getUserAccount?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType, RequireFields<IQuerygetUserAccountArgs, 'userId'>>;
    getUserAccountByAuth0Id?: Resolver<Maybe<IResolversTypes['UserAccount']>, ParentType, ContextType, RequireFields<IQuerygetUserAccountByAuth0IdArgs, 'userAuth0Id'>>;
    getUserEmailVerificationTokenDetails?: Resolver<Maybe<IResolversTypes['UserEmailVerificationTokenDetails']>, ParentType, ContextType>;
    getUserOrganizations?: Resolver<Maybe<Array<Maybe<IResolversTypes['Organization']>>>, ParentType, ContextType, RequireFields<IQuerygetUserOrganizationsArgs, never>>;
    getUserOrganizationsWithRole?: Resolver<Maybe<Array<Maybe<IResolversTypes['Organization']>>>, ParentType, ContextType, RequireFields<IQuerygetUserOrganizationsWithRoleArgs, never>>;
    getUsers?: Resolver<Maybe<Array<Maybe<IResolversTypes['UserAccount']>>>, ParentType, ContextType, RequireFields<IQuerygetUsersArgs, never>>;
    getViewerPermissions?: Resolver<Maybe<IResolversTypes['PermissionSubject']>, ParentType, ContextType, RequireFields<IQuerygetViewerPermissionsArgs, never>>;
    getViewerPolicies?: Resolver<Maybe<IResolversTypes['PolicySubject']>, ParentType, ContextType, RequireFields<IQuerygetViewerPoliciesArgs, 'input'>>;
    mergedApplicationPermissions?: Resolver<Maybe<Array<Maybe<IResolversTypes['ContributionSettings']>>>, ParentType, ContextType, RequireFields<IQuerymergedApplicationPermissionsArgs, never>>;
    messages?: Resolver<IResolversTypes['Messages'], ParentType, ContextType, RequireFields<IQuerymessagesArgs, never>>;
    organizations?: Resolver<Maybe<Array<Maybe<IResolversTypes['Organization']>>>, ParentType, ContextType>;
    team?: Resolver<Maybe<IResolversTypes['AccountTeam']>, ParentType, ContextType, RequireFields<IQueryteamArgs, 'teamId'>>;
    teams?: Resolver<Maybe<Array<Maybe<IResolversTypes['AccountTeam']>>>, ParentType, ContextType>;
    usersToChat?: Resolver<Maybe<Array<Maybe<IResolversTypes['UserAccount']>>>, ParentType, ContextType, RequireFields<IQueryusersToChatArgs, 'auth0Id'>>;
    viewerPolicies?: Resolver<Maybe<IResolversTypes['PolicySubject']>, ParentType, ContextType, RequireFields<IQueryviewerPoliciesArgs, 'input'>>;
    viewerSettings?: Resolver<IResolversTypes['ViewerSettingsSubject'], ParentType, ContextType, RequireFields<IQueryviewerSettingsArgs, never>>;
};
export declare type IRangeResolvers<ContextType = any, ParentType extends IResolversParentTypes['Range'] = IResolversParentTypes['Range']> = {
    start?: Resolver<Maybe<IResolversTypes['Position']>, ParentType, ContextType>;
    end?: Resolver<Maybe<IResolversTypes['Position']>, ParentType, ContextType>;
    startLineNumber?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    startColumn?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    endLineNumber?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    endColumn?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IReactionResolvers<ContextType = any, ParentType extends IResolversParentTypes['Reaction'] = IResolversParentTypes['Reaction']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    reaction?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    user?: Resolver<IResolversTypes['UserAccount'], ParentType, ContextType>;
    post?: Resolver<IResolversTypes['Post'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IResourceAccessRoleResolvers<ContextType = any, ParentType extends IResolversParentTypes['ResourceAccessRole'] = IResolversParentTypes['ResourceAccessRole']> = {
    accessRoles?: Resolver<Maybe<Array<Maybe<IResolversTypes['AccessRole']>>>, ParentType, ContextType>;
    resourceUserRoles?: Resolver<Maybe<Array<Maybe<IResolversTypes['ResourceUser']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IResourceDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['ResourceData'] = IResolversParentTypes['ResourceData']> = {
    __resolveType: TypeResolveFn<'OrganizationResourceData' | 'ExternalResourceData', ParentType, ContextType>;
};
export declare type IResourcePolicyResolvers<ContextType = any, ParentType extends IResolversParentTypes['ResourcePolicy'] = IResolversParentTypes['ResourcePolicy']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IResourceRoleResolvers<ContextType = any, ParentType extends IResolversParentTypes['ResourceRole'] = IResolversParentTypes['ResourceRole']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IResourceUserResolvers<ContextType = any, ParentType extends IResolversParentTypes['ResourceUser'] = IResolversParentTypes['ResourceUser']> = {
    resource?: Resolver<Maybe<IResolversTypes['URI']>, ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    isSelf?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    orgName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['Settings'] = IResolversParentTypes['Settings']> = {
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    contents?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISettingsCascadeResolvers<ContextType = any, ParentType extends IResolversParentTypes['SettingsCascade'] = IResolversParentTypes['SettingsCascade']> = {
    subjects?: Resolver<Maybe<Array<Maybe<IResolversTypes['SettingsSubject']>>>, ParentType, ContextType>;
    final?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    finalConfiguration?: Resolver<Maybe<IResolversTypes['Preferences']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISettingsGroupResolvers<ContextType = any, ParentType extends IResolversParentTypes['SettingsGroup'] = IResolversParentTypes['SettingsGroup']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    range?: Resolver<Maybe<IResolversTypes['Range']>, ParentType, ContextType>;
    title?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    titleRange?: Resolver<Maybe<IResolversTypes['Range']>, ParentType, ContextType>;
    sections?: Resolver<Maybe<Array<Maybe<IResolversTypes['SettingsSection']>>>, ParentType, ContextType>;
    contributedByExtension?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISettingsSectionResolvers<ContextType = any, ParentType extends IResolversParentTypes['SettingsSection'] = IResolversParentTypes['SettingsSection']> = {
    titleRange?: Resolver<Maybe<IResolversTypes['Range']>, ParentType, ContextType>;
    title?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    settings?: Resolver<Maybe<Array<Maybe<IResolversTypes['ContributionSettings']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISettingsSubjectResolvers<ContextType = any, ParentType extends IResolversParentTypes['SettingsSubject'] = IResolversParentTypes['SettingsSubject']> = {
    __resolveType: TypeResolveFn<'UserSettings' | 'ApplicationSettings' | 'MachineSettings' | 'OrganizationResourceSettings' | 'GlobalSettings' | 'OrganizationSettings' | 'MemorySettings' | 'DefaultSettings', ParentType, ContextType>;
};
export declare type ISocialConnectResolvers<ContextType = any, ParentType extends IResolversParentTypes['SocialConnect'] = IResolversParentTypes['SocialConnect']> = {
    facebook?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    twitter?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISubscribedOrganizationDataResolvers<ContextType = any, ParentType extends IResolversParentTypes['SubscribedOrganizationData'] = IResolversParentTypes['SubscribedOrganizationData']> = {
    resources?: Resolver<Maybe<Array<Maybe<IResolversTypes['ResourceData']>>>, ParentType, ContextType>;
    orgNameFilter?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISubscriptionResolvers<ContextType = any, ParentType extends IResolversParentTypes['Subscription'] = IResolversParentTypes['Subscription']> = {
    SubscribeToConfigurationUpdate?: SubscriptionResolver<Maybe<IResolversTypes['ConfigurationUpdateEvent']>, "SubscribeToConfigurationUpdate", ParentType, ContextType, RequireFields<ISubscriptionSubscribeToConfigurationUpdateArgs, 'orgName'>>;
    SubscribeToOrganizationContext?: SubscriptionResolver<Maybe<IResolversTypes['SubscribedOrganizationData']>, "SubscribeToOrganizationContext", ParentType, ContextType, RequireFields<ISubscriptionSubscribeToOrganizationContextArgs, never>>;
    SubscribeToPermissionUpdate?: SubscriptionResolver<Maybe<IResolversTypes['ConfigurationUpdateEvent']>, "SubscribeToPermissionUpdate", ParentType, ContextType, RequireFields<ISubscriptionSubscribeToPermissionUpdateArgs, never>>;
    SubscribeToPolicyUpdate?: SubscriptionResolver<Maybe<IResolversTypes['ConfigurationUpdateEvent']>, "SubscribeToPolicyUpdate", ParentType, ContextType, RequireFields<ISubscriptionSubscribeToPolicyUpdateArgs, never>>;
    chatMessageAdded?: SubscriptionResolver<Maybe<IResolversTypes['Post']>, "chatMessageAdded", ParentType, ContextType, RequireFields<ISubscriptionchatMessageAddedArgs, never>>;
    dummy?: SubscriptionResolver<Maybe<IResolversTypes['Int']>, "dummy", ParentType, ContextType>;
};
export declare type ITaskResolvers<ContextType = any, ParentType extends IResolversParentTypes['Task'] = IResolversParentTypes['Task']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    projectId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    taskName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ITeamMemberResolvers<ContextType = any, ParentType extends IResolversParentTypes['TeamMember'] = IResolversParentTypes['TeamMember']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    userId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    status?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface ITimeScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Time'], any> {
    name: 'Time';
}
export interface IUploadScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Upload'], any> {
    name: 'Upload';
}
export interface IURIScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['URI'], any> {
    name: 'URI';
}
export interface IURIInputScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['URIInput'], any> {
    name: 'URIInput';
}
export declare type IUserAccountResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserAccount'] = IResolversParentTypes['UserAccount']> = {
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    alias?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    emailVerified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    notificationEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    familyName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    givenName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    picture?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phoneNumber?: Resolver<Maybe<Array<IResolversTypes['PhoneNumber']>>, ParentType, ContextType>;
    tokens?: Resolver<Maybe<Array<Maybe<IResolversTypes['UserVerificationToken']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserAccountCreatedDetailedEventResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserAccountCreatedDetailedEvent'] = IResolversParentTypes['UserAccountCreatedDetailedEvent']> = {
    id?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    email?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    username?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    emailVerified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    notificationEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    alias?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    user_metadata?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserAccountCreatedEventResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserAccountCreatedEvent'] = IResolversParentTypes['UserAccountCreatedEvent']> = {
    createdUser?: Resolver<Maybe<IResolversTypes['UserAccountCreatedDetailedEvent']>, ParentType, ContextType>;
    sourceUser?: Resolver<Maybe<IResolversTypes['UserProfile']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserAccountRemovedEventResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserAccountRemovedEvent'] = IResolversParentTypes['UserAccountRemovedEvent']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    username?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    notificationEmail?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserConfigurationResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserConfiguration'] = IResolversParentTypes['UserConfiguration']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    resource?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    target?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    contents?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    keys?: Resolver<Maybe<Array<Maybe<IResolversTypes['String']>>>, ParentType, ContextType>;
    overrides?: Resolver<Maybe<Array<Maybe<IResolversTypes['Overrides']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserDeviceResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserDevice'] = IResolversParentTypes['UserDevice']> = {
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    lastLoginAt?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
    lastLoginIp?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserEmailVerificationTokenDetailsResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserEmailVerificationTokenDetails'] = IResolversParentTypes['UserEmailVerificationTokenDetails']> = {
    key?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    value?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    token?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    verified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    isValid?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserMetadataResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserMetadata'] = IResolversParentTypes['UserMetadata']> = {
    last_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    first_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    username?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    phone_number?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    work_email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    country?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    company_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    dob?: Resolver<Maybe<IResolversTypes['Date']>, ParentType, ContextType>;
    zip_code?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserOrgResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserOrg'] = IResolversParentTypes['UserOrg']> = {
    userId?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    role?: Resolver<Maybe<IResolversTypes['ApplicationRoles']>, ParentType, ContextType>;
    inactive?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserPreviousValuesResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserPreviousValues'] = IResolversParentTypes['UserPreviousValues']> = {
    auth0UserId?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<IResolversTypes['DateTime'], ParentType, ContextType>;
    emailSubscription?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
    updatedAt?: Resolver<IResolversTypes['DateTime'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserProfileResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserProfile'] = IResolversParentTypes['UserProfile']> = {
    name?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    nickname?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    picture?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    user_id?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    username?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    given_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    family_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    email_verified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    clientID?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    gender?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    locale?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    identities?: Resolver<Maybe<Array<Maybe<IResolversTypes['Auth0Identity']>>>, ParentType, ContextType>;
    accessToken?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    created_at?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    updated_at?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    user_metadata?: Resolver<Maybe<IResolversTypes['UserMetadata']>, ParentType, ContextType>;
    app_metadata?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    phone_number?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    work_email?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    country?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    company_name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    iss?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    sub?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    aud?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    iat?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    exp?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    at_hash?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    nonce?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserSettingsResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserSettings'] = IResolversParentTypes['UserSettings']> = {
    id?: Resolver<Maybe<IResolversTypes['ID']>, ParentType, ContextType>;
    latestSettings?: Resolver<Maybe<IResolversTypes['Settings']>, ParentType, ContextType>;
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    viewerCanAdminister?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    settingsCascade?: Resolver<IResolversTypes['SettingsCascade'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IUserVerificationTokenResolvers<ContextType = any, ParentType extends IResolversParentTypes['UserVerificationToken'] = IResolversParentTypes['UserVerificationToken']> = {
    key?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    value?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    token?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    verified?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IViewerSettingsSubjectResolvers<ContextType = any, ParentType extends IResolversParentTypes['ViewerSettingsSubject'] = IResolversParentTypes['ViewerSettingsSubject']> = {
    settingsURL?: Resolver<IResolversTypes['URI'], ParentType, ContextType>;
    settings?: Resolver<Maybe<IResolversTypes['Preferences']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IResolvers<ContextType = any> = {
    AccessRole?: IAccessRoleResolvers<ContextType>;
    AccountTeam?: IAccountTeamResolvers<ContextType>;
    AddressType?: IAddressTypeResolvers<ContextType>;
    AdminIdeSettings?: IAdminIdeSettingsResolvers<ContextType>;
    AnyObject?: GraphQLScalarType;
    ApplicationPolicy?: IApplicationPolicyResolvers<ContextType>;
    ApplicationRolePermission?: IApplicationRolePermissionResolvers<ContextType>;
    ApplicationSettings?: IApplicationSettingsResolvers<ContextType>;
    AsanaConnection?: IAsanaConnectionResolvers<ContextType>;
    AsanaConnectionState?: IAsanaConnectionStateResolvers<ContextType>;
    AsanaProjects?: IAsanaProjectsResolvers<ContextType>;
    AsanaUser?: IAsanaUserResolvers<ContextType>;
    AsanaWorkspaces?: IAsanaWorkspacesResolvers<ContextType>;
    Auth0Identity?: IAuth0IdentityResolvers<ContextType>;
    Auth0IdentityProfileData?: IAuth0IdentityProfileDataResolvers<ContextType>;
    AuthUser?: IAuthUserResolvers<ContextType>;
    Channel?: IChannelResolvers<ContextType>;
    ChannelMember?: IChannelMemberResolvers<ContextType>;
    ChannelSettings?: IChannelSettingsResolvers<ContextType>;
    ChannelUnread?: IChannelUnreadResolvers<ContextType>;
    Client?: IClientResolvers<ContextType>;
    ClientPhone?: IClientPhoneResolvers<ContextType>;
    Configuration?: IConfigurationResolvers<ContextType>;
    ConfigurationData?: IConfigurationDataResolvers<ContextType>;
    ConfigurationExtensionInfo?: IConfigurationExtensionInfoResolvers<ContextType>;
    ConfigurationModel?: IConfigurationModelResolvers<ContextType>;
    ConfigurationOverrides?: IConfigurationOverridesResolvers<ContextType>;
    ConfigurationPolicy?: IConfigurationPolicyResolvers<ContextType>;
    ConfigurationUpdateEvent?: IConfigurationUpdateEventResolvers<ContextType>;
    ContributionRoles?: IContributionRolesResolvers<ContextType>;
    ContributionSettings?: IContributionSettingsResolvers<ContextType>;
    ContributionSettingsProperties?: IContributionSettingsPropertiesResolvers<ContextType>;
    Country?: ICountryResolvers<ContextType>;
    CustomerInvoice?: ICustomerInvoiceResolvers<ContextType>;
    Date?: GraphQLScalarType;
    DateTime?: GraphQLScalarType;
    DefaultConfiguration?: IDefaultConfigurationResolvers<ContextType>;
    DefaultPolicy?: IDefaultPolicyResolvers<ContextType>;
    DefaultRole?: IDefaultRoleResolvers<ContextType>;
    DefaultSettings?: IDefaultSettingsResolvers<ContextType>;
    Environment?: IEnvironmentResolvers<ContextType>;
    ExternalResourceData?: IExternalResourceDataResolvers<ContextType>;
    FieldError?: IFieldErrorResolvers<ContextType>;
    File?: IFileResolvers<ContextType>;
    FileInfo?: IFileInfoResolvers<ContextType>;
    FilesInfo?: IFilesInfoResolvers<ContextType>;
    GeoLocation?: IGeoLocationResolvers<ContextType>;
    GlobalSettings?: IGlobalSettingsResolvers<ContextType>;
    IAuth0Identity?: IIAuth0IdentityResolvers<ContextType>;
    IAuth0Token?: IIAuth0TokenResolvers<ContextType>;
    IAuth0User?: IIAuth0UserResolvers<ContextType>;
    IAuth0UserProfile?: IIAuth0UserProfileResolvers<ContextType>;
    IBaseRepo?: IIBaseRepoResolvers<ContextType>;
    ICity?: IICityResolvers<ContextType>;
    IConfigurationChangeEvent?: IIConfigurationChangeEventResolvers<ContextType>;
    IConfigurationModel?: IIConfigurationModelResolvers<ContextType>;
    IConfigurationService?: IIConfigurationServiceResolvers<ContextType>;
    ICountry?: IICountryResolvers<ContextType>;
    IFileRef?: IIFileRefResolvers<ContextType>;
    IntegraitonConfigurationId?: IIntegraitonConfigurationIdResolvers<ContextType>;
    IntegrationConfiguration?: IIntegrationConfigurationResolvers<ContextType>;
    InviteMember?: IInviteMemberResolvers<ContextType>;
    InvoiceType?: IInvoiceTypeResolvers<ContextType>;
    IOrgUser?: IIOrgUserResolvers<ContextType>;
    IResourceData?: IIResourceDataResolvers<ContextType>;
    IResourceUserRole?: IIResourceUserRoleResolvers<ContextType>;
    ISettingsSubject?: IISettingsSubjectResolvers<ContextType>;
    ITerritorialState?: IITerritorialStateResolvers<ContextType>;
    IUser?: IIUserResolvers<ContextType>;
    IUserMetadata?: IIUserMetadataResolvers<ContextType>;
    JSON?: GraphQLScalarType;
    JSONObject?: GraphQLScalarType;
    LoginError?: ILoginErrorResolvers<ContextType>;
    MachineConfiguration?: IMachineConfigurationResolvers<ContextType>;
    MachineSettings?: IMachineSettingsResolvers<ContextType>;
    MemberInvoice?: IMemberInvoiceResolvers<ContextType>;
    MemorySettings?: IMemorySettingsResolvers<ContextType>;
    Messages?: IMessagesResolvers<ContextType>;
    MessengerUser?: IMessengerUserResolvers<ContextType>;
    Mutation?: IMutationResolvers<ContextType>;
    NameType?: INameTypeResolvers<ContextType>;
    Node?: INodeResolvers<ContextType>;
    Observable?: GraphQLScalarType;
    Organization?: IOrganizationResolvers<ContextType>;
    OrganizationConfiguration?: IOrganizationConfigurationResolvers<ContextType>;
    OrganizationData?: IOrganizationDataResolvers<ContextType>;
    OrganizationIdentifier?: IOrganizationIdentifierResolvers<ContextType>;
    OrganizationInvitation?: IOrganizationInvitationResolvers<ContextType>;
    OrganizationInvitationDecode?: IOrganizationInvitationDecodeResolvers<ContextType>;
    OrganizationMember?: IOrganizationMemberResolvers<ContextType>;
    OrganizationPolicy?: IOrganizationPolicyResolvers<ContextType>;
    OrganizationResourceConfiguration?: IOrganizationResourceConfigurationResolvers<ContextType>;
    OrganizationResourceData?: IOrganizationResourceDataResolvers<ContextType>;
    OrganizationResourceSettings?: IOrganizationResourceSettingsResolvers<ContextType>;
    OrganizationRole?: IOrganizationRoleResolvers<ContextType>;
    OrganizationSettings?: IOrganizationSettingsResolvers<ContextType>;
    OrgMember?: IOrgMemberResolvers<ContextType>;
    OrgUser?: IOrgUserResolvers<ContextType>;
    OrgUserAccunt?: IOrgUserAccuntResolvers<ContextType>;
    Overrides?: IOverridesResolvers<ContextType>;
    PermissionSubject?: IPermissionSubjectResolvers<ContextType>;
    PhoneNumber?: IPhoneNumberResolvers<ContextType>;
    PolicySubject?: IPolicySubjectResolvers<ContextType>;
    Position?: IPositionResolvers<ContextType>;
    Post?: IPostResolvers<ContextType>;
    PostsWithCursor?: IPostsWithCursorResolvers<ContextType>;
    PostThread?: IPostThreadResolvers<ContextType>;
    Preference_Account?: IPreference_AccountResolvers<ContextType>;
    Preference_Account_Global?: IPreference_Account_GlobalResolvers<ContextType>;
    Preference_Account_Global_Notification?: IPreference_Account_Global_NotificationResolvers<ContextType>;
    Preference_Default?: IPreference_DefaultResolvers<ContextType>;
    Preference_Global?: IPreference_GlobalResolvers<ContextType>;
    Preference_Global_User?: IPreference_Global_UserResolvers<ContextType>;
    Preference_Notification?: IPreference_NotificationResolvers<ContextType>;
    Preference_Notifications_Settings?: IPreference_Notifications_SettingsResolvers<ContextType>;
    Preference_Organization?: IPreference_OrganizationResolvers<ContextType>;
    Preference_Project?: IPreference_ProjectResolvers<ContextType>;
    Preference_Teams?: IPreference_TeamsResolvers<ContextType>;
    PreferenceItem?: IPreferenceItemResolvers<ContextType>;
    Preferences?: IPreferencesResolvers<ContextType>;
    PreferencesResponse?: IPreferencesResponseResolvers<ContextType>;
    PreferencesType?: IPreferencesTypeResolvers<ContextType>;
    Project_Output?: IProject_OutputResolvers<ContextType>;
    ProjectInvoice?: IProjectInvoiceResolvers<ContextType>;
    ProjectParameters?: IProjectParametersResolvers<ContextType>;
    Projects?: IProjectsResolvers<ContextType>;
    ProjectSource?: IProjectSourceResolvers<ContextType>;
    Query?: IQueryResolvers<ContextType>;
    Range?: IRangeResolvers<ContextType>;
    Reaction?: IReactionResolvers<ContextType>;
    ResourceAccessRole?: IResourceAccessRoleResolvers<ContextType>;
    ResourceData?: IResourceDataResolvers<ContextType>;
    ResourcePolicy?: IResourcePolicyResolvers<ContextType>;
    ResourceRole?: IResourceRoleResolvers<ContextType>;
    ResourceUser?: IResourceUserResolvers<ContextType>;
    Settings?: ISettingsResolvers<ContextType>;
    SettingsCascade?: ISettingsCascadeResolvers<ContextType>;
    SettingsGroup?: ISettingsGroupResolvers<ContextType>;
    SettingsSection?: ISettingsSectionResolvers<ContextType>;
    SettingsSubject?: ISettingsSubjectResolvers<ContextType>;
    SocialConnect?: ISocialConnectResolvers<ContextType>;
    SubscribedOrganizationData?: ISubscribedOrganizationDataResolvers<ContextType>;
    Subscription?: ISubscriptionResolvers<ContextType>;
    Task?: ITaskResolvers<ContextType>;
    TeamMember?: ITeamMemberResolvers<ContextType>;
    Time?: GraphQLScalarType;
    Upload?: GraphQLScalarType;
    URI?: GraphQLScalarType;
    URIInput?: GraphQLScalarType;
    UserAccount?: IUserAccountResolvers<ContextType>;
    UserAccountCreatedDetailedEvent?: IUserAccountCreatedDetailedEventResolvers<ContextType>;
    UserAccountCreatedEvent?: IUserAccountCreatedEventResolvers<ContextType>;
    UserAccountRemovedEvent?: IUserAccountRemovedEventResolvers<ContextType>;
    UserConfiguration?: IUserConfigurationResolvers<ContextType>;
    UserDevice?: IUserDeviceResolvers<ContextType>;
    UserEmailVerificationTokenDetails?: IUserEmailVerificationTokenDetailsResolvers<ContextType>;
    UserMetadata?: IUserMetadataResolvers<ContextType>;
    UserOrg?: IUserOrgResolvers<ContextType>;
    UserPreviousValues?: IUserPreviousValuesResolvers<ContextType>;
    UserProfile?: IUserProfileResolvers<ContextType>;
    UserSettings?: IUserSettingsResolvers<ContextType>;
    UserVerificationToken?: IUserVerificationTokenResolvers<ContextType>;
    ViewerSettingsSubject?: IViewerSettingsSubjectResolvers<ContextType>;
};
export declare type IDirectiveResolvers<ContextType = any> = {
    addAccountContext?: IaddAccountContextDirectiveResolver<any, any, ContextType>;
    addNamespaceContext?: IaddNamespaceContextDirectiveResolver<any, any, ContextType>;
    hasScope?: IhasScopeDirectiveResolver<any, any, ContextType>;
    isAuthenticated?: IisAuthenticatedDirectiveResolver<any, any, ContextType>;
    profile?: IprofileDirectiveResolver<any, any, ContextType>;
};
